#include "zoned_otp.h"
#include "pico/bootrom.h"
#include "hardware/structs/otp.h"
#include "debug_rtt.h"
#include "rp2350_otp_ecc.h"

namespace zoned_otp {

    static constexpr char byte_to_printable_char(uint8_t byte) {
        if (byte < 0x20u) {
            return '.';
        }
        if (byte > 0x7Eu) {
            return '.';
        }
        return static_cast<char>(byte);
    }
    static const char* empty_string = "";
    

    int read_zone(otp_zone_t zone, otp_zone_ecc_buffer_t& data) {
        otp_cmd_t cmd;
        cmd.flags = get_zone_start_row(zone);
        cmd.flags |= OTP_CMD_ECC_BITS;
        return rom_func_otp_access((uint8_t*)data.ecc_data, sizeof(data), cmd);
    }
    int read_zone(otp_zone_t zone, otp_zone_raw_buffer_t& data) {
        otp_cmd_t cmd;
        cmd.flags = get_zone_start_row(zone);
        return rom_func_otp_access((uint8_t*)data.raw_data, sizeof(data), cmd);
    }

    // easy way to switch between "actually writes" and "does not actually write"
    namespace _actually_writes {
        int write_zone(otp_zone_t zone, otp_zone_ecc_buffer_t& data) {
            otp_cmd_t cmd;
            cmd.flags = get_zone_start_row(zone);
            cmd.flags |= OTP_CMD_ECC_BITS;
            cmd.flags |= OTP_CMD_WRITE_BITS;
            return rom_func_otp_access((uint8_t*)data.ecc_data, sizeof(data), cmd);
        }
        int write_zone(otp_zone_t zone, otp_zone_raw_buffer_t& data) {
            otp_cmd_t cmd;
            cmd.flags = get_zone_start_row(zone);
            cmd.flags |= OTP_CMD_WRITE_BITS;
            return rom_func_otp_access((uint8_t*)data.raw_data, sizeof(data), cmd);
        }
    }
    namespace _does_not_actually_write {
        int write_zone(otp_zone_t zone, otp_zone_raw_buffer_t& data) {
            PRINT_FATAL("OTP WRITING DISABLED FOR NOW\n");
            return BOOTROM_OK;
        }
        int write_zone(otp_zone_t zone, otp_zone_ecc_buffer_t& data) {
            PRINT_FATAL("OTP WRITING DISABLED FOR NOW\n");
            return BOOTROM_OK;
        }
    }

    // differentiate between an all-zero zone,
    // a zone with maximum 1 bit per OTP row (b/c is still ECC writable),
    // and all other cases (at least on row has 2+ bits set).
    otp_zone_state_t determine_zone_state(otp_zone_t zone) {
        otp_zone_raw_buffer_t data = {0};

        int ret = read_zone(zone, data);
        if (BOOTROM_OK != ret) {
            PRINT_ERROR("Failed to read zone at 0x%03x as ecc data: %d\n", get_zone_start_row(zone), ret);
            return otp_zone_state_t::unknown;
        }
        bool found_single_bit_flip  = false;
        bool found_more_than_one_bit_set = false;
        for (size_t i = 0; i < OTP_ZONE_ROWCOUNT; ++i) {
            uint32_t tmp = data.raw_data[i];
            if (tmp == 0u) {
                // expected!
            } else if ((tmp & (tmp - 1u)) != 0u) {
                // clearing lsb set bit still non-zero, so multiple bits were set....
                found_more_than_one_bit_set = true;
            } else {
                // single bit set in raw data
                found_single_bit_flip = true;
            }
        }
        if (found_more_than_one_bit_set) {
            return otp_zone_state_t::multiple_flipped_bits_per_row;
        }
        if (found_single_bit_flip) {
            return otp_zone_state_t::max_single_bit_flipped_per_row;
        }
        return otp_zone_state_t::all_zero;
    }
    // and make easier-to-read wrappers
    bool is_zone_ecc_writable(otp_zone_t zone) {
        otp_zone_state_t state = determine_zone_state(zone);
        return state == otp_zone_state_t::all_zero || state == otp_zone_state_t::max_single_bit_flipped_per_row;
    }
    bool is_zone_all_zero(otp_zone_t zone) {
        otp_zone_state_t state = determine_zone_state(zone);
        return state == otp_zone_state_t::all_zero;
    }

    bool set_brbp_bitflips(otp_zone_t zone, otp_zone_ecc_buffer_t& data) {
        if (!is_zone_all_zero(zone)) {
            PRINT_ERROR("Zone at 0x%03x is not all-zero\n", get_zone_start_row(zone));
            return false;
        }
        otp_zone_raw_buffer_t raw = {0};

        uint32_t all_bits_flipped_count = 0u;
        uint32_t bits_already_flipped = 0u; // no bits flipped at the start ... goal is to flip each bit at least once
        for (uint16_t i = 0u; i < OTP_ZONE_ROWCOUNT; ++i) {
            uint16_t original_data = data.ecc_data[i];
            uint32_t data_with_ecc = calculate_otp_ecc(original_data);
            uint32_t tmp = data_with_ecc;

            // reset back to zero if flipped all bits at least once
            if (bits_already_flipped == 0xFFFFFFu) {
                ++all_bits_flipped_count;
                bits_already_flipped = 0u;
            }
            // mask in all the bits that have already been flipped
            tmp |= bits_already_flipped;
            // NOTE: there will ALWAYS be a flippable bit .. the BRBP bits themselves ensure this.
            if (tmp == 0xFFFFFFu) {
                raw.raw_data[i] = (1u << 23); // flips one of the BRBP bits
            } else {
                // find the least significant bit that is *NOT* set
                uint32_t bit = 1u;
                while (tmp & bit) {
                    bit <<= 1;
                }
                raw.raw_data[i] = bit;
            }
        }

        // write the pattern we just created to the OTP
        int ret = write_zone(zone, raw);    
        if (BOOTROM_OK != ret) {
            PRINT_ERROR("Failed to write zone at 0x%03x with BRBP-forcing data: %d\n", get_zone_start_row(zone), ret);
            return false;
        }
        // that's it ... single write does it all!
        return true;
    }

    bool find_blank_zone(otp_zone_t& zone){
        for (uint8_t i = 1u; i < MAX_USABLE_ZONE; ++i) {
            otp_zone_t tmp = static_cast<otp_zone_t>(i);
            if (is_zone_all_zero(tmp)) {
                zone = tmp;
                return true;
            }
        }
        return false;
    }

    bool flip_two_bits(otp_zone_raw_buffer_t& data) {
        // 24 bits, so 24*23/2 = 276 possible pairs
        // can't fully cover that in 256 rows, but let's get reasonably close
        uint16_t idx = 0;
        for (uint8_t i = 0; (idx < OTP_ZONE_ROWCOUNT) && (i < 24); ++i) {
            uint32_t maskI = 1u << i;
            for (uint8_t j = i+1; (idx < OTP_ZONE_ROWCOUNT) && (j < 24); ++j) {
                uint32_t maskJ = 1u << j;
                data.raw_data[idx] ^= maskI;
                data.raw_data[idx] ^= maskJ;
                ++idx;
            }
        }
        return true;
    }
    bool add_single_bit_errors(otp_zone_raw_buffer_t& data, bool flip_from_0_to_1) {
        uint32_t all_bits_flipped_count = 0u;
        uint32_t bits_already_flipped = 0u; // no bits flipped at the start ... goal is to flip each bit at least once
        static_assert(count_of(data.raw_data) == OTP_ZONE_ROWCOUNT, "");
        for (uint16_t i = 0u; i < OTP_ZONE_ROWCOUNT; ++i) {

            // There are two edge cases for single-bit flips, where nothing can be done.
            // Skip them explicitly here ... makes the remaining code cleaner.
            if ((data.raw_data[i] == 0xFFFFFFu) && (flip_from_0_to_1)) {
                PRINT_WARNING("Row offset 0x%02x is already 0xFFFFFFu, and thus cannot have any bits set to 1\n", i)
                continue;
            }
            if ((data.raw_data[i] == 0x000000u) && (!flip_from_0_to_1)) {
                PRINT_WARNING("Row offset 0x%02x is already 0x000000u, and thus cannot have any bits set to 0\n", i);
                continue;
            }

            // reset back to zero if flipped all bits at least once
            if (bits_already_flipped == 0xFFFFFFu) {
                ++all_bits_flipped_count;
                bits_already_flipped = 0u;
            }

            uint16_t tmp = data.raw_data[i];
            // First pass ... try to spread out which bit gets flipped,
            // to prefer bits not previously flipped.
            if (flip_from_0_to_1) {
                tmp |= bits_already_flipped;
                if (tmp == 0xFFFFFFu) {
                    // no new bits left to flip, flip any available bit...
                    tmp = data.raw_data[i];
                }
            } else {
                tmp &= ~bits_already_flipped;
                if (tmp == 0x000000u) {
                    // no new bits left to flip, flip any available bit...
                    tmp = data.raw_data[i];
                }
                tmp = ~tmp; // HACK -- invert the bits to use common code to find LSB to flip
            }
            // find the least significant bit that is *NOT* set
            uint32_t bit = 1u;
            while (tmp & bit) {
                bit <<= 1;
            }
            // Now, simply XOR that bit into the data (handles flipping either direction)
            data.raw_data[i] ^= bit;
            bits_already_flipped |= bit;
        }
        // reset back to zero if flipped all bits at least once
        if (bits_already_flipped == 0xFFFFFFu) {
            ++all_bits_flipped_count;
            bits_already_flipped = 0u;
        }
        // informational stuff
        PRINT_INFO("Bitflip %s: Was able to flip each of the 24 bits at least %d times\n", flip_from_0_to_1 ? "0->1" : "1->0", all_bits_flipped_count);
        return true;
    }
    bool add_bit_errors(otp_zone_raw_buffer_t& data, otp_bit_flip_t bitflip_type) {
        bool result = false;

        if (bitflip_type == otp_bit_flip_t::none) {
            result = true;
        } else if (bitflip_type == otp_bit_flip_t::single_bit_flip_0_to_1) {
            result = add_single_bit_errors(data, true);
        } else if (bitflip_type == otp_bit_flip_t::single_bit_flip_1_to_0) {
            result = add_single_bit_errors(data, false);
        } else if (bitflip_type == otp_bit_flip_t::multiple_bits_flipped) {
            result = flip_two_bits(data);
        } else {
            PRINT_ERROR("Unhandled bitflip type %d\n", bitflip_type);
            result = false;
        }
        return result;


    }
    bool initialize_ecc_values(otp_zone_raw_buffer_t& out_buffer, bool force_brbp, otp_bit_flip_t bitflip_type) {
    
        bool still_success = true;

        // Step 1: prepare data to be written, as it would be if using ECC writes
        for (uint16_t i = 0u; i < OTP_ZONE_ROWCOUNT; ++i) {
            uint8_t t = static_cast<uint8_t>(i);
            uint16_t as_ecc_corrected_data = (t << 8) | t;
            uint32_t as_raw_data = calculate_otp_ecc(as_ecc_corrected_data);
            
            // top 2 bits are BRBP bits, which should both be zero.  TRUST BUT VERIFY.
            if ((as_raw_data & 0xC00000u) != 0u) {
                hard_assert(false);
                return false;
            }
            out_buffer.raw_data[i] = as_raw_data;
        }

        // Step 2: Should the data be stored using BRBP?
        if (still_success && force_brbp) {
            // Invert the low 24 bits for each row
            for (uint16_t i = 0u; i < OTP_ZONE_ROWCOUNT; ++i) {
                out_buffer.raw_data[i] ^= 0xFFFFFFu;
            }
        }

        // Step 3: Should there be any intentional bit errors?
        if (still_success) {
            if (!add_bit_errors(out_buffer, bitflip_type)) {
                PRINT_ERROR("Failed to add bit flip errors of type %d\n", bitflip_type);
                still_success = false;
            }
        }

        return still_success;
    }
    bool initialize_3way_majority_vote(otp_zone_raw_buffer_t& out_buffer, otp_bit_flip_t bitflip_type) {
        for (uint16_t i = 0u; i < OTP_ZONE_ROWCOUNT; ++i) {
            uint8_t t = static_cast<uint8_t>(i);
            out_buffer.raw_data[i] = (t << 16) | (t << 8) | t;
        }
        if (!add_bit_errors(out_buffer, bitflip_type)) {
            PRINT_ERROR("Zone at 0x%03x - initialize_3way_majority_vote() failed to add bit flip errors of type %d\n", bitflip_type);
            return false;
        }
        return true;
    }

    void hexdump(const otp_zone_raw_buffer_t& data, const char* line_prefix) {
        static const size_t OTP_ROWS_PER_LINE = 4u;
        static_assert(OTP_ZONE_ROWCOUNT % OTP_ROWS_PER_LINE == 0, "OTP_ROWS_PER_LINE must divide OTP_ZONE_ROWCOUNT");
        for (size_t i = 0; i < OTP_ZONE_ROWCOUNT; i += OTP_ROWS_PER_LINE) {
            // NOTE: Not entirely sure if RTT viewers treat each print call as a separate line?
            //       Avoid the question by printing each line in one call.
            char data_chars[8+1] = {
                byte_to_printable_char(data.raw_data[i+0] & 0xFFu), byte_to_printable_char((data.raw_data[i+0] >> 8) & 0xFFu),
                byte_to_printable_char(data.raw_data[i+1] & 0xFFu), byte_to_printable_char((data.raw_data[i+1] >> 8) & 0xFFu),
                byte_to_printable_char(data.raw_data[i+2] & 0xFFu), byte_to_printable_char((data.raw_data[i+2] >> 8) & 0xFFu),
                byte_to_printable_char(data.raw_data[i+3] & 0xFFu), byte_to_printable_char((data.raw_data[i+3] >> 8) & 0xFFu),
                0
            };
            char ecc_chars[4+1] = {
                byte_to_printable_char(data.raw_data[i+0] >> 16),
                byte_to_printable_char(data.raw_data[i+1] >> 16),
                byte_to_printable_char(data.raw_data[i+2] >> 16),
                byte_to_printable_char(data.raw_data[i+3] >> 16),
                0
            };
            PRINT_VERBOSE(
                "%s"
                "0x%03x: "
                "%06x %06x %06x %06x"
                "  //  "
                "%02x %02x [%02x]  %02x %02x [%02x]  %02x %02x [%02x]  %02x %02x [%02x]"
                "  //  "
                "'%s' ['%s']"
                "\n",
                line_prefix ? line_prefix : empty_string,
                i,
                data.raw_data[i+0], data.raw_data[i+1], data.raw_data[i+2], data.raw_data[i+3],
                data.raw_data[i+0] & 0xFFu, (data.raw_data[i+0] >> 8) & 0xFFu, data.raw_data[i+0] >> 16,
                data.raw_data[i+1] & 0xFFu, (data.raw_data[i+1] >> 8) & 0xFFu, data.raw_data[i+1] >> 16,
                data.raw_data[i+2] & 0xFFu, (data.raw_data[i+2] >> 8) & 0xFFu, data.raw_data[i+2] >> 16,
                data.raw_data[i+3] & 0xFFu, (data.raw_data[i+3] >> 8) & 0xFFu, data.raw_data[i+3] >> 16,
                data_chars, ecc_chars
            );
        }
    }
    void dump_c_struct(const otp_zone_raw_buffer_t& data, const char* name) {
        PRINT_VERBOSE("const otp_zone_raw_buffer_t %s = {\n", name);
        for (size_t i = 0; i < OTP_ZONE_ROWCOUNT; ++i) {
            PRINT_VERBOSE(
                "    0x%06x, // %02x %02x [%02x]   '%c%c' [%c]\n",
                data.raw_data[i],
                (data.raw_data[i] >> (8*0)) & 0xFFu,
                (data.raw_data[i] >> (8*1)) & 0xFFu,
                (data.raw_data[i] >> (8*2)) & 0xFFu,
                byte_to_printable_char((data.raw_data[i] >> (8*0)) & 0xFFu),
                byte_to_printable_char((data.raw_data[i] >> (8*1)) & 0xFFu),
                byte_to_printable_char((data.raw_data[i] >> (8*2)) & 0xFFu)
            );
        }
        PRINT_VERBOSE("};\n");
    }

    bool prepare_zone_buffer(const zone_config_t& cfg, otp_zone_raw_buffer_t& out_buffer) {
        if (cfg.base_data_type == otp_zone_data_type_t::raw) {
            return initialize_3way_majority_vote(out_buffer, cfg.bit_flip_type);
        } else if (cfg.base_data_type == otp_zone_data_type_t::ecc) {
            return initialize_ecc_values(out_buffer, false, cfg.bit_flip_type);
        } else if (cfg.base_data_type == otp_zone_data_type_t::brbp_ecc) {
            return initialize_ecc_values(out_buffer, true, cfg.bit_flip_type);
        } else {
            PRINT_FATAL("CODE ERROR: Unhandled base data type %d (%s)\n", cfg.base_data_type, cfg.name);
            return false;
        }
    }
}


namespace zoned_otp { namespace _data {

// plain old data ... no work to generate these ... they go into ROM and use no RAM

const otp_zone_raw_buffer_t raw3x_none = {
    0x000000, // 00 00 [00]   '..' [.]
    0x010101, // 01 01 [01]   '..' [.]
    0x020202, // 02 02 [02]   '..' [.]
    0x030303, // 03 03 [03]   '..' [.]
    0x040404, // 04 04 [04]   '..' [.]
    0x050505, // 05 05 [05]   '..' [.]
    0x060606, // 06 06 [06]   '..' [.]
    0x070707, // 07 07 [07]   '..' [.]
    0x080808, // 08 08 [08]   '..' [.]
    0x090909, // 09 09 [09]   '..' [.]
    0x0A0A0A, // 0A 0A [0A]   '..' [.]
    0x0B0B0B, // 0B 0B [0B]   '..' [.]
    0x0C0C0C, // 0C 0C [0C]   '..' [.]
    0x0D0D0D, // 0D 0D [0D]   '..' [.]
    0x0E0E0E, // 0E 0E [0E]   '..' [.]
    0x0F0F0F, // 0F 0F [0F]   '..' [.]
    0x101010, // 10 10 [10]   '..' [.]
    0x111111, // 11 11 [11]   '..' [.]
    0x121212, // 12 12 [12]   '..' [.]
    0x131313, // 13 13 [13]   '..' [.]
    0x141414, // 14 14 [14]   '..' [.]
    0x151515, // 15 15 [15]   '..' [.]
    0x161616, // 16 16 [16]   '..' [.]
    0x171717, // 17 17 [17]   '..' [.]
    0x181818, // 18 18 [18]   '..' [.]
    0x191919, // 19 19 [19]   '..' [.]
    0x1A1A1A, // 1A 1A [1A]   '..' [.]
    0x1B1B1B, // 1B 1B [1B]   '..' [.]
    0x1C1C1C, // 1C 1C [1C]   '..' [.]
    0x1D1D1D, // 1D 1D [1D]   '..' [.]
    0x1E1E1E, // 1E 1E [1E]   '..' [.]
    0x1F1F1F, // 1F 1F [1F]   '..' [.]
    0x202020, // 20 20 [20]   '  ' [ ]
    0x212121, // 21 21 [21]   '!!' [!]
    0x222222, // 22 22 [22]   '""' ["]
    0x232323, // 23 23 [23]   '##' [#]
    0x242424, // 24 24 [24]   '$$' [$]
    0x252525, // 25 25 [25]   '%%' [%]
    0x262626, // 26 26 [26]   '&&' [&]
    0x272727, // 27 27 [27]   '''' [']
    0x282828, // 28 28 [28]   '((' [(]
    0x292929, // 29 29 [29]   '))' [)]
    0x2A2A2A, // 2A 2A [2A]   '**' [*]
    0x2B2B2B, // 2B 2B [2B]   '++' [+]
    0x2C2C2C, // 2C 2C [2C]   ',,' [,]
    0x2D2D2D, // 2D 2D [2D]   '--' [-]
    0x2E2E2E, // 2E 2E [2E]   '..' [.]
    0x2F2F2F, // 2F 2F [2F]   '//' [/]
    0x303030, // 30 30 [30]   '00' [0]
    0x313131, // 31 31 [31]   '11' [1]
    0x323232, // 32 32 [32]   '22' [2]
    0x333333, // 33 33 [33]   '33' [3]
    0x343434, // 34 34 [34]   '44' [4]
    0x353535, // 35 35 [35]   '55' [5]
    0x363636, // 36 36 [36]   '66' [6]
    0x373737, // 37 37 [37]   '77' [7]
    0x383838, // 38 38 [38]   '88' [8]
    0x393939, // 39 39 [39]   '99' [9]
    0x3A3A3A, // 3A 3A [3A]   '::' [:]
    0x3B3B3B, // 3B 3B [3B]   ';;' [;]
    0x3C3C3C, // 3C 3C [3C]   '<<' [<]
    0x3D3D3D, // 3D 3D [3D]   '==' [=]
    0x3E3E3E, // 3E 3E [3E]   '>>' [>]
    0x3F3F3F, // 3F 3F [3F]   '??' [?]
    0x404040, // 40 40 [40]   '@@' [@]
    0x414141, // 41 41 [41]   'AA' [A]
    0x424242, // 42 42 [42]   'BB' [B]
    0x434343, // 43 43 [43]   'CC' [C]
    0x444444, // 44 44 [44]   'DD' [D]
    0x454545, // 45 45 [45]   'EE' [E]
    0x464646, // 46 46 [46]   'FF' [F]
    0x474747, // 47 47 [47]   'GG' [G]
    0x484848, // 48 48 [48]   'HH' [H]
    0x494949, // 49 49 [49]   'II' [I]
    0x4A4A4A, // 4A 4A [4A]   'JJ' [J]
    0x4B4B4B, // 4B 4B [4B]   'KK' [K]
    0x4C4C4C, // 4C 4C [4C]   'LL' [L]
    0x4D4D4D, // 4D 4D [4D]   'MM' [M]
    0x4E4E4E, // 4E 4E [4E]   'NN' [N]
    0x4F4F4F, // 4F 4F [4F]   'OO' [O]
    0x505050, // 50 50 [50]   'PP' [P]
    0x515151, // 51 51 [51]   'QQ' [Q]
    0x525252, // 52 52 [52]   'RR' [R]
    0x535353, // 53 53 [53]   'SS' [S]
    0x545454, // 54 54 [54]   'TT' [T]
    0x555555, // 55 55 [55]   'UU' [U]
    0x565656, // 56 56 [56]   'VV' [V]
    0x575757, // 57 57 [57]   'WW' [W]
    0x585858, // 58 58 [58]   'XX' [X]
    0x595959, // 59 59 [59]   'YY' [Y]
    0x5A5A5A, // 5A 5A [5A]   'ZZ' [Z]
    0x5B5B5B, // 5B 5B [5B]   '[[' [[]
    0x5C5C5C, // 5C 5C [5C]   '\\' [\]
    0x5D5D5D, // 5D 5D [5D]   ']]' []]
    0x5E5E5E, // 5E 5E [5E]   '^^' [^]
    0x5F5F5F, // 5F 5F [5F]   '__' [_]
    0x606060, // 60 60 [60]   '``' [`]
    0x616161, // 61 61 [61]   'aa' [a]
    0x626262, // 62 62 [62]   'bb' [b]
    0x636363, // 63 63 [63]   'cc' [c]
    0x646464, // 64 64 [64]   'dd' [d]
    0x656565, // 65 65 [65]   'ee' [e]
    0x666666, // 66 66 [66]   'ff' [f]
    0x676767, // 67 67 [67]   'gg' [g]
    0x686868, // 68 68 [68]   'hh' [h]
    0x696969, // 69 69 [69]   'ii' [i]
    0x6A6A6A, // 6A 6A [6A]   'jj' [j]
    0x6B6B6B, // 6B 6B [6B]   'kk' [k]
    0x6C6C6C, // 6C 6C [6C]   'll' [l]
    0x6D6D6D, // 6D 6D [6D]   'mm' [m]
    0x6E6E6E, // 6E 6E [6E]   'nn' [n]
    0x6F6F6F, // 6F 6F [6F]   'oo' [o]
    0x707070, // 70 70 [70]   'pp' [p]
    0x717171, // 71 71 [71]   'qq' [q]
    0x727272, // 72 72 [72]   'rr' [r]
    0x737373, // 73 73 [73]   'ss' [s]
    0x747474, // 74 74 [74]   'tt' [t]
    0x757575, // 75 75 [75]   'uu' [u]
    0x767676, // 76 76 [76]   'vv' [v]
    0x777777, // 77 77 [77]   'ww' [w]
    0x787878, // 78 78 [78]   'xx' [x]
    0x797979, // 79 79 [79]   'yy' [y]
    0x7A7A7A, // 7A 7A [7A]   'zz' [z]
    0x7B7B7B, // 7B 7B [7B]   '{{' [{]
    0x7C7C7C, // 7C 7C [7C]   '||' [|]
    0x7D7D7D, // 7D 7D [7D]   '}}' [}]
    0x7E7E7E, // 7E 7E [7E]   '~~' [~]
    0x7F7F7F, // 7F 7F [7F]   '..' [.]
    0x808080, // 80 80 [80]   '..' [.]
    0x818181, // 81 81 [81]   '..' [.]
    0x828282, // 82 82 [82]   '..' [.]
    0x838383, // 83 83 [83]   '..' [.]
    0x848484, // 84 84 [84]   '..' [.]
    0x858585, // 85 85 [85]   '..' [.]
    0x868686, // 86 86 [86]   '..' [.]
    0x878787, // 87 87 [87]   '..' [.]
    0x888888, // 88 88 [88]   '..' [.]
    0x898989, // 89 89 [89]   '..' [.]
    0x8A8A8A, // 8A 8A [8A]   '..' [.]
    0x8B8B8B, // 8B 8B [8B]   '..' [.]
    0x8C8C8C, // 8C 8C [8C]   '..' [.]
    0x8D8D8D, // 8D 8D [8D]   '..' [.]
    0x8E8E8E, // 8E 8E [8E]   '..' [.]
    0x8F8F8F, // 8F 8F [8F]   '..' [.]
    0x909090, // 90 90 [90]   '..' [.]
    0x919191, // 91 91 [91]   '..' [.]
    0x929292, // 92 92 [92]   '..' [.]
    0x939393, // 93 93 [93]   '..' [.]
    0x949494, // 94 94 [94]   '..' [.]
    0x959595, // 95 95 [95]   '..' [.]
    0x969696, // 96 96 [96]   '..' [.]
    0x979797, // 97 97 [97]   '..' [.]
    0x989898, // 98 98 [98]   '..' [.]
    0x999999, // 99 99 [99]   '..' [.]
    0x9A9A9A, // 9A 9A [9A]   '..' [.]
    0x9B9B9B, // 9B 9B [9B]   '..' [.]
    0x9C9C9C, // 9C 9C [9C]   '..' [.]
    0x9D9D9D, // 9D 9D [9D]   '..' [.]
    0x9E9E9E, // 9E 9E [9E]   '..' [.]
    0x9F9F9F, // 9F 9F [9F]   '..' [.]
    0xA0A0A0, // A0 A0 [A0]   '..' [.]
    0xA1A1A1, // A1 A1 [A1]   '..' [.]
    0xA2A2A2, // A2 A2 [A2]   '..' [.]
    0xA3A3A3, // A3 A3 [A3]   '..' [.]
    0xA4A4A4, // A4 A4 [A4]   '..' [.]
    0xA5A5A5, // A5 A5 [A5]   '..' [.]
    0xA6A6A6, // A6 A6 [A6]   '..' [.]
    0xA7A7A7, // A7 A7 [A7]   '..' [.]
    0xA8A8A8, // A8 A8 [A8]   '..' [.]
    0xA9A9A9, // A9 A9 [A9]   '..' [.]
    0xAAAAAA, // AA AA [AA]   '..' [.]
    0xABABAB, // AB AB [AB]   '..' [.]
    0xACACAC, // AC AC [AC]   '..' [.]
    0xADADAD, // AD AD [AD]   '..' [.]
    0xAEAEAE, // AE AE [AE]   '..' [.]
    0xAFAFAF, // AF AF [AF]   '..' [.]
    0xB0B0B0, // B0 B0 [B0]   '..' [.]
    0xB1B1B1, // B1 B1 [B1]   '..' [.]
    0xB2B2B2, // B2 B2 [B2]   '..' [.]
    0xB3B3B3, // B3 B3 [B3]   '..' [.]
    0xB4B4B4, // B4 B4 [B4]   '..' [.]
    0xB5B5B5, // B5 B5 [B5]   '..' [.]
    0xB6B6B6, // B6 B6 [B6]   '..' [.]
    0xB7B7B7, // B7 B7 [B7]   '..' [.]
    0xB8B8B8, // B8 B8 [B8]   '..' [.]
    0xB9B9B9, // B9 B9 [B9]   '..' [.]
    0xBABABA, // BA BA [BA]   '..' [.]
    0xBBBBBB, // BB BB [BB]   '..' [.]
    0xBCBCBC, // BC BC [BC]   '..' [.]
    0xBDBDBD, // BD BD [BD]   '..' [.]
    0xBEBEBE, // BE BE [BE]   '..' [.]
    0xBFBFBF, // BF BF [BF]   '..' [.]
    0xC0C0C0, // C0 C0 [C0]   '..' [.]
    0xC1C1C1, // C1 C1 [C1]   '..' [.]
    0xC2C2C2, // C2 C2 [C2]   '..' [.]
    0xC3C3C3, // C3 C3 [C3]   '..' [.]
    0xC4C4C4, // C4 C4 [C4]   '..' [.]
    0xC5C5C5, // C5 C5 [C5]   '..' [.]
    0xC6C6C6, // C6 C6 [C6]   '..' [.]
    0xC7C7C7, // C7 C7 [C7]   '..' [.]
    0xC8C8C8, // C8 C8 [C8]   '..' [.]
    0xC9C9C9, // C9 C9 [C9]   '..' [.]
    0xCACACA, // CA CA [CA]   '..' [.]
    0xCBCBCB, // CB CB [CB]   '..' [.]
    0xCCCCCC, // CC CC [CC]   '..' [.]
    0xCDCDCD, // CD CD [CD]   '..' [.]
    0xCECECE, // CE CE [CE]   '..' [.]
    0xCFCFCF, // CF CF [CF]   '..' [.]
    0xD0D0D0, // D0 D0 [D0]   '..' [.]
    0xD1D1D1, // D1 D1 [D1]   '..' [.]
    0xD2D2D2, // D2 D2 [D2]   '..' [.]
    0xD3D3D3, // D3 D3 [D3]   '..' [.]
    0xD4D4D4, // D4 D4 [D4]   '..' [.]
    0xD5D5D5, // D5 D5 [D5]   '..' [.]
    0xD6D6D6, // D6 D6 [D6]   '..' [.]
    0xD7D7D7, // D7 D7 [D7]   '..' [.]
    0xD8D8D8, // D8 D8 [D8]   '..' [.]
    0xD9D9D9, // D9 D9 [D9]   '..' [.]
    0xDADADA, // DA DA [DA]   '..' [.]
    0xDBDBDB, // DB DB [DB]   '..' [.]
    0xDCDCDC, // DC DC [DC]   '..' [.]
    0xDDDDDD, // DD DD [DD]   '..' [.]
    0xDEDEDE, // DE DE [DE]   '..' [.]
    0xDFDFDF, // DF DF [DF]   '..' [.]
    0xE0E0E0, // E0 E0 [E0]   '..' [.]
    0xE1E1E1, // E1 E1 [E1]   '..' [.]
    0xE2E2E2, // E2 E2 [E2]   '..' [.]
    0xE3E3E3, // E3 E3 [E3]   '..' [.]
    0xE4E4E4, // E4 E4 [E4]   '..' [.]
    0xE5E5E5, // E5 E5 [E5]   '..' [.]
    0xE6E6E6, // E6 E6 [E6]   '..' [.]
    0xE7E7E7, // E7 E7 [E7]   '..' [.]
    0xE8E8E8, // E8 E8 [E8]   '..' [.]
    0xE9E9E9, // E9 E9 [E9]   '..' [.]
    0xEAEAEA, // EA EA [EA]   '..' [.]
    0xEBEBEB, // EB EB [EB]   '..' [.]
    0xECECEC, // EC EC [EC]   '..' [.]
    0xEDEDED, // ED ED [ED]   '..' [.]
    0xEEEEEE, // EE EE [EE]   '..' [.]
    0xEFEFEF, // EF EF [EF]   '..' [.]
    0xF0F0F0, // F0 F0 [F0]   '..' [.]
    0xF1F1F1, // F1 F1 [F1]   '..' [.]
    0xF2F2F2, // F2 F2 [F2]   '..' [.]
    0xF3F3F3, // F3 F3 [F3]   '..' [.]
    0xF4F4F4, // F4 F4 [F4]   '..' [.]
    0xF5F5F5, // F5 F5 [F5]   '..' [.]
    0xF6F6F6, // F6 F6 [F6]   '..' [.]
    0xF7F7F7, // F7 F7 [F7]   '..' [.]
    0xF8F8F8, // F8 F8 [F8]   '..' [.]
    0xF9F9F9, // F9 F9 [F9]   '..' [.]
    0xFAFAFA, // FA FA [FA]   '..' [.]
    0xFBFBFB, // FB FB [FB]   '..' [.]
    0xFCFCFC, // FC FC [FC]   '..' [.]
    0xFDFDFD, // FD FD [FD]   '..' [.]
    0xFEFEFE, // FE FE [FE]   '..' [.]
    0xFFFFFF, // FF FF [FF]   '..' [.]
};
const otp_zone_raw_buffer_t raw3x_0_to_1 = {
    0x000001, // 01 00 [00]   '..' [.]
    0x010103, // 03 01 [01]   '..' [.]
    0x020206, // 06 02 [02]   '..' [.]
    0x03030B, // 0B 03 [03]   '..' [.]
    0x040414, // 14 04 [04]   '..' [.]
    0x050525, // 25 05 [05]   '%.' [.]
    0x060646, // 46 06 [06]   'F.' [.]
    0x070787, // 87 07 [07]   '..' [.]
    0x080908, // 08 09 [08]   '..' [.]
    0x090B09, // 09 0B [09]   '..' [.]
    0x0A0E0A, // 0A 0E [0A]   '..' [.]
    0x0B1B0B, // 0B 1B [0B]   '..' [.]
    0x0C2C0C, // 0C 2C [0C]   '.,' [.]
    0x0D4D0D, // 0D 4D [0D]   '.M' [.]
    0x0E8E0E, // 0E 8E [0E]   '..' [.]
    0x0E0F0F, // 0F 0F [0E]   '..' [.]
    0x101810, // 10 18 [10]   '..' [.]
    0x101111, // 11 11 [10]   '..' [.]
    0x131212, // 12 12 [13]   '..' [.]
    0x121313, // 13 13 [12]   '..' [.]
    0x151414, // 14 14 [15]   '..' [.]
    0x141515, // 15 15 [14]   '..' [.]
    0x171616, // 16 16 [17]   '..' [.]
    0x161717, // 17 17 [16]   '..' [.]
    0x191818, // 18 18 [19]   '..' [.]
    0x181919, // 19 19 [18]   '..' [.]
    0x1B1A1A, // 1A 1A [1B]   '..' [.]
    0x1A1B1B, // 1B 1B [1A]   '..' [.]
    0x1D1C1C, // 1C 1C [1D]   '..' [.]
    0x1C1D1D, // 1D 1D [1C]   '..' [.]
    0x1F1E1E, // 1E 1E [1F]   '..' [.]
    0x1E1F1F, // 1F 1F [1E]   '..' [.]
    0x212020, // 20 20 [21]   '  ' [!]
    0x202121, // 21 21 [20]   '!!' [ ]
    0x232222, // 22 22 [23]   '""' [#]
    0x222323, // 23 23 [22]   '##' ["]
    0x252424, // 24 24 [25]   '$$' [%]
    0x242525, // 25 25 [24]   '%%' [$]
    0x272626, // 26 26 [27]   '&&' [']
    0x262727, // 27 27 [26]   '''' [&]
    0x292828, // 28 28 [29]   '((' [)]
    0x282929, // 29 29 [28]   '))' [(]
    0x2B2A2A, // 2A 2A [2B]   '**' [+]
    0x2A2B2B, // 2B 2B [2A]   '++' [*]
    0x2D2C2C, // 2C 2C [2D]   ',,' [-]
    0x2C2D2D, // 2D 2D [2C]   '--' [,]
    0x2F2E2E, // 2E 2E [2F]   '..' [/]
    0x2E2F2F, // 2F 2F [2E]   '//' [.]
    0x313030, // 30 30 [31]   '00' [1]
    0x303131, // 31 31 [30]   '11' [0]
    0x333232, // 32 32 [33]   '22' [3]
    0x323333, // 33 33 [32]   '33' [2]
    0x353434, // 34 34 [35]   '44' [5]
    0x343535, // 35 35 [34]   '55' [4]
    0x373636, // 36 36 [37]   '66' [7]
    0x363737, // 37 37 [36]   '77' [6]
    0x393838, // 38 38 [39]   '88' [9]
    0x383939, // 39 39 [38]   '99' [8]
    0x3B3A3A, // 3A 3A [3B]   '::' [;]
    0x3A3B3B, // 3B 3B [3A]   ';;' [:]
    0x3D3C3C, // 3C 3C [3D]   '<<' [=]
    0x3C3D3D, // 3D 3D [3C]   '==' [<]
    0x3F3E3E, // 3E 3E [3F]   '>>' [?]
    0x3E3F3F, // 3F 3F [3E]   '??' [>]
    0x414040, // 40 40 [41]   '@@' [A]
    0x404141, // 41 41 [40]   'AA' [@]
    0x434242, // 42 42 [43]   'BB' [C]
    0x424343, // 43 43 [42]   'CC' [B]
    0x454444, // 44 44 [45]   'DD' [E]
    0x444545, // 45 45 [44]   'EE' [D]
    0x474646, // 46 46 [47]   'FF' [G]
    0x464747, // 47 47 [46]   'GG' [F]
    0x494848, // 48 48 [49]   'HH' [I]
    0x484949, // 49 49 [48]   'II' [H]
    0x4B4A4A, // 4A 4A [4B]   'JJ' [K]
    0x4A4B4B, // 4B 4B [4A]   'KK' [J]
    0x4D4C4C, // 4C 4C [4D]   'LL' [M]
    0x4C4D4D, // 4D 4D [4C]   'MM' [L]
    0x4F4E4E, // 4E 4E [4F]   'NN' [O]
    0x4E4F4F, // 4F 4F [4E]   'OO' [N]
    0x515050, // 50 50 [51]   'PP' [Q]
    0x505151, // 51 51 [50]   'QQ' [P]
    0x535252, // 52 52 [53]   'RR' [S]
    0x525353, // 53 53 [52]   'SS' [R]
    0x555454, // 54 54 [55]   'TT' [U]
    0x545555, // 55 55 [54]   'UU' [T]
    0x575656, // 56 56 [57]   'VV' [W]
    0x565757, // 57 57 [56]   'WW' [V]
    0x595858, // 58 58 [59]   'XX' [Y]
    0x585959, // 59 59 [58]   'YY' [X]
    0x5B5A5A, // 5A 5A [5B]   'ZZ' [[]
    0x5A5B5B, // 5B 5B [5A]   '[[' [Z]
    0x5D5C5C, // 5C 5C [5D]   '\\' []]
    0x5C5D5D, // 5D 5D [5C]   ']]' [\]
    0x5F5E5E, // 5E 5E [5F]   '^^' [_]
    0x5E5F5F, // 5F 5F [5E]   '__' [^]
    0x616060, // 60 60 [61]   '``' [a]
    0x606161, // 61 61 [60]   'aa' [`]
    0x636262, // 62 62 [63]   'bb' [c]
    0x626363, // 63 63 [62]   'cc' [b]
    0x656464, // 64 64 [65]   'dd' [e]
    0x646565, // 65 65 [64]   'ee' [d]
    0x676666, // 66 66 [67]   'ff' [g]
    0x666767, // 67 67 [66]   'gg' [f]
    0x696868, // 68 68 [69]   'hh' [i]
    0x686969, // 69 69 [68]   'ii' [h]
    0x6B6A6A, // 6A 6A [6B]   'jj' [k]
    0x6A6B6B, // 6B 6B [6A]   'kk' [j]
    0x6D6C6C, // 6C 6C [6D]   'll' [m]
    0x6C6D6D, // 6D 6D [6C]   'mm' [l]
    0x6F6E6E, // 6E 6E [6F]   'nn' [o]
    0x6E6F6F, // 6F 6F [6E]   'oo' [n]
    0x717070, // 70 70 [71]   'pp' [q]
    0x707171, // 71 71 [70]   'qq' [p]
    0x737272, // 72 72 [73]   'rr' [s]
    0x727373, // 73 73 [72]   'ss' [r]
    0x757474, // 74 74 [75]   'tt' [u]
    0x747575, // 75 75 [74]   'uu' [t]
    0x777676, // 76 76 [77]   'vv' [w]
    0x767777, // 77 77 [76]   'ww' [v]
    0x797878, // 78 78 [79]   'xx' [y]
    0x787979, // 79 79 [78]   'yy' [x]
    0x7B7A7A, // 7A 7A [7B]   'zz' [{]
    0x7A7B7B, // 7B 7B [7A]   '{{' [z]
    0x7D7C7C, // 7C 7C [7D]   '||' [}]
    0x7C7D7D, // 7D 7D [7C]   '}}' [|]
    0x7F7E7E, // 7E 7E [7F]   '~~' [.]
    0x7E7F7F, // 7F 7F [7E]   '..' [~]
    0x818080, // 80 80 [81]   '..' [.]
    0x808181, // 81 81 [80]   '..' [.]
    0x838282, // 82 82 [83]   '..' [.]
    0x828383, // 83 83 [82]   '..' [.]
    0x858484, // 84 84 [85]   '..' [.]
    0x848585, // 85 85 [84]   '..' [.]
    0x878686, // 86 86 [87]   '..' [.]
    0x868787, // 87 87 [86]   '..' [.]
    0x898888, // 88 88 [89]   '..' [.]
    0x888989, // 89 89 [88]   '..' [.]
    0x8B8A8A, // 8A 8A [8B]   '..' [.]
    0x8A8B8B, // 8B 8B [8A]   '..' [.]
    0x8D8C8C, // 8C 8C [8D]   '..' [.]
    0x8C8D8D, // 8D 8D [8C]   '..' [.]
    0x8F8E8E, // 8E 8E [8F]   '..' [.]
    0x8E8F8F, // 8F 8F [8E]   '..' [.]
    0x919090, // 90 90 [91]   '..' [.]
    0x909191, // 91 91 [90]   '..' [.]
    0x939292, // 92 92 [93]   '..' [.]
    0x929393, // 93 93 [92]   '..' [.]
    0x959494, // 94 94 [95]   '..' [.]
    0x949595, // 95 95 [94]   '..' [.]
    0x979696, // 96 96 [97]   '..' [.]
    0x969797, // 97 97 [96]   '..' [.]
    0x999898, // 98 98 [99]   '..' [.]
    0x989999, // 99 99 [98]   '..' [.]
    0x9B9A9A, // 9A 9A [9B]   '..' [.]
    0x9A9B9B, // 9B 9B [9A]   '..' [.]
    0x9D9C9C, // 9C 9C [9D]   '..' [.]
    0x9C9D9D, // 9D 9D [9C]   '..' [.]
    0x9F9E9E, // 9E 9E [9F]   '..' [.]
    0x9E9F9F, // 9F 9F [9E]   '..' [.]
    0xA1A0A0, // A0 A0 [A1]   '..' [.]
    0xA0A1A1, // A1 A1 [A0]   '..' [.]
    0xA3A2A2, // A2 A2 [A3]   '..' [.]
    0xA2A3A3, // A3 A3 [A2]   '..' [.]
    0xA5A4A4, // A4 A4 [A5]   '..' [.]
    0xA4A5A5, // A5 A5 [A4]   '..' [.]
    0xA7A6A6, // A6 A6 [A7]   '..' [.]
    0xA6A7A7, // A7 A7 [A6]   '..' [.]
    0xA9A8A8, // A8 A8 [A9]   '..' [.]
    0xA8A9A9, // A9 A9 [A8]   '..' [.]
    0xABAAAA, // AA AA [AB]   '..' [.]
    0xAAABAB, // AB AB [AA]   '..' [.]
    0xADACAC, // AC AC [AD]   '..' [.]
    0xACADAD, // AD AD [AC]   '..' [.]
    0xAFAEAE, // AE AE [AF]   '..' [.]
    0xAEAFAF, // AF AF [AE]   '..' [.]
    0xB1B0B0, // B0 B0 [B1]   '..' [.]
    0xB0B1B1, // B1 B1 [B0]   '..' [.]
    0xB3B2B2, // B2 B2 [B3]   '..' [.]
    0xB2B3B3, // B3 B3 [B2]   '..' [.]
    0xB5B4B4, // B4 B4 [B5]   '..' [.]
    0xB4B5B5, // B5 B5 [B4]   '..' [.]
    0xB7B6B6, // B6 B6 [B7]   '..' [.]
    0xB6B7B7, // B7 B7 [B6]   '..' [.]
    0xB9B8B8, // B8 B8 [B9]   '..' [.]
    0xB8B9B9, // B9 B9 [B8]   '..' [.]
    0xBBBABA, // BA BA [BB]   '..' [.]
    0xBABBBB, // BB BB [BA]   '..' [.]
    0xBDBCBC, // BC BC [BD]   '..' [.]
    0xBCBDBD, // BD BD [BC]   '..' [.]
    0xBFBEBE, // BE BE [BF]   '..' [.]
    0xBEBFBF, // BF BF [BE]   '..' [.]
    0xC1C0C0, // C0 C0 [C1]   '..' [.]
    0xC0C1C1, // C1 C1 [C0]   '..' [.]
    0xC3C2C2, // C2 C2 [C3]   '..' [.]
    0xC2C3C3, // C3 C3 [C2]   '..' [.]
    0xC5C4C4, // C4 C4 [C5]   '..' [.]
    0xC4C5C5, // C5 C5 [C4]   '..' [.]
    0xC7C6C6, // C6 C6 [C7]   '..' [.]
    0xC6C7C7, // C7 C7 [C6]   '..' [.]
    0xC9C8C8, // C8 C8 [C9]   '..' [.]
    0xC8C9C9, // C9 C9 [C8]   '..' [.]
    0xCBCACA, // CA CA [CB]   '..' [.]
    0xCACBCB, // CB CB [CA]   '..' [.]
    0xCDCCCC, // CC CC [CD]   '..' [.]
    0xCCCDCD, // CD CD [CC]   '..' [.]
    0xCFCECE, // CE CE [CF]   '..' [.]
    0xCECFCF, // CF CF [CE]   '..' [.]
    0xD1D0D0, // D0 D0 [D1]   '..' [.]
    0xD0D1D1, // D1 D1 [D0]   '..' [.]
    0xD3D2D2, // D2 D2 [D3]   '..' [.]
    0xD2D3D3, // D3 D3 [D2]   '..' [.]
    0xD5D4D4, // D4 D4 [D5]   '..' [.]
    0xD4D5D5, // D5 D5 [D4]   '..' [.]
    0xD7D6D6, // D6 D6 [D7]   '..' [.]
    0xD6D7D7, // D7 D7 [D6]   '..' [.]
    0xD9D8D8, // D8 D8 [D9]   '..' [.]
    0xD8D9D9, // D9 D9 [D8]   '..' [.]
    0xDBDADA, // DA DA [DB]   '..' [.]
    0xDADBDB, // DB DB [DA]   '..' [.]
    0xDDDCDC, // DC DC [DD]   '..' [.]
    0xDCDDDD, // DD DD [DC]   '..' [.]
    0xDFDEDE, // DE DE [DF]   '..' [.]
    0xDEDFDF, // DF DF [DE]   '..' [.]
    0xE1E0E0, // E0 E0 [E1]   '..' [.]
    0xE0E1E1, // E1 E1 [E0]   '..' [.]
    0xE3E2E2, // E2 E2 [E3]   '..' [.]
    0xE2E3E3, // E3 E3 [E2]   '..' [.]
    0xE5E4E4, // E4 E4 [E5]   '..' [.]
    0xE4E5E5, // E5 E5 [E4]   '..' [.]
    0xE7E6E6, // E6 E6 [E7]   '..' [.]
    0xE6E7E7, // E7 E7 [E6]   '..' [.]
    0xE9E8E8, // E8 E8 [E9]   '..' [.]
    0xE8E9E9, // E9 E9 [E8]   '..' [.]
    0xEBEAEA, // EA EA [EB]   '..' [.]
    0xEAEBEB, // EB EB [EA]   '..' [.]
    0xEDECEC, // EC EC [ED]   '..' [.]
    0xECEDED, // ED ED [EC]   '..' [.]
    0xEFEEEE, // EE EE [EF]   '..' [.]
    0xEEEFEF, // EF EF [EE]   '..' [.]
    0xF1F0F0, // F0 F0 [F1]   '..' [.]
    0xF0F1F1, // F1 F1 [F0]   '..' [.]
    0xF3F2F2, // F2 F2 [F3]   '..' [.]
    0xF2F3F3, // F3 F3 [F2]   '..' [.]
    0xF5F4F4, // F4 F4 [F5]   '..' [.]
    0xF4F5F5, // F5 F5 [F4]   '..' [.]
    0xF7F6F6, // F6 F6 [F7]   '..' [.]
    0xF6F7F7, // F7 F7 [F6]   '..' [.]
    0xF9F8F8, // F8 F8 [F9]   '..' [.]
    0xF8F9F9, // F9 F9 [F8]   '..' [.]
    0xFBFAFA, // FA FA [FB]   '..' [.]
    0xFAFBFB, // FB FB [FA]   '..' [.]
    0xFDFCFC, // FC FC [FD]   '..' [.]
    0xFCFDFD, // FD FD [FC]   '..' [.]
    0xFFFEFE, // FE FE [FF]   '..' [.]
    0xFFFFFF, // FF FF [FF]   '..' [.]
};
const otp_zone_raw_buffer_t raw3x_1_to_0 = {
    0x000000, // 00 00 [00]   '..' [.]
    0x010100, // 00 01 [01]   '..' [.]
    0x020200, // 00 02 [02]   '..' [.]
    0x030203, // 03 02 [03]   '..' [.]
    0x040400, // 00 04 [04]   '..' [.]
    0x050105, // 05 01 [05]   '..' [.]
    0x060406, // 06 04 [06]   '..' [.]
    0x070706, // 06 07 [07]   '..' [.]
    0x080800, // 00 08 [08]   '..' [.]
    0x090109, // 09 01 [09]   '..' [.]
    0x0A0A08, // 08 0A [0A]   '..' [.]
    0x0B0B0A, // 0A 0B [0B]   '..' [.]
    0x0C0C08, // 08 0C [0C]   '..' [.]
    0x0D0D0C, // 0C 0D [0D]   '..' [.]
    0x0E0E0C, // 0C 0E [0E]   '..' [.]
    0x0F0F0E, // 0E 0F [0F]   '..' [.]
    0x101000, // 00 10 [10]   '..' [.]
    0x110111, // 11 01 [11]   '..' [.]
    0x121210, // 10 12 [12]   '..' [.]
    0x131312, // 12 13 [13]   '..' [.]
    0x141410, // 10 14 [14]   '..' [.]
    0x151514, // 14 15 [15]   '..' [.]
    0x161614, // 14 16 [16]   '..' [.]
    0x171716, // 16 17 [17]   '..' [.]
    0x181810, // 10 18 [18]   '..' [.]
    0x191918, // 18 19 [19]   '..' [.]
    0x1A1A18, // 18 1A [1A]   '..' [.]
    0x1B1B1A, // 1A 1B [1B]   '..' [.]
    0x1C1C18, // 18 1C [1C]   '..' [.]
    0x1D1D1C, // 1C 1D [1D]   '..' [.]
    0x1E1E1C, // 1C 1E [1E]   '..' [.]
    0x1F1F1E, // 1E 1F [1F]   '..' [.]
    0x202000, // 00 20 [20]   '. ' [ ]
    0x210121, // 21 01 [21]   '!.' [!]
    0x222220, // 20 22 [22]   ' "' ["]
    0x232322, // 22 23 [23]   '"#' [#]
    0x242420, // 20 24 [24]   ' $' [$]
    0x252524, // 24 25 [25]   '$%' [%]
    0x262624, // 24 26 [26]   '$&' [&]
    0x272726, // 26 27 [27]   '&'' [']
    0x282820, // 20 28 [28]   ' (' [(]
    0x292928, // 28 29 [29]   '()' [)]
    0x2A2A28, // 28 2A [2A]   '(*' [*]
    0x2B2B2A, // 2A 2B [2B]   '*+' [+]
    0x2C2C28, // 28 2C [2C]   '(,' [,]
    0x2D2D2C, // 2C 2D [2D]   ',-' [-]
    0x2E2E2C, // 2C 2E [2E]   ',.' [.]
    0x2F2F2E, // 2E 2F [2F]   './' [/]
    0x303020, // 20 30 [30]   ' 0' [0]
    0x313130, // 30 31 [31]   '01' [1]
    0x323230, // 30 32 [32]   '02' [2]
    0x333332, // 32 33 [33]   '23' [3]
    0x343430, // 30 34 [34]   '04' [4]
    0x353534, // 34 35 [35]   '45' [5]
    0x363634, // 34 36 [36]   '46' [6]
    0x373736, // 36 37 [37]   '67' [7]
    0x383830, // 30 38 [38]   '08' [8]
    0x393938, // 38 39 [39]   '89' [9]
    0x3A3A38, // 38 3A [3A]   '8:' [:]
    0x3B3B3A, // 3A 3B [3B]   ':;' [;]
    0x3C3C38, // 38 3C [3C]   '8<' [<]
    0x3D3D3C, // 3C 3D [3D]   '<=' [=]
    0x3E3E3C, // 3C 3E [3E]   '<>' [>]
    0x3F3F3E, // 3E 3F [3F]   '>?' [?]
    0x404000, // 00 40 [40]   '.@' [@]
    0x410141, // 41 01 [41]   'A.' [A]
    0x424240, // 40 42 [42]   '@B' [B]
    0x434342, // 42 43 [43]   'BC' [C]
    0x444440, // 40 44 [44]   '@D' [D]
    0x454544, // 44 45 [45]   'DE' [E]
    0x464644, // 44 46 [46]   'DF' [F]
    0x474746, // 46 47 [47]   'FG' [G]
    0x484840, // 40 48 [48]   '@H' [H]
    0x494948, // 48 49 [49]   'HI' [I]
    0x4A4A48, // 48 4A [4A]   'HJ' [J]
    0x4B4B4A, // 4A 4B [4B]   'JK' [K]
    0x4C4C48, // 48 4C [4C]   'HL' [L]
    0x4D4D4C, // 4C 4D [4D]   'LM' [M]
    0x4E4E4C, // 4C 4E [4E]   'LN' [N]
    0x4F4F4E, // 4E 4F [4F]   'NO' [O]
    0x505040, // 40 50 [50]   '@P' [P]
    0x515150, // 50 51 [51]   'PQ' [Q]
    0x525250, // 50 52 [52]   'PR' [R]
    0x535352, // 52 53 [53]   'RS' [S]
    0x545450, // 50 54 [54]   'PT' [T]
    0x555554, // 54 55 [55]   'TU' [U]
    0x565654, // 54 56 [56]   'TV' [V]
    0x575756, // 56 57 [57]   'VW' [W]
    0x585850, // 50 58 [58]   'PX' [X]
    0x595958, // 58 59 [59]   'XY' [Y]
    0x5A5A58, // 58 5A [5A]   'XZ' [Z]
    0x5B5B5A, // 5A 5B [5B]   'Z[' [[]
    0x5C5C58, // 58 5C [5C]   'X\' [\]
    0x5D5D5C, // 5C 5D [5D]   '\]' []]
    0x5E5E5C, // 5C 5E [5E]   '\^' [^]
    0x5F5F5E, // 5E 5F [5F]   '^_' [_]
    0x606040, // 40 60 [60]   '@`' [`]
    0x616160, // 60 61 [61]   '`a' [a]
    0x626260, // 60 62 [62]   '`b' [b]
    0x636362, // 62 63 [63]   'bc' [c]
    0x646460, // 60 64 [64]   '`d' [d]
    0x656564, // 64 65 [65]   'de' [e]
    0x666664, // 64 66 [66]   'df' [f]
    0x676766, // 66 67 [67]   'fg' [g]
    0x686860, // 60 68 [68]   '`h' [h]
    0x696968, // 68 69 [69]   'hi' [i]
    0x6A6A68, // 68 6A [6A]   'hj' [j]
    0x6B6B6A, // 6A 6B [6B]   'jk' [k]
    0x6C6C68, // 68 6C [6C]   'hl' [l]
    0x6D6D6C, // 6C 6D [6D]   'lm' [m]
    0x6E6E6C, // 6C 6E [6E]   'ln' [n]
    0x6F6F6E, // 6E 6F [6F]   'no' [o]
    0x707060, // 60 70 [70]   '`p' [p]
    0x717170, // 70 71 [71]   'pq' [q]
    0x727270, // 70 72 [72]   'pr' [r]
    0x737372, // 72 73 [73]   'rs' [s]
    0x747470, // 70 74 [74]   'pt' [t]
    0x757574, // 74 75 [75]   'tu' [u]
    0x767674, // 74 76 [76]   'tv' [v]
    0x777776, // 76 77 [77]   'vw' [w]
    0x787870, // 70 78 [78]   'px' [x]
    0x797978, // 78 79 [79]   'xy' [y]
    0x7A7A78, // 78 7A [7A]   'xz' [z]
    0x7B7B7A, // 7A 7B [7B]   'z{' [{]
    0x7C7C78, // 78 7C [7C]   'x|' [|]
    0x7D7D7C, // 7C 7D [7D]   '|}' [}]
    0x7E7E7C, // 7C 7E [7E]   '|~' [~]
    0x7F7F7E, // 7E 7F [7F]   '~.' [.]
    0x808000, // 00 80 [80]   '..' [.]
    0x810181, // 81 01 [81]   '..' [.]
    0x828280, // 80 82 [82]   '..' [.]
    0x838382, // 82 83 [83]   '..' [.]
    0x848480, // 80 84 [84]   '..' [.]
    0x858584, // 84 85 [85]   '..' [.]
    0x868684, // 84 86 [86]   '..' [.]
    0x878786, // 86 87 [87]   '..' [.]
    0x888880, // 80 88 [88]   '..' [.]
    0x898988, // 88 89 [89]   '..' [.]
    0x8A8A88, // 88 8A [8A]   '..' [.]
    0x8B8B8A, // 8A 8B [8B]   '..' [.]
    0x8C8C88, // 88 8C [8C]   '..' [.]
    0x8D8D8C, // 8C 8D [8D]   '..' [.]
    0x8E8E8C, // 8C 8E [8E]   '..' [.]
    0x8F8F8E, // 8E 8F [8F]   '..' [.]
    0x909080, // 80 90 [90]   '..' [.]
    0x919190, // 90 91 [91]   '..' [.]
    0x929290, // 90 92 [92]   '..' [.]
    0x939392, // 92 93 [93]   '..' [.]
    0x949490, // 90 94 [94]   '..' [.]
    0x959594, // 94 95 [95]   '..' [.]
    0x969694, // 94 96 [96]   '..' [.]
    0x979796, // 96 97 [97]   '..' [.]
    0x989890, // 90 98 [98]   '..' [.]
    0x999998, // 98 99 [99]   '..' [.]
    0x9A9A98, // 98 9A [9A]   '..' [.]
    0x9B9B9A, // 9A 9B [9B]   '..' [.]
    0x9C9C98, // 98 9C [9C]   '..' [.]
    0x9D9D9C, // 9C 9D [9D]   '..' [.]
    0x9E9E9C, // 9C 9E [9E]   '..' [.]
    0x9F9F9E, // 9E 9F [9F]   '..' [.]
    0xA0A080, // 80 A0 [A0]   '..' [.]
    0xA1A1A0, // A0 A1 [A1]   '..' [.]
    0xA2A2A0, // A0 A2 [A2]   '..' [.]
    0xA3A3A2, // A2 A3 [A3]   '..' [.]
    0xA4A4A0, // A0 A4 [A4]   '..' [.]
    0xA5A5A4, // A4 A5 [A5]   '..' [.]
    0xA6A6A4, // A4 A6 [A6]   '..' [.]
    0xA7A7A6, // A6 A7 [A7]   '..' [.]
    0xA8A8A0, // A0 A8 [A8]   '..' [.]
    0xA9A9A8, // A8 A9 [A9]   '..' [.]
    0xAAAAA8, // A8 AA [AA]   '..' [.]
    0xABABAA, // AA AB [AB]   '..' [.]
    0xACACA8, // A8 AC [AC]   '..' [.]
    0xADADAC, // AC AD [AD]   '..' [.]
    0xAEAEAC, // AC AE [AE]   '..' [.]
    0xAFAFAE, // AE AF [AF]   '..' [.]
    0xB0B0A0, // A0 B0 [B0]   '..' [.]
    0xB1B1B0, // B0 B1 [B1]   '..' [.]
    0xB2B2B0, // B0 B2 [B2]   '..' [.]
    0xB3B3B2, // B2 B3 [B3]   '..' [.]
    0xB4B4B0, // B0 B4 [B4]   '..' [.]
    0xB5B5B4, // B4 B5 [B5]   '..' [.]
    0xB6B6B4, // B4 B6 [B6]   '..' [.]
    0xB7B7B6, // B6 B7 [B7]   '..' [.]
    0xB8B8B0, // B0 B8 [B8]   '..' [.]
    0xB9B9B8, // B8 B9 [B9]   '..' [.]
    0xBABAB8, // B8 BA [BA]   '..' [.]
    0xBBBBBA, // BA BB [BB]   '..' [.]
    0xBCBCB8, // B8 BC [BC]   '..' [.]
    0xBDBDBC, // BC BD [BD]   '..' [.]
    0xBEBEBC, // BC BE [BE]   '..' [.]
    0xBFBFBE, // BE BF [BF]   '..' [.]
    0xC0C080, // 80 C0 [C0]   '..' [.]
    0xC1C1C0, // C0 C1 [C1]   '..' [.]
    0xC2C2C0, // C0 C2 [C2]   '..' [.]
    0xC3C3C2, // C2 C3 [C3]   '..' [.]
    0xC4C4C0, // C0 C4 [C4]   '..' [.]
    0xC5C5C4, // C4 C5 [C5]   '..' [.]
    0xC6C6C4, // C4 C6 [C6]   '..' [.]
    0xC7C7C6, // C6 C7 [C7]   '..' [.]
    0xC8C8C0, // C0 C8 [C8]   '..' [.]
    0xC9C9C8, // C8 C9 [C9]   '..' [.]
    0xCACAC8, // C8 CA [CA]   '..' [.]
    0xCBCBCA, // CA CB [CB]   '..' [.]
    0xCCCCC8, // C8 CC [CC]   '..' [.]
    0xCDCDCC, // CC CD [CD]   '..' [.]
    0xCECECC, // CC CE [CE]   '..' [.]
    0xCFCFCE, // CE CF [CF]   '..' [.]
    0xD0D0C0, // C0 D0 [D0]   '..' [.]
    0xD1D1D0, // D0 D1 [D1]   '..' [.]
    0xD2D2D0, // D0 D2 [D2]   '..' [.]
    0xD3D3D2, // D2 D3 [D3]   '..' [.]
    0xD4D4D0, // D0 D4 [D4]   '..' [.]
    0xD5D5D4, // D4 D5 [D5]   '..' [.]
    0xD6D6D4, // D4 D6 [D6]   '..' [.]
    0xD7D7D6, // D6 D7 [D7]   '..' [.]
    0xD8D8D0, // D0 D8 [D8]   '..' [.]
    0xD9D9D8, // D8 D9 [D9]   '..' [.]
    0xDADAD8, // D8 DA [DA]   '..' [.]
    0xDBDBDA, // DA DB [DB]   '..' [.]
    0xDCDCD8, // D8 DC [DC]   '..' [.]
    0xDDDDDC, // DC DD [DD]   '..' [.]
    0xDEDEDC, // DC DE [DE]   '..' [.]
    0xDFDFDE, // DE DF [DF]   '..' [.]
    0xE0E0C0, // C0 E0 [E0]   '..' [.]
    0xE1E1E0, // E0 E1 [E1]   '..' [.]
    0xE2E2E0, // E0 E2 [E2]   '..' [.]
    0xE3E3E2, // E2 E3 [E3]   '..' [.]
    0xE4E4E0, // E0 E4 [E4]   '..' [.]
    0xE5E5E4, // E4 E5 [E5]   '..' [.]
    0xE6E6E4, // E4 E6 [E6]   '..' [.]
    0xE7E7E6, // E6 E7 [E7]   '..' [.]
    0xE8E8E0, // E0 E8 [E8]   '..' [.]
    0xE9E9E8, // E8 E9 [E9]   '..' [.]
    0xEAEAE8, // E8 EA [EA]   '..' [.]
    0xEBEBEA, // EA EB [EB]   '..' [.]
    0xECECE8, // E8 EC [EC]   '..' [.]
    0xEDEDEC, // EC ED [ED]   '..' [.]
    0xEEEEEC, // EC EE [EE]   '..' [.]
    0xEFEFEE, // EE EF [EF]   '..' [.]
    0xF0F0E0, // E0 F0 [F0]   '..' [.]
    0xF1F1F0, // F0 F1 [F1]   '..' [.]
    0xF2F2F0, // F0 F2 [F2]   '..' [.]
    0xF3F3F2, // F2 F3 [F3]   '..' [.]
    0xF4F4F0, // F0 F4 [F4]   '..' [.]
    0xF5F5F4, // F4 F5 [F5]   '..' [.]
    0xF6F6F4, // F4 F6 [F6]   '..' [.]
    0xF7F7F6, // F6 F7 [F7]   '..' [.]
    0xF8F8F0, // F0 F8 [F8]   '..' [.]
    0xF9F9F8, // F8 F9 [F9]   '..' [.]
    0xFAFAF8, // F8 FA [FA]   '..' [.]
    0xFBFBFA, // FA FB [FB]   '..' [.]
    0xFCFCF8, // F8 FC [FC]   '..' [.]
    0xFDFDFC, // FC FD [FD]   '..' [.]
    0xFEFEFC, // FC FE [FE]   '..' [.]
    0xFFFFFE, // FE FF [FF]   '..' [.]
};
const otp_zone_raw_buffer_t raw3x_multibit = {
    0x000003, // 03 00 [00]   '..' [.]
    0x010104, // 04 01 [01]   '..' [.]
    0x02020B, // 0B 02 [02]   '..' [.]
    0x030312, // 12 03 [03]   '..' [.]
    0x040425, // 25 04 [04]   '%.' [.]
    0x050544, // 44 05 [05]   'D.' [.]
    0x060687, // 87 06 [06]   '..' [.]
    0x070606, // 06 06 [07]   '..' [.]
    0x080A09, // 09 0A [08]   '..' [.]
    0x090D08, // 08 0D [09]   '..' [.]
    0x0A020B, // 0B 02 [0A]   '..' [.]
    0x0B1B0A, // 0A 1B [0B]   '..' [.]
    0x0C2C0D, // 0D 2C [0C]   '.,' [.]
    0x0D4D0C, // 0C 4D [0D]   '.M' [.]
    0x0E8E0F, // 0F 8E [0E]   '..' [.]
    0x0E0F0E, // 0E 0F [0E]   '..' [.]
    0x121011, // 11 10 [12]   '..' [.]
    0x151110, // 10 11 [15]   '..' [.]
    0x1A1213, // 13 12 [1A]   '..' [.]
    0x031312, // 12 13 [03]   '..' [.]
    0x341415, // 15 14 [34]   '..' [4]
    0x551514, // 14 15 [55]   '..' [U]
    0x961617, // 17 16 [96]   '..' [.]
    0x171711, // 11 17 [17]   '..' [.]
    0x181812, // 12 18 [18]   '..' [.]
    0x19190B, // 0B 19 [19]   '..' [.]
    0x1A1A38, // 38 1A [1A]   '8.' [.]
    0x1B1B59, // 59 1B [1B]   'Y.' [.]
    0x1C1C9E, // 9E 1C [1C]   '..' [.]
    0x1D1C1F, // 1F 1C [1D]   '..' [.]
    0x1E1C1C, // 1C 1C [1E]   '..' [.]
    0x1F1B1D, // 1D 1B [1F]   '..' [.]
    0x202822, // 22 28 [20]   '"(' [ ]
    0x213123, // 23 31 [21]   '#1' [!]
    0x220220, // 20 02 [22]   ' .' ["]
    0x236321, // 21 63 [23]   '!c' [#]
    0x24A426, // 26 A4 [24]   '&.' [$]
    0x242527, // 27 25 [24]   ''%' [$]
    0x242624, // 24 26 [24]   '$&' [$]
    0x232725, // 25 27 [23]   '%'' [#]
    0x20282A, // 2A 28 [20]   '*(' [ ]
    0x39292B, // 2B 29 [39]   '+)' [9]
    0x0A2A28, // 28 2A [0A]   '(*' [.]
    0x6B2B29, // 29 2B [6B]   ')+' [k]
    0xAC2C2E, // 2E 2C [AC]   '.,' [.]
    0x2D2D21, // 21 2D [2D]   '!-' [-]
    0x2E2E3A, // 3A 2E [2E]   ':.' [.]
    0x2F2F0B, // 0B 2F [2F]   './' [/]
    0x303074, // 74 30 [30]   't0' [0]
    0x3131B5, // B5 31 [31]   '.1' [1]
    0x323336, // 36 33 [32]   '63' [2]
    0x333137, // 37 31 [33]   '71' [3]
    0x343030, // 30 30 [34]   '00' [4]
    0x353D31, // 31 3D [35]   '1=' [5]
    0x362632, // 32 26 [36]   '2&' [6]
    0x371733, // 33 17 [37]   '3.' [7]
    0x38783C, // 3C 78 [38]   '<x' [8]
    0x39B93D, // 3D B9 [39]   '=.' [9]
    0x3B3A3E, // 3E 3A [3B]   '>:' [;]
    0x393B3F, // 3F 3B [39]   '?;' [9]
    0x383C38, // 38 3C [38]   '8<' [8]
    0x353D39, // 39 3D [35]   '9=' [5]
    0x2E3E3A, // 3A 3E [2E]   ':>' [.]
    0x1F3F3B, // 3B 3F [1F]   ';?' [.]
    0x004044, // 44 40 [00]   'D@' [.]
    0xC14145, // 45 41 [C1]   'EA' [.]
    0x42425A, // 5A 42 [42]   'ZB' [B]
    0x43436B, // 6B 43 [43]   'kC' [C]
    0x44440C, // 0C 44 [44]   '.D' [D]
    0x4545CD, // CD 45 [45]   '.E' [E]
    0x46474E, // 4E 47 [46]   'NG' [F]
    0x47454F, // 4F 45 [47]   'OE' [G]
    0x484C40, // 40 4C [48]   '@L' [H]
    0x494141, // 41 41 [49]   'AA' [I]
    0x4A5A42, // 42 5A [4A]   'BZ' [J]
    0x4B6B43, // 43 6B [4B]   'Ck' [K]
    0x4C0C44, // 44 0C [4C]   'D.' [L]
    0x4DCD45, // 45 CD [4D]   'E.' [M]
    0x4F4E46, // 46 4E [4F]   'FN' [O]
    0x4D4F47, // 47 4F [4D]   'GO' [M]
    0x545058, // 58 50 [54]   'XP' [T]
    0x595159, // 59 51 [59]   'YQ' [Y]
    0x42525A, // 5A 52 [42]   'ZR' [B]
    0x73535B, // 5B 53 [73]   '[S' [s]
    0x14545C, // 5C 54 [14]   '\T' [.]
    0xD5555D, // 5D 55 [D5]   ']U' [.]
    0x565666, // 66 56 [56]   'fV' [V]
    0x575707, // 07 57 [57]   '.W' [W]
    0x5858C8, // C8 58 [58]   '.X' [X]
    0x595849, // 49 58 [59]   'IX' [Y]
    0x5A584A, // 4A 58 [5A]   'JX' [Z]
    0x5B5F4B, // 4B 5F [5B]   'K_' [[]
    0x5C544C, // 4C 54 [5C]   'LT' [\]
    0x5D4D4D, // 4D 4D [5D]   'MM' []]
    0x5E7E4E, // 4E 7E [5E]   'N~' [^]
    0x5F1F4F, // 4F 1F [5F]   'O.' [_]
    0x60E070, // 70 E0 [60]   'p.' [`]
    0x606171, // 71 61 [60]   'qa' [`]
    0x606272, // 72 62 [60]   'rb' [`]
    0x676373, // 73 63 [67]   'sc' [g]
    0x6C6474, // 74 64 [6C]   'td' [l]
    0x756575, // 75 65 [75]   'ue' [u]
    0x466676, // 76 66 [46]   'vf' [F]
    0x276777, // 77 67 [27]   'wg' [']
    0xE86878, // 78 68 [E8]   'xh' [.]
    0x696909, // 09 69 [69]   '.i' [i]
    0x6A6ACA, // CA 6A [6A]   '.j' [j]
    0x6B6A4B, // 4B 6A [6B]   'Kj' [k]
    0x6C6E4C, // 4C 6E [6C]   'Ln' [l]
    0x6D694D, // 4D 69 [6D]   'Mi' [m]
    0x6E664E, // 4E 66 [6E]   'Nf' [n]
    0x6F7F4F, // 4F 7F [6F]   'O.' [o]
    0x705050, // 50 50 [70]   'PP' [p]
    0x713151, // 51 31 [71]   'Q1' [q]
    0x72F252, // 52 F2 [72]   'R.' [r]
    0x727353, // 53 73 [72]   'Ss' [r]
    0x767454, // 54 74 [76]   'Tt' [v]
    0x717555, // 55 75 [71]   'Uu' [q]
    0x7E7656, // 56 76 [7E]   'Vv' [~]
    0x677757, // 57 77 [67]   'Ww' [g]
    0x587858, // 58 78 [58]   'Xx' [X]
    0x397959, // 59 79 [39]   'Yy' [9]
    0xFA7A5A, // 5A 7A [FA]   'Zz' [.]
    0x7B7BBB, // BB 7B [7B]   '.{' [{]
    0x7C7D3C, // 3C 7D [7C]   '<}' [|]
    0x7D7F3D, // 3D 7F [7D]   '=.' [}]
    0x7E7A3E, // 3E 7A [7E]   '>z' [~]
    0x7F773F, // 3F 77 [7F]   '?w' [.]
    0x8090C0, // C0 90 [80]   '..' [.]
    0x81A1C1, // C1 A1 [81]   '..' [.]
    0x82C2C2, // C2 C2 [82]   '..' [.]
    0x8303C3, // C3 03 [83]   '..' [.]
    0x8584C4, // C4 84 [85]   '..' [.]
    0x8785C5, // C5 85 [87]   '..' [.]
    0x8286C6, // C6 86 [82]   '..' [.]
    0x8F87C7, // C7 87 [8F]   '..' [.]
    0x9888C8, // C8 88 [98]   '..' [.]
    0xA989C9, // C9 89 [A9]   '..' [.]
    0xCA8ACA, // CA 8A [CA]   '..' [.]
    0x0B8BCB, // CB 8B [0B]   '..' [.]
    0x8C8D0C, // 0C 8D [8C]   '..' [.]
    0x8D8F0D, // 0D 8F [8D]   '..' [.]
    0x8E8A0E, // 0E 8A [8E]   '..' [.]
    0x8F870F, // 0F 87 [8F]   '..' [.]
    0x908010, // 10 80 [90]   '..' [.]
    0x91B111, // 11 B1 [91]   '..' [.]
    0x92D212, // 12 D2 [92]   '..' [.]
    0x931313, // 13 13 [93]   '..' [.]
    0x959414, // 14 94 [95]   '..' [.]
    0x979515, // 15 95 [97]   '..' [.]
    0x929616, // 16 96 [92]   '..' [.]
    0x9F9717, // 17 97 [9F]   '..' [.]
    0x889818, // 18 98 [88]   '..' [.]
    0xB99919, // 19 99 [B9]   '..' [.]
    0xDA9A1A, // 1A 9A [DA]   '..' [.]
    0x1B9B1B, // 1B 9B [1B]   '..' [.]
    0x9C9F9C, // 9C 9F [9C]   '..' [.]
    0x9D989D, // 9D 98 [9D]   '..' [.]
    0x9E979E, // 9E 97 [9E]   '..' [.]
    0x9F8E9F, // 9F 8E [9F]   '..' [.]
    0xA081A0, // A0 81 [A0]   '..' [.]
    0xA1E0A1, // A1 E0 [A1]   '..' [.]
    0xA223A2, // A2 23 [A2]   '.#' [.]
    0xA2A2A3, // A3 A2 [A2]   '..' [.]
    0xA6A5A4, // A4 A5 [A6]   '..' [.]
    0xA1A4A5, // A5 A4 [A1]   '..' [.]
    0xAEA7A6, // A6 A7 [AE]   '..' [.]
    0xB7A6A7, // A7 A6 [B7]   '..' [.]
    0x88A9A8, // A8 A9 [88]   '..' [.]
    0xE9A8A9, // A9 A8 [E9]   '..' [.]
    0x2AABAA, // AA AB [2A]   '..' [*]
    0xABADAB, // AB AD [AB]   '..' [.]
    0xACA6AC, // AC A6 [AC]   '..' [.]
    0xADBFAD, // AD BF [AD]   '..' [.]
    0xAE8CAE, // AE 8C [AE]   '..' [.]
    0xAFEDAF, // AF ED [AF]   '..' [.]
    0xB032B0, // B0 32 [B0]   '.2' [.]
    0xB0B3B1, // B1 B3 [B0]   '..' [.]
    0xB0B0B2, // B2 B0 [B0]   '..' [.]
    0xB7B1B3, // B3 B1 [B7]   '..' [.]
    0xBCB6B4, // B4 B6 [BC]   '..' [.]
    0xA5B7B5, // B5 B7 [A5]   '..' [.]
    0x96B4B6, // B6 B4 [96]   '..' [.]
    0xF7B5B7, // B7 B5 [F7]   '..' [.]
    0x38BAB8, // B8 BA [38]   '..' [8]
    0xB9B5B9, // B9 B5 [B9]   '..' [.]
    0xBAAEBA, // BA AE [BA]   '..' [.]
    0xBB9FBB, // BB 9F [BB]   '..' [.]
    0xBCF8BC, // BC F8 [BC]   '..' [.]
    0xBD39BD, // BD 39 [BD]   '.9' [.]
    0xBFBABE, // BE BA [BF]   '..' [.]
    0xBDBBBF, // BF BB [BD]   '..' [.]
    0xC4C4C0, // C0 C4 [C4]   '..' [.]
    0xC9C5C1, // C1 C5 [C9]   '..' [.]
    0xD2C6C2, // C2 C6 [D2]   '..' [.]
    0xE3C7C3, // C3 C7 [E3]   '..' [.]
    0x84C0C4, // C4 C0 [84]   '..' [.]
    0x45C1C5, // C5 C1 [45]   '..' [E]
    0xC6DEC6, // C6 DE [C6]   '..' [.]
    0xC7EFC7, // C7 EF [C7]   '..' [.]
    0xC880C8, // C8 80 [C8]   '..' [.]
    0xC941C9, // C9 41 [C9]   '.A' [.]
    0xCBC2CA, // CA C2 [CB]   '..' [.]
    0xC9C3CB, // CB C3 [C9]   '..' [.]
    0xC8C4CC, // CC C4 [C8]   '..' [.]
    0xC5C5CD, // CD C5 [C5]   '..' [.]
    0xDEC6CE, // CE C6 [DE]   '..' [.]
    0xEFC7CF, // CF C7 [EF]   '..' [.]
    0x90D8D0, // D0 D8 [90]   '..' [.]
    0x51D9D1, // D1 D9 [51]   '..' [Q]
    0xD2E2D2, // D2 E2 [D2]   '..' [.]
    0xD383D3, // D3 83 [D3]   '..' [.]
    0xD444D4, // D4 44 [D4]   '.D' [.]
    0xD4C5D5, // D5 C5 [D4]   '..' [.]
    0xD4C6D6, // D6 C6 [D4]   '..' [.]
    0xD3C7D7, // D7 C7 [D3]   '..' [.]
    0xD0C8D8, // D8 C8 [D0]   '..' [.]
    0xC9C9D9, // D9 C9 [C9]   '..' [.]
    0xFACADA, // DA CA [FA]   '..' [.]
    0x9BCBDB, // DB CB [9B]   '..' [.]
    0x5CCCDC, // DC CC [5C]   '..' [\]
    0xDDBDDD, // DD BD [DD]   '..' [.]
    0xDE7EDE, // DE 7E [DE]   '.~' [.]
    0xDEFFDF, // DF FF [DE]   '..' [.]
    0xE2C0E0, // E0 C0 [E2]   '..' [.]
    0xE5C1E1, // E1 C1 [E5]   '..' [.]
    0xEAC2E2, // E2 C2 [EA]   '..' [.]
    0xF3C3E3, // E3 C3 [F3]   '..' [.]
    0xC4C4E4, // E4 C4 [C4]   '..' [.]
    0xA5C5E5, // E5 C5 [A5]   '..' [.]
    0x66C6E6, // E6 C6 [66]   '..' [f]
    0xE727E7, // E7 27 [E7]   '.'' [.]
    0xE9A8E8, // E8 A8 [E9]   '..' [.]
    0xEBA9E9, // E9 A9 [EB]   '..' [.]
    0xEEAAEA, // EA AA [EE]   '..' [.]
    0xE3ABEB, // EB AB [E3]   '..' [.]
    0xFCACEC, // EC AC [FC]   '..' [.]
    0xCDADED, // ED AD [CD]   '..' [.]
    0xAEAEEE, // EE AE [AE]   '..' [.]
    0x6FAFEF, // EF AF [6F]   '..' [o]
    0xF170F0, // F0 70 [F1]   '.p' [.]
    0xF371F1, // F1 71 [F3]   '.q' [.]
    0xF672F2, // F2 72 [F6]   '.r' [.]
    0xFB73F3, // F3 73 [FB]   '.s' [.]
    0xE474F4, // F4 74 [E4]   '.t' [.]
    0xD575F5, // F5 75 [D5]   '.u' [.]
    0xB676F6, // F6 76 [B6]   '.v' [.]
    0x7777F7, // F7 77 [77]   '.w' [w]
    0xFBF8F8, // F8 F8 [FB]   '..' [.]
    0xFCF9F9, // F9 F9 [FC]   '..' [.]
    0xF3FAFA, // FA FA [F3]   '..' [.]
    0xEAFBFB, // FB FB [EA]   '..' [.]
    0xDDFCFC, // FC FC [DD]   '..' [.]
    0xBCFDFD, // FD FD [BC]   '..' [.]
    0x7FFEFE, // FE FE [7F]   '..' [.]
    0xF9FFFF, // FF FF [F9]   '..' [.]
};
const otp_zone_raw_buffer_t ecc_none = {
    0x000000, // 00 00 [00]   '..' [.]
    0x2E0101, // 01 01 [2E]   '..' [.]
    0x2B0202, // 02 02 [2B]   '..' [+]
    0x050303, // 03 03 [05]   '..' [.]
    0x090404, // 04 04 [09]   '..' [.]
    0x270505, // 05 05 [27]   '..' [']
    0x220606, // 06 06 [22]   '..' ["]
    0x0C0707, // 07 07 [0C]   '..' [.]
    0x360808, // 08 08 [36]   '..' [6]
    0x180909, // 09 09 [18]   '..' [.]
    0x1D0A0A, // 0A 0A [1D]   '..' [.]
    0x330B0B, // 0B 0B [33]   '..' [3]
    0x3F0C0C, // 0C 0C [3F]   '..' [?]
    0x110D0D, // 0D 0D [11]   '..' [.]
    0x140E0E, // 0E 0E [14]   '..' [.]
    0x3A0F0F, // 0F 0F [3A]   '..' [:]
    0x1B1010, // 10 10 [1B]   '..' [.]
    0x351111, // 11 11 [35]   '..' [5]
    0x301212, // 12 12 [30]   '..' [0]
    0x1E1313, // 13 13 [1E]   '..' [.]
    0x121414, // 14 14 [12]   '..' [.]
    0x3C1515, // 15 15 [3C]   '..' [<]
    0x391616, // 16 16 [39]   '..' [9]
    0x171717, // 17 17 [17]   '..' [.]
    0x2D1818, // 18 18 [2D]   '..' [-]
    0x031919, // 19 19 [03]   '..' [.]
    0x061A1A, // 1A 1A [06]   '..' [.]
    0x281B1B, // 1B 1B [28]   '..' [(]
    0x241C1C, // 1C 1C [24]   '..' [$]
    0x0A1D1D, // 1D 1D [0A]   '..' [.]
    0x0F1E1E, // 1E 1E [0F]   '..' [.]
    0x211F1F, // 1F 1F [21]   '..' [!]
    0x392020, // 20 20 [39]   '  ' [9]
    0x172121, // 21 21 [17]   '!!' [.]
    0x122222, // 22 22 [12]   '""' [.]
    0x3C2323, // 23 23 [3C]   '##' [<]
    0x302424, // 24 24 [30]   '$$' [0]
    0x1E2525, // 25 25 [1E]   '%%' [.]
    0x1B2626, // 26 26 [1B]   '&&' [.]
    0x352727, // 27 27 [35]   '''' [5]
    0x0F2828, // 28 28 [0F]   '((' [.]
    0x212929, // 29 29 [21]   '))' [!]
    0x242A2A, // 2A 2A [24]   '**' [$]
    0x0A2B2B, // 2B 2B [0A]   '++' [.]
    0x062C2C, // 2C 2C [06]   ',,' [.]
    0x282D2D, // 2D 2D [28]   '--' [(]
    0x2D2E2E, // 2E 2E [2D]   '..' [-]
    0x032F2F, // 2F 2F [03]   '//' [.]
    0x223030, // 30 30 [22]   '00' ["]
    0x0C3131, // 31 31 [0C]   '11' [.]
    0x093232, // 32 32 [09]   '22' [.]
    0x273333, // 33 33 [27]   '33' [']
    0x2B3434, // 34 34 [2B]   '44' [+]
    0x053535, // 35 35 [05]   '55' [.]
    0x003636, // 36 36 [00]   '66' [.]
    0x2E3737, // 37 37 [2E]   '77' [.]
    0x143838, // 38 38 [14]   '88' [.]
    0x3A3939, // 39 39 [3A]   '99' [:]
    0x3F3A3A, // 3A 3A [3F]   '::' [?]
    0x113B3B, // 3B 3B [11]   ';;' [.]
    0x1D3C3C, // 3C 3C [1D]   '<<' [.]
    0x333D3D, // 3D 3D [33]   '==' [3]
    0x363E3E, // 3E 3E [36]   '>>' [6]
    0x183F3F, // 3F 3F [18]   '??' [.]
    0x3F4040, // 40 40 [3F]   '@@' [?]
    0x114141, // 41 41 [11]   'AA' [.]
    0x144242, // 42 42 [14]   'BB' [.]
    0x3A4343, // 43 43 [3A]   'CC' [:]
    0x364444, // 44 44 [36]   'DD' [6]
    0x184545, // 45 45 [18]   'EE' [.]
    0x1D4646, // 46 46 [1D]   'FF' [.]
    0x334747, // 47 47 [33]   'GG' [3]
    0x094848, // 48 48 [09]   'HH' [.]
    0x274949, // 49 49 [27]   'II' [']
    0x224A4A, // 4A 4A [22]   'JJ' ["]
    0x0C4B4B, // 4B 4B [0C]   'KK' [.]
    0x004C4C, // 4C 4C [00]   'LL' [.]
    0x2E4D4D, // 4D 4D [2E]   'MM' [.]
    0x2B4E4E, // 4E 4E [2B]   'NN' [+]
    0x054F4F, // 4F 4F [05]   'OO' [.]
    0x245050, // 50 50 [24]   'PP' [$]
    0x0A5151, // 51 51 [0A]   'QQ' [.]
    0x0F5252, // 52 52 [0F]   'RR' [.]
    0x215353, // 53 53 [21]   'SS' [!]
    0x2D5454, // 54 54 [2D]   'TT' [-]
    0x035555, // 55 55 [03]   'UU' [.]
    0x065656, // 56 56 [06]   'VV' [.]
    0x285757, // 57 57 [28]   'WW' [(]
    0x125858, // 58 58 [12]   'XX' [.]
    0x3C5959, // 59 59 [3C]   'YY' [<]
    0x395A5A, // 5A 5A [39]   'ZZ' [9]
    0x175B5B, // 5B 5B [17]   '[[' [.]
    0x1B5C5C, // 5C 5C [1B]   '\\' [.]
    0x355D5D, // 5D 5D [35]   ']]' [5]
    0x305E5E, // 5E 5E [30]   '^^' [0]
    0x1E5F5F, // 5F 5F [1E]   '__' [.]
    0x066060, // 60 60 [06]   '``' [.]
    0x286161, // 61 61 [28]   'aa' [(]
    0x2D6262, // 62 62 [2D]   'bb' [-]
    0x036363, // 63 63 [03]   'cc' [.]
    0x0F6464, // 64 64 [0F]   'dd' [.]
    0x216565, // 65 65 [21]   'ee' [!]
    0x246666, // 66 66 [24]   'ff' [$]
    0x0A6767, // 67 67 [0A]   'gg' [.]
    0x306868, // 68 68 [30]   'hh' [0]
    0x1E6969, // 69 69 [1E]   'ii' [.]
    0x1B6A6A, // 6A 6A [1B]   'jj' [.]
    0x356B6B, // 6B 6B [35]   'kk' [5]
    0x396C6C, // 6C 6C [39]   'll' [9]
    0x176D6D, // 6D 6D [17]   'mm' [.]
    0x126E6E, // 6E 6E [12]   'nn' [.]
    0x3C6F6F, // 6F 6F [3C]   'oo' [<]
    0x1D7070, // 70 70 [1D]   'pp' [.]
    0x337171, // 71 71 [33]   'qq' [3]
    0x367272, // 72 72 [36]   'rr' [6]
    0x187373, // 73 73 [18]   'ss' [.]
    0x147474, // 74 74 [14]   'tt' [.]
    0x3A7575, // 75 75 [3A]   'uu' [:]
    0x3F7676, // 76 76 [3F]   'vv' [?]
    0x117777, // 77 77 [11]   'ww' [.]
    0x2B7878, // 78 78 [2B]   'xx' [+]
    0x057979, // 79 79 [05]   'yy' [.]
    0x007A7A, // 7A 7A [00]   'zz' [.]
    0x2E7B7B, // 7B 7B [2E]   '{{' [.]
    0x227C7C, // 7C 7C [22]   '||' ["]
    0x0C7D7D, // 7D 7D [0C]   '}}' [.]
    0x097E7E, // 7E 7E [09]   '~~' [.]
    0x277F7F, // 7F 7F [27]   '..' [']
    0x398080, // 80 80 [39]   '..' [9]
    0x178181, // 81 81 [17]   '..' [.]
    0x128282, // 82 82 [12]   '..' [.]
    0x3C8383, // 83 83 [3C]   '..' [<]
    0x308484, // 84 84 [30]   '..' [0]
    0x1E8585, // 85 85 [1E]   '..' [.]
    0x1B8686, // 86 86 [1B]   '..' [.]
    0x358787, // 87 87 [35]   '..' [5]
    0x0F8888, // 88 88 [0F]   '..' [.]
    0x218989, // 89 89 [21]   '..' [!]
    0x248A8A, // 8A 8A [24]   '..' [$]
    0x0A8B8B, // 8B 8B [0A]   '..' [.]
    0x068C8C, // 8C 8C [06]   '..' [.]
    0x288D8D, // 8D 8D [28]   '..' [(]
    0x2D8E8E, // 8E 8E [2D]   '..' [-]
    0x038F8F, // 8F 8F [03]   '..' [.]
    0x229090, // 90 90 [22]   '..' ["]
    0x0C9191, // 91 91 [0C]   '..' [.]
    0x099292, // 92 92 [09]   '..' [.]
    0x279393, // 93 93 [27]   '..' [']
    0x2B9494, // 94 94 [2B]   '..' [+]
    0x059595, // 95 95 [05]   '..' [.]
    0x009696, // 96 96 [00]   '..' [.]
    0x2E9797, // 97 97 [2E]   '..' [.]
    0x149898, // 98 98 [14]   '..' [.]
    0x3A9999, // 99 99 [3A]   '..' [:]
    0x3F9A9A, // 9A 9A [3F]   '..' [?]
    0x119B9B, // 9B 9B [11]   '..' [.]
    0x1D9C9C, // 9C 9C [1D]   '..' [.]
    0x339D9D, // 9D 9D [33]   '..' [3]
    0x369E9E, // 9E 9E [36]   '..' [6]
    0x189F9F, // 9F 9F [18]   '..' [.]
    0x00A0A0, // A0 A0 [00]   '..' [.]
    0x2EA1A1, // A1 A1 [2E]   '..' [.]
    0x2BA2A2, // A2 A2 [2B]   '..' [+]
    0x05A3A3, // A3 A3 [05]   '..' [.]
    0x09A4A4, // A4 A4 [09]   '..' [.]
    0x27A5A5, // A5 A5 [27]   '..' [']
    0x22A6A6, // A6 A6 [22]   '..' ["]
    0x0CA7A7, // A7 A7 [0C]   '..' [.]
    0x36A8A8, // A8 A8 [36]   '..' [6]
    0x18A9A9, // A9 A9 [18]   '..' [.]
    0x1DAAAA, // AA AA [1D]   '..' [.]
    0x33ABAB, // AB AB [33]   '..' [3]
    0x3FACAC, // AC AC [3F]   '..' [?]
    0x11ADAD, // AD AD [11]   '..' [.]
    0x14AEAE, // AE AE [14]   '..' [.]
    0x3AAFAF, // AF AF [3A]   '..' [:]
    0x1BB0B0, // B0 B0 [1B]   '..' [.]
    0x35B1B1, // B1 B1 [35]   '..' [5]
    0x30B2B2, // B2 B2 [30]   '..' [0]
    0x1EB3B3, // B3 B3 [1E]   '..' [.]
    0x12B4B4, // B4 B4 [12]   '..' [.]
    0x3CB5B5, // B5 B5 [3C]   '..' [<]
    0x39B6B6, // B6 B6 [39]   '..' [9]
    0x17B7B7, // B7 B7 [17]   '..' [.]
    0x2DB8B8, // B8 B8 [2D]   '..' [-]
    0x03B9B9, // B9 B9 [03]   '..' [.]
    0x06BABA, // BA BA [06]   '..' [.]
    0x28BBBB, // BB BB [28]   '..' [(]
    0x24BCBC, // BC BC [24]   '..' [$]
    0x0ABDBD, // BD BD [0A]   '..' [.]
    0x0FBEBE, // BE BE [0F]   '..' [.]
    0x21BFBF, // BF BF [21]   '..' [!]
    0x06C0C0, // C0 C0 [06]   '..' [.]
    0x28C1C1, // C1 C1 [28]   '..' [(]
    0x2DC2C2, // C2 C2 [2D]   '..' [-]
    0x03C3C3, // C3 C3 [03]   '..' [.]
    0x0FC4C4, // C4 C4 [0F]   '..' [.]
    0x21C5C5, // C5 C5 [21]   '..' [!]
    0x24C6C6, // C6 C6 [24]   '..' [$]
    0x0AC7C7, // C7 C7 [0A]   '..' [.]
    0x30C8C8, // C8 C8 [30]   '..' [0]
    0x1EC9C9, // C9 C9 [1E]   '..' [.]
    0x1BCACA, // CA CA [1B]   '..' [.]
    0x35CBCB, // CB CB [35]   '..' [5]
    0x39CCCC, // CC CC [39]   '..' [9]
    0x17CDCD, // CD CD [17]   '..' [.]
    0x12CECE, // CE CE [12]   '..' [.]
    0x3CCFCF, // CF CF [3C]   '..' [<]
    0x1DD0D0, // D0 D0 [1D]   '..' [.]
    0x33D1D1, // D1 D1 [33]   '..' [3]
    0x36D2D2, // D2 D2 [36]   '..' [6]
    0x18D3D3, // D3 D3 [18]   '..' [.]
    0x14D4D4, // D4 D4 [14]   '..' [.]
    0x3AD5D5, // D5 D5 [3A]   '..' [:]
    0x3FD6D6, // D6 D6 [3F]   '..' [?]
    0x11D7D7, // D7 D7 [11]   '..' [.]
    0x2BD8D8, // D8 D8 [2B]   '..' [+]
    0x05D9D9, // D9 D9 [05]   '..' [.]
    0x00DADA, // DA DA [00]   '..' [.]
    0x2EDBDB, // DB DB [2E]   '..' [.]
    0x22DCDC, // DC DC [22]   '..' ["]
    0x0CDDDD, // DD DD [0C]   '..' [.]
    0x09DEDE, // DE DE [09]   '..' [.]
    0x27DFDF, // DF DF [27]   '..' [']
    0x3FE0E0, // E0 E0 [3F]   '..' [?]
    0x11E1E1, // E1 E1 [11]   '..' [.]
    0x14E2E2, // E2 E2 [14]   '..' [.]
    0x3AE3E3, // E3 E3 [3A]   '..' [:]
    0x36E4E4, // E4 E4 [36]   '..' [6]
    0x18E5E5, // E5 E5 [18]   '..' [.]
    0x1DE6E6, // E6 E6 [1D]   '..' [.]
    0x33E7E7, // E7 E7 [33]   '..' [3]
    0x09E8E8, // E8 E8 [09]   '..' [.]
    0x27E9E9, // E9 E9 [27]   '..' [']
    0x22EAEA, // EA EA [22]   '..' ["]
    0x0CEBEB, // EB EB [0C]   '..' [.]
    0x00ECEC, // EC EC [00]   '..' [.]
    0x2EEDED, // ED ED [2E]   '..' [.]
    0x2BEEEE, // EE EE [2B]   '..' [+]
    0x05EFEF, // EF EF [05]   '..' [.]
    0x24F0F0, // F0 F0 [24]   '..' [$]
    0x0AF1F1, // F1 F1 [0A]   '..' [.]
    0x0FF2F2, // F2 F2 [0F]   '..' [.]
    0x21F3F3, // F3 F3 [21]   '..' [!]
    0x2DF4F4, // F4 F4 [2D]   '..' [-]
    0x03F5F5, // F5 F5 [03]   '..' [.]
    0x06F6F6, // F6 F6 [06]   '..' [.]
    0x28F7F7, // F7 F7 [28]   '..' [(]
    0x12F8F8, // F8 F8 [12]   '..' [.]
    0x3CF9F9, // F9 F9 [3C]   '..' [<]
    0x39FAFA, // FA FA [39]   '..' [9]
    0x17FBFB, // FB FB [17]   '..' [.]
    0x1BFCFC, // FC FC [1B]   '..' [.]
    0x35FDFD, // FD FD [35]   '..' [5]
    0x30FEFE, // FE FE [30]   '..' [0]
    0x1EFFFF, // FF FF [1E]   '..' [.]
};
const otp_zone_raw_buffer_t ecc_0_to_1 = {
    0x000001, // 01 00 [00]   '..' [.]
    0x2E0103, // 03 01 [2E]   '..' [.]
    0x2B0206, // 06 02 [2B]   '..' [+]
    0x05030B, // 0B 03 [05]   '..' [.]
    0x090414, // 14 04 [09]   '..' [.]
    0x270525, // 25 05 [27]   '%.' [']
    0x220646, // 46 06 [22]   'F.' ["]
    0x0C0787, // 87 07 [0C]   '..' [.]
    0x360908, // 08 09 [36]   '..' [6]
    0x180B09, // 09 0B [18]   '..' [.]
    0x1D0E0A, // 0A 0E [1D]   '..' [.]
    0x331B0B, // 0B 1B [33]   '..' [3]
    0x3F2C0C, // 0C 2C [3F]   '.,' [?]
    0x114D0D, // 0D 4D [11]   '.M' [.]
    0x148E0E, // 0E 8E [14]   '..' [.]
    0x3B0F0F, // 0F 0F [3B]   '..' [;]
    0x1B1810, // 10 18 [1B]   '..' [.]
    0x341111, // 11 11 [34]   '..' [4]
    0x311212, // 12 12 [31]   '..' [1]
    0x1F1313, // 13 13 [1F]   '..' [.]
    0x131414, // 14 14 [13]   '..' [.]
    0x3D1515, // 15 15 [3D]   '..' [=]
    0x381616, // 16 16 [38]   '..' [8]
    0x161717, // 17 17 [16]   '..' [.]
    0x2C1818, // 18 18 [2C]   '..' [,]
    0x021919, // 19 19 [02]   '..' [.]
    0x071A1A, // 1A 1A [07]   '..' [.]
    0x291B1B, // 1B 1B [29]   '..' [)]
    0x251C1C, // 1C 1C [25]   '..' [%]
    0x0B1D1D, // 1D 1D [0B]   '..' [.]
    0x0E1E1E, // 1E 1E [0E]   '..' [.]
    0x201F1F, // 1F 1F [20]   '..' [ ]
    0x382020, // 20 20 [38]   '  ' [8]
    0x162121, // 21 21 [16]   '!!' [.]
    0x132222, // 22 22 [13]   '""' [.]
    0x3D2323, // 23 23 [3D]   '##' [=]
    0x312424, // 24 24 [31]   '$$' [1]
    0x1F2525, // 25 25 [1F]   '%%' [.]
    0x1A2626, // 26 26 [1A]   '&&' [.]
    0x342727, // 27 27 [34]   '''' [4]
    0x0E2828, // 28 28 [0E]   '((' [.]
    0x202929, // 29 29 [20]   '))' [ ]
    0x252A2A, // 2A 2A [25]   '**' [%]
    0x0B2B2B, // 2B 2B [0B]   '++' [.]
    0x072C2C, // 2C 2C [07]   ',,' [.]
    0x292D2D, // 2D 2D [29]   '--' [)]
    0x2C2E2E, // 2E 2E [2C]   '..' [,]
    0x022F2F, // 2F 2F [02]   '//' [.]
    0x233030, // 30 30 [23]   '00' [#]
    0x0D3131, // 31 31 [0D]   '11' [.]
    0x083232, // 32 32 [08]   '22' [.]
    0x263333, // 33 33 [26]   '33' [&]
    0x2A3434, // 34 34 [2A]   '44' [*]
    0x043535, // 35 35 [04]   '55' [.]
    0x013636, // 36 36 [01]   '66' [.]
    0x2F3737, // 37 37 [2F]   '77' [/]
    0x153838, // 38 38 [15]   '88' [.]
    0x3B3939, // 39 39 [3B]   '99' [;]
    0x3E3A3A, // 3A 3A [3E]   '::' [>]
    0x103B3B, // 3B 3B [10]   ';;' [.]
    0x1C3C3C, // 3C 3C [1C]   '<<' [.]
    0x323D3D, // 3D 3D [32]   '==' [2]
    0x373E3E, // 3E 3E [37]   '>>' [7]
    0x193F3F, // 3F 3F [19]   '??' [.]
    0x3E4040, // 40 40 [3E]   '@@' [>]
    0x104141, // 41 41 [10]   'AA' [.]
    0x154242, // 42 42 [15]   'BB' [.]
    0x3B4343, // 43 43 [3B]   'CC' [;]
    0x374444, // 44 44 [37]   'DD' [7]
    0x194545, // 45 45 [19]   'EE' [.]
    0x1C4646, // 46 46 [1C]   'FF' [.]
    0x324747, // 47 47 [32]   'GG' [2]
    0x084848, // 48 48 [08]   'HH' [.]
    0x264949, // 49 49 [26]   'II' [&]
    0x234A4A, // 4A 4A [23]   'JJ' [#]
    0x0D4B4B, // 4B 4B [0D]   'KK' [.]
    0x014C4C, // 4C 4C [01]   'LL' [.]
    0x2F4D4D, // 4D 4D [2F]   'MM' [/]
    0x2A4E4E, // 4E 4E [2A]   'NN' [*]
    0x044F4F, // 4F 4F [04]   'OO' [.]
    0x255050, // 50 50 [25]   'PP' [%]
    0x0B5151, // 51 51 [0B]   'QQ' [.]
    0x0E5252, // 52 52 [0E]   'RR' [.]
    0x205353, // 53 53 [20]   'SS' [ ]
    0x2C5454, // 54 54 [2C]   'TT' [,]
    0x025555, // 55 55 [02]   'UU' [.]
    0x075656, // 56 56 [07]   'VV' [.]
    0x295757, // 57 57 [29]   'WW' [)]
    0x135858, // 58 58 [13]   'XX' [.]
    0x3D5959, // 59 59 [3D]   'YY' [=]
    0x385A5A, // 5A 5A [38]   'ZZ' [8]
    0x165B5B, // 5B 5B [16]   '[[' [.]
    0x1A5C5C, // 5C 5C [1A]   '\\' [.]
    0x345D5D, // 5D 5D [34]   ']]' [4]
    0x315E5E, // 5E 5E [31]   '^^' [1]
    0x1F5F5F, // 5F 5F [1F]   '__' [.]
    0x076060, // 60 60 [07]   '``' [.]
    0x296161, // 61 61 [29]   'aa' [)]
    0x2C6262, // 62 62 [2C]   'bb' [,]
    0x026363, // 63 63 [02]   'cc' [.]
    0x0E6464, // 64 64 [0E]   'dd' [.]
    0x206565, // 65 65 [20]   'ee' [ ]
    0x256666, // 66 66 [25]   'ff' [%]
    0x0B6767, // 67 67 [0B]   'gg' [.]
    0x316868, // 68 68 [31]   'hh' [1]
    0x1F6969, // 69 69 [1F]   'ii' [.]
    0x1A6A6A, // 6A 6A [1A]   'jj' [.]
    0x346B6B, // 6B 6B [34]   'kk' [4]
    0x386C6C, // 6C 6C [38]   'll' [8]
    0x166D6D, // 6D 6D [16]   'mm' [.]
    0x136E6E, // 6E 6E [13]   'nn' [.]
    0x3D6F6F, // 6F 6F [3D]   'oo' [=]
    0x1C7070, // 70 70 [1C]   'pp' [.]
    0x327171, // 71 71 [32]   'qq' [2]
    0x377272, // 72 72 [37]   'rr' [7]
    0x197373, // 73 73 [19]   'ss' [.]
    0x157474, // 74 74 [15]   'tt' [.]
    0x3B7575, // 75 75 [3B]   'uu' [;]
    0x3E7676, // 76 76 [3E]   'vv' [>]
    0x107777, // 77 77 [10]   'ww' [.]
    0x2A7878, // 78 78 [2A]   'xx' [*]
    0x047979, // 79 79 [04]   'yy' [.]
    0x017A7A, // 7A 7A [01]   'zz' [.]
    0x2F7B7B, // 7B 7B [2F]   '{{' [/]
    0x237C7C, // 7C 7C [23]   '||' [#]
    0x0D7D7D, // 7D 7D [0D]   '}}' [.]
    0x087E7E, // 7E 7E [08]   '~~' [.]
    0x267F7F, // 7F 7F [26]   '..' [&]
    0x388080, // 80 80 [38]   '..' [8]
    0x168181, // 81 81 [16]   '..' [.]
    0x138282, // 82 82 [13]   '..' [.]
    0x3D8383, // 83 83 [3D]   '..' [=]
    0x318484, // 84 84 [31]   '..' [1]
    0x1F8585, // 85 85 [1F]   '..' [.]
    0x1A8686, // 86 86 [1A]   '..' [.]
    0x348787, // 87 87 [34]   '..' [4]
    0x0E8888, // 88 88 [0E]   '..' [.]
    0x208989, // 89 89 [20]   '..' [ ]
    0x258A8A, // 8A 8A [25]   '..' [%]
    0x0B8B8B, // 8B 8B [0B]   '..' [.]
    0x078C8C, // 8C 8C [07]   '..' [.]
    0x298D8D, // 8D 8D [29]   '..' [)]
    0x2C8E8E, // 8E 8E [2C]   '..' [,]
    0x028F8F, // 8F 8F [02]   '..' [.]
    0x239090, // 90 90 [23]   '..' [#]
    0x0D9191, // 91 91 [0D]   '..' [.]
    0x089292, // 92 92 [08]   '..' [.]
    0x269393, // 93 93 [26]   '..' [&]
    0x2A9494, // 94 94 [2A]   '..' [*]
    0x049595, // 95 95 [04]   '..' [.]
    0x019696, // 96 96 [01]   '..' [.]
    0x2F9797, // 97 97 [2F]   '..' [/]
    0x159898, // 98 98 [15]   '..' [.]
    0x3B9999, // 99 99 [3B]   '..' [;]
    0x3E9A9A, // 9A 9A [3E]   '..' [>]
    0x109B9B, // 9B 9B [10]   '..' [.]
    0x1C9C9C, // 9C 9C [1C]   '..' [.]
    0x329D9D, // 9D 9D [32]   '..' [2]
    0x379E9E, // 9E 9E [37]   '..' [7]
    0x199F9F, // 9F 9F [19]   '..' [.]
    0x01A0A0, // A0 A0 [01]   '..' [.]
    0x2FA1A1, // A1 A1 [2F]   '..' [/]
    0x2AA2A2, // A2 A2 [2A]   '..' [*]
    0x04A3A3, // A3 A3 [04]   '..' [.]
    0x08A4A4, // A4 A4 [08]   '..' [.]
    0x26A5A5, // A5 A5 [26]   '..' [&]
    0x23A6A6, // A6 A6 [23]   '..' [#]
    0x0DA7A7, // A7 A7 [0D]   '..' [.]
    0x37A8A8, // A8 A8 [37]   '..' [7]
    0x19A9A9, // A9 A9 [19]   '..' [.]
    0x1CAAAA, // AA AA [1C]   '..' [.]
    0x32ABAB, // AB AB [32]   '..' [2]
    0x3EACAC, // AC AC [3E]   '..' [>]
    0x10ADAD, // AD AD [10]   '..' [.]
    0x15AEAE, // AE AE [15]   '..' [.]
    0x3BAFAF, // AF AF [3B]   '..' [;]
    0x1AB0B0, // B0 B0 [1A]   '..' [.]
    0x34B1B1, // B1 B1 [34]   '..' [4]
    0x31B2B2, // B2 B2 [31]   '..' [1]
    0x1FB3B3, // B3 B3 [1F]   '..' [.]
    0x13B4B4, // B4 B4 [13]   '..' [.]
    0x3DB5B5, // B5 B5 [3D]   '..' [=]
    0x38B6B6, // B6 B6 [38]   '..' [8]
    0x16B7B7, // B7 B7 [16]   '..' [.]
    0x2CB8B8, // B8 B8 [2C]   '..' [,]
    0x02B9B9, // B9 B9 [02]   '..' [.]
    0x07BABA, // BA BA [07]   '..' [.]
    0x29BBBB, // BB BB [29]   '..' [)]
    0x25BCBC, // BC BC [25]   '..' [%]
    0x0BBDBD, // BD BD [0B]   '..' [.]
    0x0EBEBE, // BE BE [0E]   '..' [.]
    0x20BFBF, // BF BF [20]   '..' [ ]
    0x07C0C0, // C0 C0 [07]   '..' [.]
    0x29C1C1, // C1 C1 [29]   '..' [)]
    0x2CC2C2, // C2 C2 [2C]   '..' [,]
    0x02C3C3, // C3 C3 [02]   '..' [.]
    0x0EC4C4, // C4 C4 [0E]   '..' [.]
    0x20C5C5, // C5 C5 [20]   '..' [ ]
    0x25C6C6, // C6 C6 [25]   '..' [%]
    0x0BC7C7, // C7 C7 [0B]   '..' [.]
    0x31C8C8, // C8 C8 [31]   '..' [1]
    0x1FC9C9, // C9 C9 [1F]   '..' [.]
    0x1ACACA, // CA CA [1A]   '..' [.]
    0x34CBCB, // CB CB [34]   '..' [4]
    0x38CCCC, // CC CC [38]   '..' [8]
    0x16CDCD, // CD CD [16]   '..' [.]
    0x13CECE, // CE CE [13]   '..' [.]
    0x3DCFCF, // CF CF [3D]   '..' [=]
    0x1CD0D0, // D0 D0 [1C]   '..' [.]
    0x32D1D1, // D1 D1 [32]   '..' [2]
    0x37D2D2, // D2 D2 [37]   '..' [7]
    0x19D3D3, // D3 D3 [19]   '..' [.]
    0x15D4D4, // D4 D4 [15]   '..' [.]
    0x3BD5D5, // D5 D5 [3B]   '..' [;]
    0x3ED6D6, // D6 D6 [3E]   '..' [>]
    0x10D7D7, // D7 D7 [10]   '..' [.]
    0x2AD8D8, // D8 D8 [2A]   '..' [*]
    0x04D9D9, // D9 D9 [04]   '..' [.]
    0x01DADA, // DA DA [01]   '..' [.]
    0x2FDBDB, // DB DB [2F]   '..' [/]
    0x23DCDC, // DC DC [23]   '..' [#]
    0x0DDDDD, // DD DD [0D]   '..' [.]
    0x08DEDE, // DE DE [08]   '..' [.]
    0x26DFDF, // DF DF [26]   '..' [&]
    0x3EE0E0, // E0 E0 [3E]   '..' [>]
    0x10E1E1, // E1 E1 [10]   '..' [.]
    0x15E2E2, // E2 E2 [15]   '..' [.]
    0x3BE3E3, // E3 E3 [3B]   '..' [;]
    0x37E4E4, // E4 E4 [37]   '..' [7]
    0x19E5E5, // E5 E5 [19]   '..' [.]
    0x1CE6E6, // E6 E6 [1C]   '..' [.]
    0x32E7E7, // E7 E7 [32]   '..' [2]
    0x08E8E8, // E8 E8 [08]   '..' [.]
    0x26E9E9, // E9 E9 [26]   '..' [&]
    0x23EAEA, // EA EA [23]   '..' [#]
    0x0DEBEB, // EB EB [0D]   '..' [.]
    0x01ECEC, // EC EC [01]   '..' [.]
    0x2FEDED, // ED ED [2F]   '..' [/]
    0x2AEEEE, // EE EE [2A]   '..' [*]
    0x04EFEF, // EF EF [04]   '..' [.]
    0x25F0F0, // F0 F0 [25]   '..' [%]
    0x0BF1F1, // F1 F1 [0B]   '..' [.]
    0x0EF2F2, // F2 F2 [0E]   '..' [.]
    0x20F3F3, // F3 F3 [20]   '..' [ ]
    0x2CF4F4, // F4 F4 [2C]   '..' [,]
    0x02F5F5, // F5 F5 [02]   '..' [.]
    0x07F6F6, // F6 F6 [07]   '..' [.]
    0x29F7F7, // F7 F7 [29]   '..' [)]
    0x13F8F8, // F8 F8 [13]   '..' [.]
    0x3DF9F9, // F9 F9 [3D]   '..' [=]
    0x38FAFA, // FA FA [38]   '..' [8]
    0x16FBFB, // FB FB [16]   '..' [.]
    0x1AFCFC, // FC FC [1A]   '..' [.]
    0x34FDFD, // FD FD [34]   '..' [4]
    0x31FEFE, // FE FE [31]   '..' [1]
    0x1FFFFF, // FF FF [1F]   '..' [.]
};
const otp_zone_raw_buffer_t ecc_1_to_0 = {
    0x000000, // 00 00 [00]   '..' [.]
    0x2E0100, // 00 01 [2E]   '..' [.]
    0x2B0200, // 00 02 [2B]   '..' [+]
    0x050203, // 03 02 [05]   '..' [.]
    0x090400, // 00 04 [09]   '..' [.]
    0x270105, // 05 01 [27]   '..' [']
    0x220406, // 06 04 [22]   '..' ["]
    0x0C0706, // 06 07 [0C]   '..' [.]
    0x360800, // 00 08 [36]   '..' [6]
    0x180109, // 09 01 [18]   '..' [.]
    0x1D0A08, // 08 0A [1D]   '..' [.]
    0x330B0A, // 0A 0B [33]   '..' [3]
    0x3F0C08, // 08 0C [3F]   '..' [?]
    0x110D0C, // 0C 0D [11]   '..' [.]
    0x140E0C, // 0C 0E [14]   '..' [.]
    0x3A0F0E, // 0E 0F [3A]   '..' [:]
    0x1B1000, // 00 10 [1B]   '..' [.]
    0x350111, // 11 01 [35]   '..' [5]
    0x301210, // 10 12 [30]   '..' [0]
    0x1E1312, // 12 13 [1E]   '..' [.]
    0x121410, // 10 14 [12]   '..' [.]
    0x3C1514, // 14 15 [3C]   '..' [<]
    0x391614, // 14 16 [39]   '..' [9]
    0x171716, // 16 17 [17]   '..' [.]
    0x2D1810, // 10 18 [2D]   '..' [-]
    0x031918, // 18 19 [03]   '..' [.]
    0x061A18, // 18 1A [06]   '..' [.]
    0x281B1A, // 1A 1B [28]   '..' [(]
    0x241C18, // 18 1C [24]   '..' [$]
    0x0A1D1C, // 1C 1D [0A]   '..' [.]
    0x0F1E1C, // 1C 1E [0F]   '..' [.]
    0x211F1E, // 1E 1F [21]   '..' [!]
    0x392000, // 00 20 [39]   '. ' [9]
    0x170121, // 21 01 [17]   '!.' [.]
    0x122220, // 20 22 [12]   ' "' [.]
    0x3C2322, // 22 23 [3C]   '"#' [<]
    0x302420, // 20 24 [30]   ' $' [0]
    0x1E2524, // 24 25 [1E]   '$%' [.]
    0x1B2624, // 24 26 [1B]   '$&' [.]
    0x352726, // 26 27 [35]   '&'' [5]
    0x0F2820, // 20 28 [0F]   ' (' [.]
    0x212928, // 28 29 [21]   '()' [!]
    0x242A28, // 28 2A [24]   '(*' [$]
    0x0A2B2A, // 2A 2B [0A]   '*+' [.]
    0x062C28, // 28 2C [06]   '(,' [.]
    0x282D2C, // 2C 2D [28]   ',-' [(]
    0x2D2E2C, // 2C 2E [2D]   ',.' [-]
    0x032F2E, // 2E 2F [03]   './' [.]
    0x223020, // 20 30 [22]   ' 0' ["]
    0x0C3130, // 30 31 [0C]   '01' [.]
    0x093230, // 30 32 [09]   '02' [.]
    0x273332, // 32 33 [27]   '23' [']
    0x2B3430, // 30 34 [2B]   '04' [+]
    0x053534, // 34 35 [05]   '45' [.]
    0x003634, // 34 36 [00]   '46' [.]
    0x2E3736, // 36 37 [2E]   '67' [.]
    0x143830, // 30 38 [14]   '08' [.]
    0x3A3938, // 38 39 [3A]   '89' [:]
    0x3F3A38, // 38 3A [3F]   '8:' [?]
    0x113B3A, // 3A 3B [11]   ':;' [.]
    0x1D3C38, // 38 3C [1D]   '8<' [.]
    0x333D3C, // 3C 3D [33]   '<=' [3]
    0x363E3C, // 3C 3E [36]   '<>' [6]
    0x183F3E, // 3E 3F [18]   '>?' [.]
    0x3F4000, // 00 40 [3F]   '.@' [?]
    0x110141, // 41 01 [11]   'A.' [.]
    0x144240, // 40 42 [14]   '@B' [.]
    0x3A4342, // 42 43 [3A]   'BC' [:]
    0x364440, // 40 44 [36]   '@D' [6]
    0x184544, // 44 45 [18]   'DE' [.]
    0x1D4644, // 44 46 [1D]   'DF' [.]
    0x334746, // 46 47 [33]   'FG' [3]
    0x094840, // 40 48 [09]   '@H' [.]
    0x274948, // 48 49 [27]   'HI' [']
    0x224A48, // 48 4A [22]   'HJ' ["]
    0x0C4B4A, // 4A 4B [0C]   'JK' [.]
    0x004C48, // 48 4C [00]   'HL' [.]
    0x2E4D4C, // 4C 4D [2E]   'LM' [.]
    0x2B4E4C, // 4C 4E [2B]   'LN' [+]
    0x054F4E, // 4E 4F [05]   'NO' [.]
    0x245040, // 40 50 [24]   '@P' [$]
    0x0A5150, // 50 51 [0A]   'PQ' [.]
    0x0F5250, // 50 52 [0F]   'PR' [.]
    0x215352, // 52 53 [21]   'RS' [!]
    0x2D5450, // 50 54 [2D]   'PT' [-]
    0x035554, // 54 55 [03]   'TU' [.]
    0x065654, // 54 56 [06]   'TV' [.]
    0x285756, // 56 57 [28]   'VW' [(]
    0x125850, // 50 58 [12]   'PX' [.]
    0x3C5958, // 58 59 [3C]   'XY' [<]
    0x395A58, // 58 5A [39]   'XZ' [9]
    0x175B5A, // 5A 5B [17]   'Z[' [.]
    0x1B5C58, // 58 5C [1B]   'X\' [.]
    0x355D5C, // 5C 5D [35]   '\]' [5]
    0x305E5C, // 5C 5E [30]   '\^' [0]
    0x1E5F5E, // 5E 5F [1E]   '^_' [.]
    0x066040, // 40 60 [06]   '@`' [.]
    0x286160, // 60 61 [28]   '`a' [(]
    0x2D6260, // 60 62 [2D]   '`b' [-]
    0x036362, // 62 63 [03]   'bc' [.]
    0x0F6460, // 60 64 [0F]   '`d' [.]
    0x216564, // 64 65 [21]   'de' [!]
    0x246664, // 64 66 [24]   'df' [$]
    0x0A6766, // 66 67 [0A]   'fg' [.]
    0x306860, // 60 68 [30]   '`h' [0]
    0x1E6968, // 68 69 [1E]   'hi' [.]
    0x1B6A68, // 68 6A [1B]   'hj' [.]
    0x356B6A, // 6A 6B [35]   'jk' [5]
    0x396C68, // 68 6C [39]   'hl' [9]
    0x176D6C, // 6C 6D [17]   'lm' [.]
    0x126E6C, // 6C 6E [12]   'ln' [.]
    0x3C6F6E, // 6E 6F [3C]   'no' [<]
    0x1D7060, // 60 70 [1D]   '`p' [.]
    0x337170, // 70 71 [33]   'pq' [3]
    0x367270, // 70 72 [36]   'pr' [6]
    0x187372, // 72 73 [18]   'rs' [.]
    0x147470, // 70 74 [14]   'pt' [.]
    0x3A7574, // 74 75 [3A]   'tu' [:]
    0x3F7674, // 74 76 [3F]   'tv' [?]
    0x117776, // 76 77 [11]   'vw' [.]
    0x2B7870, // 70 78 [2B]   'px' [+]
    0x057978, // 78 79 [05]   'xy' [.]
    0x007A78, // 78 7A [00]   'xz' [.]
    0x2E7B7A, // 7A 7B [2E]   'z{' [.]
    0x227C78, // 78 7C [22]   'x|' ["]
    0x0C7D7C, // 7C 7D [0C]   '|}' [.]
    0x097E7C, // 7C 7E [09]   '|~' [.]
    0x277F7E, // 7E 7F [27]   '~.' [']
    0x398000, // 00 80 [39]   '..' [9]
    0x170181, // 81 01 [17]   '..' [.]
    0x128280, // 80 82 [12]   '..' [.]
    0x3C8382, // 82 83 [3C]   '..' [<]
    0x308480, // 80 84 [30]   '..' [0]
    0x1E8584, // 84 85 [1E]   '..' [.]
    0x1B8684, // 84 86 [1B]   '..' [.]
    0x358786, // 86 87 [35]   '..' [5]
    0x0F8880, // 80 88 [0F]   '..' [.]
    0x218988, // 88 89 [21]   '..' [!]
    0x248A88, // 88 8A [24]   '..' [$]
    0x0A8B8A, // 8A 8B [0A]   '..' [.]
    0x068C88, // 88 8C [06]   '..' [.]
    0x288D8C, // 8C 8D [28]   '..' [(]
    0x2D8E8C, // 8C 8E [2D]   '..' [-]
    0x038F8E, // 8E 8F [03]   '..' [.]
    0x229080, // 80 90 [22]   '..' ["]
    0x0C9190, // 90 91 [0C]   '..' [.]
    0x099290, // 90 92 [09]   '..' [.]
    0x279392, // 92 93 [27]   '..' [']
    0x2B9490, // 90 94 [2B]   '..' [+]
    0x059594, // 94 95 [05]   '..' [.]
    0x009694, // 94 96 [00]   '..' [.]
    0x2E9796, // 96 97 [2E]   '..' [.]
    0x149890, // 90 98 [14]   '..' [.]
    0x3A9998, // 98 99 [3A]   '..' [:]
    0x3F9A98, // 98 9A [3F]   '..' [?]
    0x119B9A, // 9A 9B [11]   '..' [.]
    0x1D9C98, // 98 9C [1D]   '..' [.]
    0x339D9C, // 9C 9D [33]   '..' [3]
    0x369E9C, // 9C 9E [36]   '..' [6]
    0x189F9E, // 9E 9F [18]   '..' [.]
    0x00A080, // 80 A0 [00]   '..' [.]
    0x2EA1A0, // A0 A1 [2E]   '..' [.]
    0x2BA2A0, // A0 A2 [2B]   '..' [+]
    0x05A3A2, // A2 A3 [05]   '..' [.]
    0x09A4A0, // A0 A4 [09]   '..' [.]
    0x27A5A4, // A4 A5 [27]   '..' [']
    0x22A6A4, // A4 A6 [22]   '..' ["]
    0x0CA7A6, // A6 A7 [0C]   '..' [.]
    0x36A8A0, // A0 A8 [36]   '..' [6]
    0x18A9A8, // A8 A9 [18]   '..' [.]
    0x1DAAA8, // A8 AA [1D]   '..' [.]
    0x33ABAA, // AA AB [33]   '..' [3]
    0x3FACA8, // A8 AC [3F]   '..' [?]
    0x11ADAC, // AC AD [11]   '..' [.]
    0x14AEAC, // AC AE [14]   '..' [.]
    0x3AAFAE, // AE AF [3A]   '..' [:]
    0x1BB0A0, // A0 B0 [1B]   '..' [.]
    0x35B1B0, // B0 B1 [35]   '..' [5]
    0x30B2B0, // B0 B2 [30]   '..' [0]
    0x1EB3B2, // B2 B3 [1E]   '..' [.]
    0x12B4B0, // B0 B4 [12]   '..' [.]
    0x3CB5B4, // B4 B5 [3C]   '..' [<]
    0x39B6B4, // B4 B6 [39]   '..' [9]
    0x17B7B6, // B6 B7 [17]   '..' [.]
    0x2DB8B0, // B0 B8 [2D]   '..' [-]
    0x03B9B8, // B8 B9 [03]   '..' [.]
    0x06BAB8, // B8 BA [06]   '..' [.]
    0x28BBBA, // BA BB [28]   '..' [(]
    0x24BCB8, // B8 BC [24]   '..' [$]
    0x0ABDBC, // BC BD [0A]   '..' [.]
    0x0FBEBC, // BC BE [0F]   '..' [.]
    0x21BFBE, // BE BF [21]   '..' [!]
    0x06C080, // 80 C0 [06]   '..' [.]
    0x28C1C0, // C0 C1 [28]   '..' [(]
    0x2DC2C0, // C0 C2 [2D]   '..' [-]
    0x03C3C2, // C2 C3 [03]   '..' [.]
    0x0FC4C0, // C0 C4 [0F]   '..' [.]
    0x21C5C4, // C4 C5 [21]   '..' [!]
    0x24C6C4, // C4 C6 [24]   '..' [$]
    0x0AC7C6, // C6 C7 [0A]   '..' [.]
    0x30C8C0, // C0 C8 [30]   '..' [0]
    0x1EC9C8, // C8 C9 [1E]   '..' [.]
    0x1BCAC8, // C8 CA [1B]   '..' [.]
    0x35CBCA, // CA CB [35]   '..' [5]
    0x39CCC8, // C8 CC [39]   '..' [9]
    0x17CDCC, // CC CD [17]   '..' [.]
    0x12CECC, // CC CE [12]   '..' [.]
    0x3CCFCE, // CE CF [3C]   '..' [<]
    0x1DD0C0, // C0 D0 [1D]   '..' [.]
    0x33D1D0, // D0 D1 [33]   '..' [3]
    0x36D2D0, // D0 D2 [36]   '..' [6]
    0x18D3D2, // D2 D3 [18]   '..' [.]
    0x14D4D0, // D0 D4 [14]   '..' [.]
    0x3AD5D4, // D4 D5 [3A]   '..' [:]
    0x3FD6D4, // D4 D6 [3F]   '..' [?]
    0x11D7D6, // D6 D7 [11]   '..' [.]
    0x2BD8D0, // D0 D8 [2B]   '..' [+]
    0x05D9D8, // D8 D9 [05]   '..' [.]
    0x00DAD8, // D8 DA [00]   '..' [.]
    0x2EDBDA, // DA DB [2E]   '..' [.]
    0x22DCD8, // D8 DC [22]   '..' ["]
    0x0CDDDC, // DC DD [0C]   '..' [.]
    0x09DEDC, // DC DE [09]   '..' [.]
    0x27DFDE, // DE DF [27]   '..' [']
    0x3FE0C0, // C0 E0 [3F]   '..' [?]
    0x11E1E0, // E0 E1 [11]   '..' [.]
    0x14E2E0, // E0 E2 [14]   '..' [.]
    0x3AE3E2, // E2 E3 [3A]   '..' [:]
    0x36E4E0, // E0 E4 [36]   '..' [6]
    0x18E5E4, // E4 E5 [18]   '..' [.]
    0x1DE6E4, // E4 E6 [1D]   '..' [.]
    0x33E7E6, // E6 E7 [33]   '..' [3]
    0x09E8E0, // E0 E8 [09]   '..' [.]
    0x27E9E8, // E8 E9 [27]   '..' [']
    0x22EAE8, // E8 EA [22]   '..' ["]
    0x0CEBEA, // EA EB [0C]   '..' [.]
    0x00ECE8, // E8 EC [00]   '..' [.]
    0x2EEDEC, // EC ED [2E]   '..' [.]
    0x2BEEEC, // EC EE [2B]   '..' [+]
    0x05EFEE, // EE EF [05]   '..' [.]
    0x24F0E0, // E0 F0 [24]   '..' [$]
    0x0AF1F0, // F0 F1 [0A]   '..' [.]
    0x0FF2F0, // F0 F2 [0F]   '..' [.]
    0x21F3F2, // F2 F3 [21]   '..' [!]
    0x2DF4F0, // F0 F4 [2D]   '..' [-]
    0x03F5F4, // F4 F5 [03]   '..' [.]
    0x06F6F4, // F4 F6 [06]   '..' [.]
    0x28F7F6, // F6 F7 [28]   '..' [(]
    0x12F8F0, // F0 F8 [12]   '..' [.]
    0x3CF9F8, // F8 F9 [3C]   '..' [<]
    0x39FAF8, // F8 FA [39]   '..' [9]
    0x17FBFA, // FA FB [17]   '..' [.]
    0x1BFCF8, // F8 FC [1B]   '..' [.]
    0x35FDFC, // FC FD [35]   '..' [5]
    0x30FEFC, // FC FE [30]   '..' [0]
    0x1EFFFE, // FE FF [1E]   '..' [.]
};
const otp_zone_raw_buffer_t ecc_multibit = {
    0x000003, // 03 00 [00]   '..' [.]
    0x2E0104, // 04 01 [2E]   '..' [.]
    0x2B020B, // 0B 02 [2B]   '..' [+]
    0x050312, // 12 03 [05]   '..' [.]
    0x090425, // 25 04 [09]   '%.' [.]
    0x270544, // 44 05 [27]   'D.' [']
    0x220687, // 87 06 [22]   '..' ["]
    0x0C0606, // 06 06 [0C]   '..' [.]
    0x360A09, // 09 0A [36]   '..' [6]
    0x180D08, // 08 0D [18]   '..' [.]
    0x1D020B, // 0B 02 [1D]   '..' [.]
    0x331B0A, // 0A 1B [33]   '..' [3]
    0x3F2C0D, // 0D 2C [3F]   '.,' [?]
    0x114D0C, // 0C 4D [11]   '.M' [.]
    0x148E0F, // 0F 8E [14]   '..' [.]
    0x3B0F0E, // 0E 0F [3B]   '..' [;]
    0x191011, // 11 10 [19]   '..' [.]
    0x311110, // 10 11 [31]   '..' [1]
    0x381213, // 13 12 [38]   '..' [8]
    0x0E1312, // 12 13 [0E]   '..' [.]
    0x321415, // 15 14 [32]   '..' [2]
    0x7C1514, // 14 15 [7C]   '..' [|]
    0xB91617, // 17 16 [B9]   '..' [.]
    0x171711, // 11 17 [17]   '..' [.]
    0x2D1812, // 12 18 [2D]   '..' [-]
    0x03190B, // 0B 19 [03]   '..' [.]
    0x061A38, // 38 1A [06]   '8.' [.]
    0x281B59, // 59 1B [28]   'Y.' [(]
    0x241C9E, // 9E 1C [24]   '..' [$]
    0x0A1C1F, // 1F 1C [0A]   '..' [.]
    0x0F1C1C, // 1C 1C [0F]   '..' [.]
    0x211B1D, // 1D 1B [21]   '..' [!]
    0x392822, // 22 28 [39]   '"(' [9]
    0x173123, // 23 31 [17]   '#1' [.]
    0x120220, // 20 02 [12]   ' .' [.]
    0x3C6321, // 21 63 [3C]   '!c' [<]
    0x30A426, // 26 A4 [30]   '&.' [0]
    0x1F2527, // 27 25 [1F]   ''%' [.]
    0x192624, // 24 26 [19]   '$&' [.]
    0x312725, // 25 27 [31]   '%'' [1]
    0x07282A, // 2A 28 [07]   '*(' [.]
    0x31292B, // 2B 29 [31]   '+)' [1]
    0x042A28, // 28 2A [04]   '(*' [.]
    0x4A2B29, // 29 2B [4A]   ')+' [J]
    0x862C2E, // 2E 2C [86]   '.,' [.]
    0x282D21, // 21 2D [28]   '!-' [(]
    0x2D2E3A, // 3A 2E [2D]   ':.' [-]
    0x032F0B, // 0B 2F [03]   './' [.]
    0x223074, // 74 30 [22]   't0' ["]
    0x0C31B5, // B5 31 [0C]   '.1' [.]
    0x093336, // 36 33 [09]   '63' [.]
    0x273137, // 37 31 [27]   '71' [']
    0x2B3030, // 30 30 [2B]   '00' [+]
    0x053D31, // 31 3D [05]   '1=' [.]
    0x002632, // 32 26 [00]   '2&' [.]
    0x2E1733, // 33 17 [2E]   '3.' [.]
    0x14783C, // 3C 78 [14]   '<x' [.]
    0x3AB93D, // 3D B9 [3A]   '=.' [:]
    0x3E3A3E, // 3E 3A [3E]   '>:' [>]
    0x133B3F, // 3F 3B [13]   '?;' [.]
    0x193C38, // 38 3C [19]   '8<' [.]
    0x3B3D39, // 39 3D [3B]   '9=' [;]
    0x263E3A, // 3A 3E [26]   ':>' [&]
    0x383F3B, // 3B 3F [38]   ';?' [8]
    0x7F4044, // 44 40 [7F]   'D@' [.]
    0x914145, // 45 41 [91]   'EA' [.]
    0x14425A, // 5A 42 [14]   'ZB' [.]
    0x3A436B, // 6B 43 [3A]   'kC' [:]
    0x36440C, // 0C 44 [36]   '.D' [6]
    0x1845CD, // CD 45 [18]   '.E' [.]
    0x1D474E, // 4E 47 [1D]   'NG' [.]
    0x33454F, // 4F 45 [33]   'OE' [3]
    0x094C40, // 40 4C [09]   '@L' [.]
    0x274141, // 41 41 [27]   'AA' [']
    0x225A42, // 42 5A [22]   'BZ' ["]
    0x0C6B43, // 43 6B [0C]   'Ck' [.]
    0x000C44, // 44 0C [00]   'D.' [.]
    0x2ECD45, // 45 CD [2E]   'E.' [.]
    0x2A4E46, // 46 4E [2A]   'FN' [*]
    0x074F47, // 47 4F [07]   'GO' [.]
    0x205058, // 58 50 [20]   'XP' [ ]
    0x025159, // 59 51 [02]   'YQ' [.]
    0x1F525A, // 5A 52 [1F]   'ZR' [.]
    0x01535B, // 5B 53 [01]   '[S' [.]
    0x6D545C, // 5C 54 [6D]   '\T' [m]
    0x83555D, // 5D 55 [83]   ']U' [.]
    0x065666, // 66 56 [06]   'fV' [.]
    0x285707, // 07 57 [28]   '.W' [(]
    0x1258C8, // C8 58 [12]   '.X' [.]
    0x3C5849, // 49 58 [3C]   'IX' [<]
    0x39584A, // 4A 58 [39]   'JX' [9]
    0x175F4B, // 4B 5F [17]   'K_' [.]
    0x1B544C, // 4C 54 [1B]   'LT' [.]
    0x354D4D, // 4D 4D [35]   'MM' [5]
    0x307E4E, // 4E 7E [30]   'N~' [0]
    0x1E1F4F, // 4F 1F [1E]   'O.' [.]
    0x06E070, // 70 E0 [06]   'p.' [.]
    0x296171, // 71 61 [29]   'qa' [)]
    0x2F6272, // 72 62 [2F]   'rb' [/]
    0x076373, // 73 63 [07]   'sc' [.]
    0x076474, // 74 64 [07]   'td' [.]
    0x316575, // 75 65 [31]   'ue' [1]
    0x046676, // 76 66 [04]   'vf' [.]
    0x4A6777, // 77 67 [4A]   'wg' [J]
    0xB06878, // 78 68 [B0]   'xh' [.]
    0x1E6909, // 09 69 [1E]   '.i' [.]
    0x1B6ACA, // CA 6A [1B]   '.j' [.]
    0x356A4B, // 4B 6A [35]   'Kj' [5]
    0x396E4C, // 4C 6E [39]   'Ln' [9]
    0x17694D, // 4D 69 [17]   'Mi' [.]
    0x12664E, // 4E 66 [12]   'Nf' [.]
    0x3C7F4F, // 4F 7F [3C]   'O.' [<]
    0x1D5050, // 50 50 [1D]   'PP' [.]
    0x333151, // 51 31 [33]   'Q1' [3]
    0x36F252, // 52 F2 [36]   'R.' [6]
    0x197353, // 53 73 [19]   'Ss' [.]
    0x167454, // 54 74 [16]   'Tt' [.]
    0x3E7555, // 55 75 [3E]   'Uu' [>]
    0x377656, // 56 76 [37]   'Vv' [7]
    0x017757, // 57 77 [01]   'Ww' [.]
    0x0B7858, // 58 78 [0B]   'Xx' [.]
    0x457959, // 59 79 [45]   'Yy' [E]
    0x807A5A, // 5A 7A [80]   'Zz' [.]
    0x2E7BBB, // BB 7B [2E]   '.{' [.]
    0x227D3C, // 3C 7D [22]   '<}' ["]
    0x0C7F3D, // 3D 7F [0C]   '=.' [.]
    0x097A3E, // 3E 7A [09]   '>z' [.]
    0x27773F, // 3F 77 [27]   '?w' [']
    0x3990C0, // C0 90 [39]   '..' [9]
    0x17A1C1, // C1 A1 [17]   '..' [.]
    0x12C2C2, // C2 C2 [12]   '..' [.]
    0x3C03C3, // C3 03 [3C]   '..' [<]
    0x3184C4, // C4 84 [31]   '..' [1]
    0x1C85C5, // C5 85 [1C]   '..' [.]
    0x1F86C6, // C6 86 [1F]   '..' [.]
    0x3D87C7, // C7 87 [3D]   '..' [=]
    0x1F88C8, // C8 88 [1F]   '..' [.]
    0x0189C9, // C9 89 [01]   '..' [.]
    0x648ACA, // CA 8A [64]   '..' [d]
    0x8A8BCB, // CB 8B [8A]   '..' [.]
    0x068D0C, // 0C 8D [06]   '..' [.]
    0x288F0D, // 0D 8F [28]   '..' [(]
    0x2D8A0E, // 0E 8A [2D]   '..' [-]
    0x03870F, // 0F 87 [03]   '..' [.]
    0x228010, // 10 80 [22]   '..' ["]
    0x0CB111, // 11 B1 [0C]   '..' [.]
    0x09D212, // 12 D2 [09]   '..' [.]
    0x271313, // 13 13 [27]   '..' [']
    0x2A9414, // 14 94 [2A]   '..' [*]
    0x079515, // 15 95 [07]   '..' [.]
    0x049616, // 16 96 [04]   '..' [.]
    0x269717, // 17 97 [26]   '..' [&]
    0x049818, // 18 98 [04]   '..' [.]
    0x1A9919, // 19 99 [1A]   '..' [.]
    0x7F9A1A, // 1A 9A [7F]   '..' [.]
    0x919B1B, // 1B 9B [91]   '..' [.]
    0x1D9F9C, // 9C 9F [1D]   '..' [.]
    0x33989D, // 9D 98 [33]   '..' [3]
    0x36979E, // 9E 97 [36]   '..' [6]
    0x188E9F, // 9F 8E [18]   '..' [.]
    0x0081A0, // A0 81 [00]   '..' [.]
    0x2EE0A1, // A1 E0 [2E]   '..' [.]
    0x2B23A2, // A2 23 [2B]   '.#' [+]
    0x04A2A3, // A3 A2 [04]   '..' [.]
    0x0BA5A4, // A4 A5 [0B]   '..' [.]
    0x23A4A5, // A5 A4 [23]   '..' [#]
    0x2AA7A6, // A6 A7 [2A]   '..' [*]
    0x1CA6A7, // A7 A6 [1C]   '..' [.]
    0x16A9A8, // A8 A9 [16]   '..' [.]
    0x58A8A9, // A9 A8 [58]   '..' [X]
    0x9DABAA, // AA AB [9D]   '..' [.]
    0x33ADAB, // AB AD [33]   '..' [3]
    0x3FA6AC, // AC A6 [3F]   '..' [?]
    0x11BFAD, // AD BF [11]   '..' [.]
    0x148CAE, // AE 8C [14]   '..' [.]
    0x3AEDAF, // AF ED [3A]   '..' [:]
    0x1B32B0, // B0 32 [1B]   '.2' [.]
    0x34B3B1, // B1 B3 [34]   '..' [4]
    0x32B0B2, // B2 B0 [32]   '..' [2]
    0x1AB1B3, // B3 B1 [1A]   '..' [.]
    0x1AB6B4, // B4 B6 [1A]   '..' [.]
    0x2CB7B5, // B5 B7 [2C]   '..' [,]
    0x19B4B6, // B6 B4 [19]   '..' [.]
    0x57B5B7, // B7 B5 [57]   '..' [W]
    0xADBAB8, // B8 BA [AD]   '..' [.]
    0x03B5B9, // B9 B5 [03]   '..' [.]
    0x06AEBA, // BA AE [06]   '..' [.]
    0x289FBB, // BB 9F [28]   '..' [(]
    0x24F8BC, // BC F8 [24]   '..' [$]
    0x0A39BD, // BD 39 [0A]   '.9' [.]
    0x0EBABE, // BE BA [0E]   '..' [.]
    0x23BBBF, // BF BB [23]   '..' [#]
    0x02C4C0, // C0 C4 [02]   '..' [.]
    0x20C5C1, // C1 C5 [20]   '..' [ ]
    0x3DC6C2, // C2 C6 [3D]   '..' [=]
    0x23C7C3, // C3 C7 [23]   '..' [#]
    0x4FC0C4, // C4 C0 [4F]   '..' [O]
    0xA1C1C5, // C5 C1 [A1]   '..' [.]
    0x24DEC6, // C6 DE [24]   '..' [$]
    0x0AEFC7, // C7 EF [0A]   '..' [.]
    0x3080C8, // C8 80 [30]   '..' [0]
    0x1E41C9, // C9 41 [1E]   '.A' [.]
    0x1AC2CA, // CA C2 [1A]   '..' [.]
    0x37C3CB, // CB C3 [37]   '..' [7]
    0x3DC4CC, // CC C4 [3D]   '..' [=]
    0x1FC5CD, // CD C5 [1F]   '..' [.]
    0x02C6CE, // CE C6 [02]   '..' [.]
    0x1CC7CF, // CF C7 [1C]   '..' [.]
    0x5DD8D0, // D0 D8 [5D]   '..' []]
    0xB3D9D1, // D1 D9 [B3]   '..' [.]
    0x36E2D2, // D2 E2 [36]   '..' [6]
    0x1883D3, // D3 83 [18]   '..' [.]
    0x1444D4, // D4 44 [14]   '.D' [.]
    0x3BC5D5, // D5 C5 [3B]   '..' [;]
    0x3DC6D6, // D6 C6 [3D]   '..' [=]
    0x15C7D7, // D7 C7 [15]   '..' [.]
    0x23C8D8, // D8 C8 [23]   '..' [#]
    0x15C9D9, // D9 C9 [15]   '..' [.]
    0x20CADA, // DA CA [20]   '..' [ ]
    0x6ECBDB, // DB CB [6E]   '..' [n]
    0xA2CCDC, // DC CC [A2]   '..' [.]
    0x0CBDDD, // DD BD [0C]   '..' [.]
    0x097EDE, // DE 7E [09]   '.~' [.]
    0x26FFDF, // DF FF [26]   '..' [&]
    0x3DC0E0, // E0 C0 [3D]   '..' [=]
    0x15C1E1, // E1 C1 [15]   '..' [.]
    0x1CC2E2, // E2 C2 [1C]   '..' [.]
    0x2AC3E3, // E3 C3 [2A]   '..' [*]
    0x16C4E4, // E4 C4 [16]   '..' [.]
    0x58C5E5, // E5 C5 [58]   '..' [X]
    0x9DC6E6, // E6 C6 [9D]   '..' [.]
    0x3327E7, // E7 27 [33]   '.'' [3]
    0x08A8E8, // E8 A8 [08]   '..' [.]
    0x25A9E9, // E9 A9 [25]   '..' [%]
    0x26AAEA, // EA AA [26]   '..' [&]
    0x04ABEB, // EB AB [04]   '..' [.]
    0x10ACEC, // EC AC [10]   '..' [.]
    0x0EADED, // ED AD [0E]   '..' [.]
    0x6BAEEE, // EE AE [6B]   '..' [k]
    0x85AFEF, // EF AF [85]   '..' [.]
    0x2570F0, // F0 70 [25]   '.p' [%]
    0x0871F1, // F1 71 [08]   '.q' [.]
    0x0B72F2, // F2 72 [0B]   '.r' [.]
    0x2973F3, // F3 73 [29]   '.s' [)]
    0x3D74F4, // F4 74 [3D]   '.t' [=]
    0x2375F5, // F5 75 [23]   '.u' [#]
    0x4676F6, // F6 76 [46]   '.v' [F]
    0xA877F7, // F7 77 [A8]   '.w' [.]
    0x11F8F8, // F8 F8 [11]   '..' [.]
    0x39F9F9, // F9 F9 [39]   '..' [9]
    0x30FAFA, // FA FA [30]   '..' [0]
    0x06FBFB, // FB FB [06]   '..' [.]
    0x3AFCFC, // FC FC [3A]   '..' [:]
    0x74FDFD, // FD FD [74]   '..' [t]
    0xB1FEFE, // FE FE [B1]   '..' [.]
    0x18FFFF, // FF FF [18]   '..' [.]
};
const otp_zone_raw_buffer_t brbp_none = {
    0xFFFFFF, // FF FF [FF]   '..' [.]
    0xD1FEFE, // FE FE [D1]   '..' [.]
    0xD4FDFD, // FD FD [D4]   '..' [.]
    0xFAFCFC, // FC FC [FA]   '..' [.]
    0xF6FBFB, // FB FB [F6]   '..' [.]
    0xD8FAFA, // FA FA [D8]   '..' [.]
    0xDDF9F9, // F9 F9 [DD]   '..' [.]
    0xF3F8F8, // F8 F8 [F3]   '..' [.]
    0xC9F7F7, // F7 F7 [C9]   '..' [.]
    0xE7F6F6, // F6 F6 [E7]   '..' [.]
    0xE2F5F5, // F5 F5 [E2]   '..' [.]
    0xCCF4F4, // F4 F4 [CC]   '..' [.]
    0xC0F3F3, // F3 F3 [C0]   '..' [.]
    0xEEF2F2, // F2 F2 [EE]   '..' [.]
    0xEBF1F1, // F1 F1 [EB]   '..' [.]
    0xC5F0F0, // F0 F0 [C5]   '..' [.]
    0xE4EFEF, // EF EF [E4]   '..' [.]
    0xCAEEEE, // EE EE [CA]   '..' [.]
    0xCFEDED, // ED ED [CF]   '..' [.]
    0xE1ECEC, // EC EC [E1]   '..' [.]
    0xEDEBEB, // EB EB [ED]   '..' [.]
    0xC3EAEA, // EA EA [C3]   '..' [.]
    0xC6E9E9, // E9 E9 [C6]   '..' [.]
    0xE8E8E8, // E8 E8 [E8]   '..' [.]
    0xD2E7E7, // E7 E7 [D2]   '..' [.]
    0xFCE6E6, // E6 E6 [FC]   '..' [.]
    0xF9E5E5, // E5 E5 [F9]   '..' [.]
    0xD7E4E4, // E4 E4 [D7]   '..' [.]
    0xDBE3E3, // E3 E3 [DB]   '..' [.]
    0xF5E2E2, // E2 E2 [F5]   '..' [.]
    0xF0E1E1, // E1 E1 [F0]   '..' [.]
    0xDEE0E0, // E0 E0 [DE]   '..' [.]
    0xC6DFDF, // DF DF [C6]   '..' [.]
    0xE8DEDE, // DE DE [E8]   '..' [.]
    0xEDDDDD, // DD DD [ED]   '..' [.]
    0xC3DCDC, // DC DC [C3]   '..' [.]
    0xCFDBDB, // DB DB [CF]   '..' [.]
    0xE1DADA, // DA DA [E1]   '..' [.]
    0xE4D9D9, // D9 D9 [E4]   '..' [.]
    0xCAD8D8, // D8 D8 [CA]   '..' [.]
    0xF0D7D7, // D7 D7 [F0]   '..' [.]
    0xDED6D6, // D6 D6 [DE]   '..' [.]
    0xDBD5D5, // D5 D5 [DB]   '..' [.]
    0xF5D4D4, // D4 D4 [F5]   '..' [.]
    0xF9D3D3, // D3 D3 [F9]   '..' [.]
    0xD7D2D2, // D2 D2 [D7]   '..' [.]
    0xD2D1D1, // D1 D1 [D2]   '..' [.]
    0xFCD0D0, // D0 D0 [FC]   '..' [.]
    0xDDCFCF, // CF CF [DD]   '..' [.]
    0xF3CECE, // CE CE [F3]   '..' [.]
    0xF6CDCD, // CD CD [F6]   '..' [.]
    0xD8CCCC, // CC CC [D8]   '..' [.]
    0xD4CBCB, // CB CB [D4]   '..' [.]
    0xFACACA, // CA CA [FA]   '..' [.]
    0xFFC9C9, // C9 C9 [FF]   '..' [.]
    0xD1C8C8, // C8 C8 [D1]   '..' [.]
    0xEBC7C7, // C7 C7 [EB]   '..' [.]
    0xC5C6C6, // C6 C6 [C5]   '..' [.]
    0xC0C5C5, // C5 C5 [C0]   '..' [.]
    0xEEC4C4, // C4 C4 [EE]   '..' [.]
    0xE2C3C3, // C3 C3 [E2]   '..' [.]
    0xCCC2C2, // C2 C2 [CC]   '..' [.]
    0xC9C1C1, // C1 C1 [C9]   '..' [.]
    0xE7C0C0, // C0 C0 [E7]   '..' [.]
    0xC0BFBF, // BF BF [C0]   '..' [.]
    0xEEBEBE, // BE BE [EE]   '..' [.]
    0xEBBDBD, // BD BD [EB]   '..' [.]
    0xC5BCBC, // BC BC [C5]   '..' [.]
    0xC9BBBB, // BB BB [C9]   '..' [.]
    0xE7BABA, // BA BA [E7]   '..' [.]
    0xE2B9B9, // B9 B9 [E2]   '..' [.]
    0xCCB8B8, // B8 B8 [CC]   '..' [.]
    0xF6B7B7, // B7 B7 [F6]   '..' [.]
    0xD8B6B6, // B6 B6 [D8]   '..' [.]
    0xDDB5B5, // B5 B5 [DD]   '..' [.]
    0xF3B4B4, // B4 B4 [F3]   '..' [.]
    0xFFB3B3, // B3 B3 [FF]   '..' [.]
    0xD1B2B2, // B2 B2 [D1]   '..' [.]
    0xD4B1B1, // B1 B1 [D4]   '..' [.]
    0xFAB0B0, // B0 B0 [FA]   '..' [.]
    0xDBAFAF, // AF AF [DB]   '..' [.]
    0xF5AEAE, // AE AE [F5]   '..' [.]
    0xF0ADAD, // AD AD [F0]   '..' [.]
    0xDEACAC, // AC AC [DE]   '..' [.]
    0xD2ABAB, // AB AB [D2]   '..' [.]
    0xFCAAAA, // AA AA [FC]   '..' [.]
    0xF9A9A9, // A9 A9 [F9]   '..' [.]
    0xD7A8A8, // A8 A8 [D7]   '..' [.]
    0xEDA7A7, // A7 A7 [ED]   '..' [.]
    0xC3A6A6, // A6 A6 [C3]   '..' [.]
    0xC6A5A5, // A5 A5 [C6]   '..' [.]
    0xE8A4A4, // A4 A4 [E8]   '..' [.]
    0xE4A3A3, // A3 A3 [E4]   '..' [.]
    0xCAA2A2, // A2 A2 [CA]   '..' [.]
    0xCFA1A1, // A1 A1 [CF]   '..' [.]
    0xE1A0A0, // A0 A0 [E1]   '..' [.]
    0xF99F9F, // 9F 9F [F9]   '..' [.]
    0xD79E9E, // 9E 9E [D7]   '..' [.]
    0xD29D9D, // 9D 9D [D2]   '..' [.]
    0xFC9C9C, // 9C 9C [FC]   '..' [.]
    0xF09B9B, // 9B 9B [F0]   '..' [.]
    0xDE9A9A, // 9A 9A [DE]   '..' [.]
    0xDB9999, // 99 99 [DB]   '..' [.]
    0xF59898, // 98 98 [F5]   '..' [.]
    0xCF9797, // 97 97 [CF]   '..' [.]
    0xE19696, // 96 96 [E1]   '..' [.]
    0xE49595, // 95 95 [E4]   '..' [.]
    0xCA9494, // 94 94 [CA]   '..' [.]
    0xC69393, // 93 93 [C6]   '..' [.]
    0xE89292, // 92 92 [E8]   '..' [.]
    0xED9191, // 91 91 [ED]   '..' [.]
    0xC39090, // 90 90 [C3]   '..' [.]
    0xE28F8F, // 8F 8F [E2]   '..' [.]
    0xCC8E8E, // 8E 8E [CC]   '..' [.]
    0xC98D8D, // 8D 8D [C9]   '..' [.]
    0xE78C8C, // 8C 8C [E7]   '..' [.]
    0xEB8B8B, // 8B 8B [EB]   '..' [.]
    0xC58A8A, // 8A 8A [C5]   '..' [.]
    0xC08989, // 89 89 [C0]   '..' [.]
    0xEE8888, // 88 88 [EE]   '..' [.]
    0xD48787, // 87 87 [D4]   '..' [.]
    0xFA8686, // 86 86 [FA]   '..' [.]
    0xFF8585, // 85 85 [FF]   '..' [.]
    0xD18484, // 84 84 [D1]   '..' [.]
    0xDD8383, // 83 83 [DD]   '..' [.]
    0xF38282, // 82 82 [F3]   '..' [.]
    0xF68181, // 81 81 [F6]   '..' [.]
    0xD88080, // 80 80 [D8]   '..' [.]
    0xC67F7F, // 7F 7F [C6]   '..' [.]
    0xE87E7E, // 7E 7E [E8]   '~~' [.]
    0xED7D7D, // 7D 7D [ED]   '}}' [.]
    0xC37C7C, // 7C 7C [C3]   '||' [.]
    0xCF7B7B, // 7B 7B [CF]   '{{' [.]
    0xE17A7A, // 7A 7A [E1]   'zz' [.]
    0xE47979, // 79 79 [E4]   'yy' [.]
    0xCA7878, // 78 78 [CA]   'xx' [.]
    0xF07777, // 77 77 [F0]   'ww' [.]
    0xDE7676, // 76 76 [DE]   'vv' [.]
    0xDB7575, // 75 75 [DB]   'uu' [.]
    0xF57474, // 74 74 [F5]   'tt' [.]
    0xF97373, // 73 73 [F9]   'ss' [.]
    0xD77272, // 72 72 [D7]   'rr' [.]
    0xD27171, // 71 71 [D2]   'qq' [.]
    0xFC7070, // 70 70 [FC]   'pp' [.]
    0xDD6F6F, // 6F 6F [DD]   'oo' [.]
    0xF36E6E, // 6E 6E [F3]   'nn' [.]
    0xF66D6D, // 6D 6D [F6]   'mm' [.]
    0xD86C6C, // 6C 6C [D8]   'll' [.]
    0xD46B6B, // 6B 6B [D4]   'kk' [.]
    0xFA6A6A, // 6A 6A [FA]   'jj' [.]
    0xFF6969, // 69 69 [FF]   'ii' [.]
    0xD16868, // 68 68 [D1]   'hh' [.]
    0xEB6767, // 67 67 [EB]   'gg' [.]
    0xC56666, // 66 66 [C5]   'ff' [.]
    0xC06565, // 65 65 [C0]   'ee' [.]
    0xEE6464, // 64 64 [EE]   'dd' [.]
    0xE26363, // 63 63 [E2]   'cc' [.]
    0xCC6262, // 62 62 [CC]   'bb' [.]
    0xC96161, // 61 61 [C9]   'aa' [.]
    0xE76060, // 60 60 [E7]   '``' [.]
    0xFF5F5F, // 5F 5F [FF]   '__' [.]
    0xD15E5E, // 5E 5E [D1]   '^^' [.]
    0xD45D5D, // 5D 5D [D4]   ']]' [.]
    0xFA5C5C, // 5C 5C [FA]   '\\' [.]
    0xF65B5B, // 5B 5B [F6]   '[[' [.]
    0xD85A5A, // 5A 5A [D8]   'ZZ' [.]
    0xDD5959, // 59 59 [DD]   'YY' [.]
    0xF35858, // 58 58 [F3]   'XX' [.]
    0xC95757, // 57 57 [C9]   'WW' [.]
    0xE75656, // 56 56 [E7]   'VV' [.]
    0xE25555, // 55 55 [E2]   'UU' [.]
    0xCC5454, // 54 54 [CC]   'TT' [.]
    0xC05353, // 53 53 [C0]   'SS' [.]
    0xEE5252, // 52 52 [EE]   'RR' [.]
    0xEB5151, // 51 51 [EB]   'QQ' [.]
    0xC55050, // 50 50 [C5]   'PP' [.]
    0xE44F4F, // 4F 4F [E4]   'OO' [.]
    0xCA4E4E, // 4E 4E [CA]   'NN' [.]
    0xCF4D4D, // 4D 4D [CF]   'MM' [.]
    0xE14C4C, // 4C 4C [E1]   'LL' [.]
    0xED4B4B, // 4B 4B [ED]   'KK' [.]
    0xC34A4A, // 4A 4A [C3]   'JJ' [.]
    0xC64949, // 49 49 [C6]   'II' [.]
    0xE84848, // 48 48 [E8]   'HH' [.]
    0xD24747, // 47 47 [D2]   'GG' [.]
    0xFC4646, // 46 46 [FC]   'FF' [.]
    0xF94545, // 45 45 [F9]   'EE' [.]
    0xD74444, // 44 44 [D7]   'DD' [.]
    0xDB4343, // 43 43 [DB]   'CC' [.]
    0xF54242, // 42 42 [F5]   'BB' [.]
    0xF04141, // 41 41 [F0]   'AA' [.]
    0xDE4040, // 40 40 [DE]   '@@' [.]
    0xF93F3F, // 3F 3F [F9]   '??' [.]
    0xD73E3E, // 3E 3E [D7]   '>>' [.]
    0xD23D3D, // 3D 3D [D2]   '==' [.]
    0xFC3C3C, // 3C 3C [FC]   '<<' [.]
    0xF03B3B, // 3B 3B [F0]   ';;' [.]
    0xDE3A3A, // 3A 3A [DE]   '::' [.]
    0xDB3939, // 39 39 [DB]   '99' [.]
    0xF53838, // 38 38 [F5]   '88' [.]
    0xCF3737, // 37 37 [CF]   '77' [.]
    0xE13636, // 36 36 [E1]   '66' [.]
    0xE43535, // 35 35 [E4]   '55' [.]
    0xCA3434, // 34 34 [CA]   '44' [.]
    0xC63333, // 33 33 [C6]   '33' [.]
    0xE83232, // 32 32 [E8]   '22' [.]
    0xED3131, // 31 31 [ED]   '11' [.]
    0xC33030, // 30 30 [C3]   '00' [.]
    0xE22F2F, // 2F 2F [E2]   '//' [.]
    0xCC2E2E, // 2E 2E [CC]   '..' [.]
    0xC92D2D, // 2D 2D [C9]   '--' [.]
    0xE72C2C, // 2C 2C [E7]   ',,' [.]
    0xEB2B2B, // 2B 2B [EB]   '++' [.]
    0xC52A2A, // 2A 2A [C5]   '**' [.]
    0xC02929, // 29 29 [C0]   '))' [.]
    0xEE2828, // 28 28 [EE]   '((' [.]
    0xD42727, // 27 27 [D4]   '''' [.]
    0xFA2626, // 26 26 [FA]   '&&' [.]
    0xFF2525, // 25 25 [FF]   '%%' [.]
    0xD12424, // 24 24 [D1]   '$$' [.]
    0xDD2323, // 23 23 [DD]   '##' [.]
    0xF32222, // 22 22 [F3]   '""' [.]
    0xF62121, // 21 21 [F6]   '!!' [.]
    0xD82020, // 20 20 [D8]   '  ' [.]
    0xC01F1F, // 1F 1F [C0]   '..' [.]
    0xEE1E1E, // 1E 1E [EE]   '..' [.]
    0xEB1D1D, // 1D 1D [EB]   '..' [.]
    0xC51C1C, // 1C 1C [C5]   '..' [.]
    0xC91B1B, // 1B 1B [C9]   '..' [.]
    0xE71A1A, // 1A 1A [E7]   '..' [.]
    0xE21919, // 19 19 [E2]   '..' [.]
    0xCC1818, // 18 18 [CC]   '..' [.]
    0xF61717, // 17 17 [F6]   '..' [.]
    0xD81616, // 16 16 [D8]   '..' [.]
    0xDD1515, // 15 15 [DD]   '..' [.]
    0xF31414, // 14 14 [F3]   '..' [.]
    0xFF1313, // 13 13 [FF]   '..' [.]
    0xD11212, // 12 12 [D1]   '..' [.]
    0xD41111, // 11 11 [D4]   '..' [.]
    0xFA1010, // 10 10 [FA]   '..' [.]
    0xDB0F0F, // 0F 0F [DB]   '..' [.]
    0xF50E0E, // 0E 0E [F5]   '..' [.]
    0xF00D0D, // 0D 0D [F0]   '..' [.]
    0xDE0C0C, // 0C 0C [DE]   '..' [.]
    0xD20B0B, // 0B 0B [D2]   '..' [.]
    0xFC0A0A, // 0A 0A [FC]   '..' [.]
    0xF90909, // 09 09 [F9]   '..' [.]
    0xD70808, // 08 08 [D7]   '..' [.]
    0xED0707, // 07 07 [ED]   '..' [.]
    0xC30606, // 06 06 [C3]   '..' [.]
    0xC60505, // 05 05 [C6]   '..' [.]
    0xE80404, // 04 04 [E8]   '..' [.]
    0xE40303, // 03 03 [E4]   '..' [.]
    0xCA0202, // 02 02 [CA]   '..' [.]
    0xCF0101, // 01 01 [CF]   '..' [.]
    0xE10000, // 00 00 [E1]   '..' [.]
};
const otp_zone_raw_buffer_t brbp_0_to_1 = {
    0xFFFFFF, // FF FF [FF]   '..' [.]
    0xD1FEFF, // FF FE [D1]   '..' [.]
    0xD4FDFF, // FF FD [D4]   '..' [.]
    0xFAFDFC, // FC FD [FA]   '..' [.]
    0xF6FBFF, // FF FB [F6]   '..' [.]
    0xD8FEFA, // FA FE [D8]   '..' [.]
    0xDDFBF9, // F9 FB [DD]   '..' [.]
    0xF2F8F8, // F8 F8 [F2]   '..' [.]
    0xC9F7FF, // FF F7 [C9]   '..' [.]
    0xE7FEF6, // F6 FE [E7]   '..' [.]
    0xE3F5F5, // F5 F5 [E3]   '..' [.]
    0xCDF4F4, // F4 F4 [CD]   '..' [.]
    0xC1F3F3, // F3 F3 [C1]   '..' [.]
    0xEFF2F2, // F2 F2 [EF]   '..' [.]
    0xEAF1F1, // F1 F1 [EA]   '..' [.]
    0xC4F0F0, // F0 F0 [C4]   '..' [.]
    0xE4EFFF, // FF EF [E4]   '..' [.]
    0xCAFEEE, // EE FE [CA]   '..' [.]
    0xCEEDED, // ED ED [CE]   '..' [.]
    0xE0ECEC, // EC EC [E0]   '..' [.]
    0xECEBEB, // EB EB [EC]   '..' [.]
    0xC2EAEA, // EA EA [C2]   '..' [.]
    0xC7E9E9, // E9 E9 [C7]   '..' [.]
    0xE9E8E8, // E8 E8 [E9]   '..' [.]
    0xD3E7E7, // E7 E7 [D3]   '..' [.]
    0xFDE6E6, // E6 E6 [FD]   '..' [.]
    0xF8E5E5, // E5 E5 [F8]   '..' [.]
    0xD6E4E4, // E4 E4 [D6]   '..' [.]
    0xDAE3E3, // E3 E3 [DA]   '..' [.]
    0xF4E2E2, // E2 E2 [F4]   '..' [.]
    0xF1E1E1, // E1 E1 [F1]   '..' [.]
    0xDFE0E0, // E0 E0 [DF]   '..' [.]
    0xC6DFFF, // FF DF [C6]   '..' [.]
    0xE8FEDE, // DE FE [E8]   '..' [.]
    0xECDDDD, // DD DD [EC]   '..' [.]
    0xC2DCDC, // DC DC [C2]   '..' [.]
    0xCEDBDB, // DB DB [CE]   '..' [.]
    0xE0DADA, // DA DA [E0]   '..' [.]
    0xE5D9D9, // D9 D9 [E5]   '..' [.]
    0xCBD8D8, // D8 D8 [CB]   '..' [.]
    0xF1D7D7, // D7 D7 [F1]   '..' [.]
    0xDFD6D6, // D6 D6 [DF]   '..' [.]
    0xDAD5D5, // D5 D5 [DA]   '..' [.]
    0xF4D4D4, // D4 D4 [F4]   '..' [.]
    0xF8D3D3, // D3 D3 [F8]   '..' [.]
    0xD6D2D2, // D2 D2 [D6]   '..' [.]
    0xD3D1D1, // D1 D1 [D3]   '..' [.]
    0xFDD0D0, // D0 D0 [FD]   '..' [.]
    0xDCCFCF, // CF CF [DC]   '..' [.]
    0xF2CECE, // CE CE [F2]   '..' [.]
    0xF7CDCD, // CD CD [F7]   '..' [.]
    0xD9CCCC, // CC CC [D9]   '..' [.]
    0xD5CBCB, // CB CB [D5]   '..' [.]
    0xFBCACA, // CA CA [FB]   '..' [.]
    0xFEC9C9, // C9 C9 [FE]   '..' [.]
    0xD0C8C8, // C8 C8 [D0]   '..' [.]
    0xEAC7C7, // C7 C7 [EA]   '..' [.]
    0xC4C6C6, // C6 C6 [C4]   '..' [.]
    0xC1C5C5, // C5 C5 [C1]   '..' [.]
    0xEFC4C4, // C4 C4 [EF]   '..' [.]
    0xE3C3C3, // C3 C3 [E3]   '..' [.]
    0xCDC2C2, // C2 C2 [CD]   '..' [.]
    0xC8C1C1, // C1 C1 [C8]   '..' [.]
    0xE6C0C0, // C0 C0 [E6]   '..' [.]
    0xC0BFFF, // FF BF [C0]   '..' [.]
    0xEEFEBE, // BE FE [EE]   '..' [.]
    0xEABDBD, // BD BD [EA]   '..' [.]
    0xC4BCBC, // BC BC [C4]   '..' [.]
    0xC8BBBB, // BB BB [C8]   '..' [.]
    0xE6BABA, // BA BA [E6]   '..' [.]
    0xE3B9B9, // B9 B9 [E3]   '..' [.]
    0xCDB8B8, // B8 B8 [CD]   '..' [.]
    0xF7B7B7, // B7 B7 [F7]   '..' [.]
    0xD9B6B6, // B6 B6 [D9]   '..' [.]
    0xDCB5B5, // B5 B5 [DC]   '..' [.]
    0xF2B4B4, // B4 B4 [F2]   '..' [.]
    0xFEB3B3, // B3 B3 [FE]   '..' [.]
    0xD0B2B2, // B2 B2 [D0]   '..' [.]
    0xD5B1B1, // B1 B1 [D5]   '..' [.]
    0xFBB0B0, // B0 B0 [FB]   '..' [.]
    0xDAAFAF, // AF AF [DA]   '..' [.]
    0xF4AEAE, // AE AE [F4]   '..' [.]
    0xF1ADAD, // AD AD [F1]   '..' [.]
    0xDFACAC, // AC AC [DF]   '..' [.]
    0xD3ABAB, // AB AB [D3]   '..' [.]
    0xFDAAAA, // AA AA [FD]   '..' [.]
    0xF8A9A9, // A9 A9 [F8]   '..' [.]
    0xD6A8A8, // A8 A8 [D6]   '..' [.]
    0xECA7A7, // A7 A7 [EC]   '..' [.]
    0xC2A6A6, // A6 A6 [C2]   '..' [.]
    0xC7A5A5, // A5 A5 [C7]   '..' [.]
    0xE9A4A4, // A4 A4 [E9]   '..' [.]
    0xE5A3A3, // A3 A3 [E5]   '..' [.]
    0xCBA2A2, // A2 A2 [CB]   '..' [.]
    0xCEA1A1, // A1 A1 [CE]   '..' [.]
    0xE0A0A0, // A0 A0 [E0]   '..' [.]
    0xF89F9F, // 9F 9F [F8]   '..' [.]
    0xD69E9E, // 9E 9E [D6]   '..' [.]
    0xD39D9D, // 9D 9D [D3]   '..' [.]
    0xFD9C9C, // 9C 9C [FD]   '..' [.]
    0xF19B9B, // 9B 9B [F1]   '..' [.]
    0xDF9A9A, // 9A 9A [DF]   '..' [.]
    0xDA9999, // 99 99 [DA]   '..' [.]
    0xF49898, // 98 98 [F4]   '..' [.]
    0xCE9797, // 97 97 [CE]   '..' [.]
    0xE09696, // 96 96 [E0]   '..' [.]
    0xE59595, // 95 95 [E5]   '..' [.]
    0xCB9494, // 94 94 [CB]   '..' [.]
    0xC79393, // 93 93 [C7]   '..' [.]
    0xE99292, // 92 92 [E9]   '..' [.]
    0xEC9191, // 91 91 [EC]   '..' [.]
    0xC29090, // 90 90 [C2]   '..' [.]
    0xE38F8F, // 8F 8F [E3]   '..' [.]
    0xCD8E8E, // 8E 8E [CD]   '..' [.]
    0xC88D8D, // 8D 8D [C8]   '..' [.]
    0xE68C8C, // 8C 8C [E6]   '..' [.]
    0xEA8B8B, // 8B 8B [EA]   '..' [.]
    0xC48A8A, // 8A 8A [C4]   '..' [.]
    0xC18989, // 89 89 [C1]   '..' [.]
    0xEF8888, // 88 88 [EF]   '..' [.]
    0xD58787, // 87 87 [D5]   '..' [.]
    0xFB8686, // 86 86 [FB]   '..' [.]
    0xFE8585, // 85 85 [FE]   '..' [.]
    0xD08484, // 84 84 [D0]   '..' [.]
    0xDC8383, // 83 83 [DC]   '..' [.]
    0xF28282, // 82 82 [F2]   '..' [.]
    0xF78181, // 81 81 [F7]   '..' [.]
    0xD98080, // 80 80 [D9]   '..' [.]
    0xC67FFF, // FF 7F [C6]   '..' [.]
    0xE8FE7E, // 7E FE [E8]   '~.' [.]
    0xEC7D7D, // 7D 7D [EC]   '}}' [.]
    0xC27C7C, // 7C 7C [C2]   '||' [.]
    0xCE7B7B, // 7B 7B [CE]   '{{' [.]
    0xE07A7A, // 7A 7A [E0]   'zz' [.]
    0xE57979, // 79 79 [E5]   'yy' [.]
    0xCB7878, // 78 78 [CB]   'xx' [.]
    0xF17777, // 77 77 [F1]   'ww' [.]
    0xDF7676, // 76 76 [DF]   'vv' [.]
    0xDA7575, // 75 75 [DA]   'uu' [.]
    0xF47474, // 74 74 [F4]   'tt' [.]
    0xF87373, // 73 73 [F8]   'ss' [.]
    0xD67272, // 72 72 [D6]   'rr' [.]
    0xD37171, // 71 71 [D3]   'qq' [.]
    0xFD7070, // 70 70 [FD]   'pp' [.]
    0xDC6F6F, // 6F 6F [DC]   'oo' [.]
    0xF26E6E, // 6E 6E [F2]   'nn' [.]
    0xF76D6D, // 6D 6D [F7]   'mm' [.]
    0xD96C6C, // 6C 6C [D9]   'll' [.]
    0xD56B6B, // 6B 6B [D5]   'kk' [.]
    0xFB6A6A, // 6A 6A [FB]   'jj' [.]
    0xFE6969, // 69 69 [FE]   'ii' [.]
    0xD06868, // 68 68 [D0]   'hh' [.]
    0xEA6767, // 67 67 [EA]   'gg' [.]
    0xC46666, // 66 66 [C4]   'ff' [.]
    0xC16565, // 65 65 [C1]   'ee' [.]
    0xEF6464, // 64 64 [EF]   'dd' [.]
    0xE36363, // 63 63 [E3]   'cc' [.]
    0xCD6262, // 62 62 [CD]   'bb' [.]
    0xC86161, // 61 61 [C8]   'aa' [.]
    0xE66060, // 60 60 [E6]   '``' [.]
    0xFE5F5F, // 5F 5F [FE]   '__' [.]
    0xD05E5E, // 5E 5E [D0]   '^^' [.]
    0xD55D5D, // 5D 5D [D5]   ']]' [.]
    0xFB5C5C, // 5C 5C [FB]   '\\' [.]
    0xF75B5B, // 5B 5B [F7]   '[[' [.]
    0xD95A5A, // 5A 5A [D9]   'ZZ' [.]
    0xDC5959, // 59 59 [DC]   'YY' [.]
    0xF25858, // 58 58 [F2]   'XX' [.]
    0xC85757, // 57 57 [C8]   'WW' [.]
    0xE65656, // 56 56 [E6]   'VV' [.]
    0xE35555, // 55 55 [E3]   'UU' [.]
    0xCD5454, // 54 54 [CD]   'TT' [.]
    0xC15353, // 53 53 [C1]   'SS' [.]
    0xEF5252, // 52 52 [EF]   'RR' [.]
    0xEA5151, // 51 51 [EA]   'QQ' [.]
    0xC45050, // 50 50 [C4]   'PP' [.]
    0xE54F4F, // 4F 4F [E5]   'OO' [.]
    0xCB4E4E, // 4E 4E [CB]   'NN' [.]
    0xCE4D4D, // 4D 4D [CE]   'MM' [.]
    0xE04C4C, // 4C 4C [E0]   'LL' [.]
    0xEC4B4B, // 4B 4B [EC]   'KK' [.]
    0xC24A4A, // 4A 4A [C2]   'JJ' [.]
    0xC74949, // 49 49 [C7]   'II' [.]
    0xE94848, // 48 48 [E9]   'HH' [.]
    0xD34747, // 47 47 [D3]   'GG' [.]
    0xFD4646, // 46 46 [FD]   'FF' [.]
    0xF84545, // 45 45 [F8]   'EE' [.]
    0xD64444, // 44 44 [D6]   'DD' [.]
    0xDA4343, // 43 43 [DA]   'CC' [.]
    0xF44242, // 42 42 [F4]   'BB' [.]
    0xF14141, // 41 41 [F1]   'AA' [.]
    0xDF4040, // 40 40 [DF]   '@@' [.]
    0xF83F3F, // 3F 3F [F8]   '??' [.]
    0xD63E3E, // 3E 3E [D6]   '>>' [.]
    0xD33D3D, // 3D 3D [D3]   '==' [.]
    0xFD3C3C, // 3C 3C [FD]   '<<' [.]
    0xF13B3B, // 3B 3B [F1]   ';;' [.]
    0xDF3A3A, // 3A 3A [DF]   '::' [.]
    0xDA3939, // 39 39 [DA]   '99' [.]
    0xF43838, // 38 38 [F4]   '88' [.]
    0xCE3737, // 37 37 [CE]   '77' [.]
    0xE03636, // 36 36 [E0]   '66' [.]
    0xE53535, // 35 35 [E5]   '55' [.]
    0xCB3434, // 34 34 [CB]   '44' [.]
    0xC73333, // 33 33 [C7]   '33' [.]
    0xE93232, // 32 32 [E9]   '22' [.]
    0xEC3131, // 31 31 [EC]   '11' [.]
    0xC23030, // 30 30 [C2]   '00' [.]
    0xE32F2F, // 2F 2F [E3]   '//' [.]
    0xCD2E2E, // 2E 2E [CD]   '..' [.]
    0xC82D2D, // 2D 2D [C8]   '--' [.]
    0xE62C2C, // 2C 2C [E6]   ',,' [.]
    0xEA2B2B, // 2B 2B [EA]   '++' [.]
    0xC42A2A, // 2A 2A [C4]   '**' [.]
    0xC12929, // 29 29 [C1]   '))' [.]
    0xEF2828, // 28 28 [EF]   '((' [.]
    0xD52727, // 27 27 [D5]   '''' [.]
    0xFB2626, // 26 26 [FB]   '&&' [.]
    0xFE2525, // 25 25 [FE]   '%%' [.]
    0xD02424, // 24 24 [D0]   '$$' [.]
    0xDC2323, // 23 23 [DC]   '##' [.]
    0xF22222, // 22 22 [F2]   '""' [.]
    0xF72121, // 21 21 [F7]   '!!' [.]
    0xD92020, // 20 20 [D9]   '  ' [.]
    0xC11F1F, // 1F 1F [C1]   '..' [.]
    0xEF1E1E, // 1E 1E [EF]   '..' [.]
    0xEA1D1D, // 1D 1D [EA]   '..' [.]
    0xC41C1C, // 1C 1C [C4]   '..' [.]
    0xC81B1B, // 1B 1B [C8]   '..' [.]
    0xE61A1A, // 1A 1A [E6]   '..' [.]
    0xE31919, // 19 19 [E3]   '..' [.]
    0xCD1818, // 18 18 [CD]   '..' [.]
    0xF71717, // 17 17 [F7]   '..' [.]
    0xD91616, // 16 16 [D9]   '..' [.]
    0xDC1515, // 15 15 [DC]   '..' [.]
    0xF21414, // 14 14 [F2]   '..' [.]
    0xFE1313, // 13 13 [FE]   '..' [.]
    0xD01212, // 12 12 [D0]   '..' [.]
    0xD51111, // 11 11 [D5]   '..' [.]
    0xFB1010, // 10 10 [FB]   '..' [.]
    0xDA0F0F, // 0F 0F [DA]   '..' [.]
    0xF40E0E, // 0E 0E [F4]   '..' [.]
    0xF10D0D, // 0D 0D [F1]   '..' [.]
    0xDF0C0C, // 0C 0C [DF]   '..' [.]
    0xD30B0B, // 0B 0B [D3]   '..' [.]
    0xFD0A0A, // 0A 0A [FD]   '..' [.]
    0xF80909, // 09 09 [F8]   '..' [.]
    0xD60808, // 08 08 [D6]   '..' [.]
    0xEC0707, // 07 07 [EC]   '..' [.]
    0xC20606, // 06 06 [C2]   '..' [.]
    0xC70505, // 05 05 [C7]   '..' [.]
    0xE90404, // 04 04 [E9]   '..' [.]
    0xE50303, // 03 03 [E5]   '..' [.]
    0xCB0202, // 02 02 [CB]   '..' [.]
    0xCE0101, // 01 01 [CE]   '..' [.]
    0xE00000, // 00 00 [E0]   '..' [.]
};
const otp_zone_raw_buffer_t brbp_1_to_0 = {
    0xFFFFFE, // FE FF [FF]   '..' [.]
    0xD1FEFC, // FC FE [D1]   '..' [.]
    0xD4FDF9, // F9 FD [D4]   '..' [.]
    0xFAFCF4, // F4 FC [FA]   '..' [.]
    0xF6FBEB, // EB FB [F6]   '..' [.]
    0xD8FADA, // DA FA [D8]   '..' [.]
    0xDDF9B9, // B9 F9 [DD]   '..' [.]
    0xF3F878, // 78 F8 [F3]   'x.' [.]
    0xC9F6F7, // F7 F6 [C9]   '..' [.]
    0xE7F4F6, // F6 F4 [E7]   '..' [.]
    0xE2F1F5, // F5 F1 [E2]   '..' [.]
    0xCCE4F4, // F4 E4 [CC]   '..' [.]
    0xC0D3F3, // F3 D3 [C0]   '..' [.]
    0xEEB2F2, // F2 B2 [EE]   '..' [.]
    0xEB71F1, // F1 71 [EB]   '.q' [.]
    0xC5F0E0, // E0 F0 [C5]   '..' [.]
    0xE4E7EF, // EF E7 [E4]   '..' [.]
    0xCAEEEC, // EC EE [CA]   '..' [.]
    0xCFEDEC, // EC ED [CF]   '..' [.]
    0xE1ECE8, // E8 EC [E1]   '..' [.]
    0xEDEBEA, // EA EB [ED]   '..' [.]
    0xC3EAE8, // E8 EA [C3]   '..' [.]
    0xC6E9E8, // E8 E9 [C6]   '..' [.]
    0xE8E8E0, // E0 E8 [E8]   '..' [.]
    0xD2E7E6, // E6 E7 [D2]   '..' [.]
    0xFCE6E4, // E4 E6 [FC]   '..' [.]
    0xF9E5E4, // E4 E5 [F9]   '..' [.]
    0xD7E4E0, // E0 E4 [D7]   '..' [.]
    0xDBE3E2, // E2 E3 [DB]   '..' [.]
    0xF5E2E0, // E0 E2 [F5]   '..' [.]
    0xF0E1E0, // E0 E1 [F0]   '..' [.]
    0xDEE0C0, // C0 E0 [DE]   '..' [.]
    0xC6DFDE, // DE DF [C6]   '..' [.]
    0xE8DEDC, // DC DE [E8]   '..' [.]
    0xEDDDDC, // DC DD [ED]   '..' [.]
    0xC3DCD8, // D8 DC [C3]   '..' [.]
    0xCFDBDA, // DA DB [CF]   '..' [.]
    0xE1DAD8, // D8 DA [E1]   '..' [.]
    0xE4D9D8, // D8 D9 [E4]   '..' [.]
    0xCAD8D0, // D0 D8 [CA]   '..' [.]
    0xF0D7D6, // D6 D7 [F0]   '..' [.]
    0xDED6D4, // D4 D6 [DE]   '..' [.]
    0xDBD5D4, // D4 D5 [DB]   '..' [.]
    0xF5D4D0, // D0 D4 [F5]   '..' [.]
    0xF9D3D2, // D2 D3 [F9]   '..' [.]
    0xD7D2D0, // D0 D2 [D7]   '..' [.]
    0xD2D1D0, // D0 D1 [D2]   '..' [.]
    0xFCD0C0, // C0 D0 [FC]   '..' [.]
    0xDDCFCE, // CE CF [DD]   '..' [.]
    0xF3CECC, // CC CE [F3]   '..' [.]
    0xF6CDCC, // CC CD [F6]   '..' [.]
    0xD8CCC8, // C8 CC [D8]   '..' [.]
    0xD4CBCA, // CA CB [D4]   '..' [.]
    0xFACAC8, // C8 CA [FA]   '..' [.]
    0xFFC9C8, // C8 C9 [FF]   '..' [.]
    0xD1C8C0, // C0 C8 [D1]   '..' [.]
    0xEBC7C6, // C6 C7 [EB]   '..' [.]
    0xC5C6C4, // C4 C6 [C5]   '..' [.]
    0xC0C5C4, // C4 C5 [C0]   '..' [.]
    0xEEC4C0, // C0 C4 [EE]   '..' [.]
    0xE2C3C2, // C2 C3 [E2]   '..' [.]
    0xCCC2C0, // C0 C2 [CC]   '..' [.]
    0xC9C1C0, // C0 C1 [C9]   '..' [.]
    0xE7C080, // 80 C0 [E7]   '..' [.]
    0xC0BFBE, // BE BF [C0]   '..' [.]
    0xEEBEBC, // BC BE [EE]   '..' [.]
    0xEBBDBC, // BC BD [EB]   '..' [.]
    0xC5BCB8, // B8 BC [C5]   '..' [.]
    0xC9BBBA, // BA BB [C9]   '..' [.]
    0xE7BAB8, // B8 BA [E7]   '..' [.]
    0xE2B9B8, // B8 B9 [E2]   '..' [.]
    0xCCB8B0, // B0 B8 [CC]   '..' [.]
    0xF6B7B6, // B6 B7 [F6]   '..' [.]
    0xD8B6B4, // B4 B6 [D8]   '..' [.]
    0xDDB5B4, // B4 B5 [DD]   '..' [.]
    0xF3B4B0, // B0 B4 [F3]   '..' [.]
    0xFFB3B2, // B2 B3 [FF]   '..' [.]
    0xD1B2B0, // B0 B2 [D1]   '..' [.]
    0xD4B1B0, // B0 B1 [D4]   '..' [.]
    0xFAB0A0, // A0 B0 [FA]   '..' [.]
    0xDBAFAE, // AE AF [DB]   '..' [.]
    0xF5AEAC, // AC AE [F5]   '..' [.]
    0xF0ADAC, // AC AD [F0]   '..' [.]
    0xDEACA8, // A8 AC [DE]   '..' [.]
    0xD2ABAA, // AA AB [D2]   '..' [.]
    0xFCAAA8, // A8 AA [FC]   '..' [.]
    0xF9A9A8, // A8 A9 [F9]   '..' [.]
    0xD7A8A0, // A0 A8 [D7]   '..' [.]
    0xEDA7A6, // A6 A7 [ED]   '..' [.]
    0xC3A6A4, // A4 A6 [C3]   '..' [.]
    0xC6A5A4, // A4 A5 [C6]   '..' [.]
    0xE8A4A0, // A0 A4 [E8]   '..' [.]
    0xE4A3A2, // A2 A3 [E4]   '..' [.]
    0xCAA2A0, // A0 A2 [CA]   '..' [.]
    0xCFA1A0, // A0 A1 [CF]   '..' [.]
    0xE1A080, // 80 A0 [E1]   '..' [.]
    0xF99F9E, // 9E 9F [F9]   '..' [.]
    0xD79E9C, // 9C 9E [D7]   '..' [.]
    0xD29D9C, // 9C 9D [D2]   '..' [.]
    0xFC9C98, // 98 9C [FC]   '..' [.]
    0xF09B9A, // 9A 9B [F0]   '..' [.]
    0xDE9A98, // 98 9A [DE]   '..' [.]
    0xDB9998, // 98 99 [DB]   '..' [.]
    0xF59890, // 90 98 [F5]   '..' [.]
    0xCF9796, // 96 97 [CF]   '..' [.]
    0xE19694, // 94 96 [E1]   '..' [.]
    0xE49594, // 94 95 [E4]   '..' [.]
    0xCA9490, // 90 94 [CA]   '..' [.]
    0xC69392, // 92 93 [C6]   '..' [.]
    0xE89290, // 90 92 [E8]   '..' [.]
    0xED9190, // 90 91 [ED]   '..' [.]
    0xC39080, // 80 90 [C3]   '..' [.]
    0xE28F8E, // 8E 8F [E2]   '..' [.]
    0xCC8E8C, // 8C 8E [CC]   '..' [.]
    0xC98D8C, // 8C 8D [C9]   '..' [.]
    0xE78C88, // 88 8C [E7]   '..' [.]
    0xEB8B8A, // 8A 8B [EB]   '..' [.]
    0xC58A88, // 88 8A [C5]   '..' [.]
    0xC08988, // 88 89 [C0]   '..' [.]
    0xEE8880, // 80 88 [EE]   '..' [.]
    0xD48786, // 86 87 [D4]   '..' [.]
    0xFA8684, // 84 86 [FA]   '..' [.]
    0xFF8584, // 84 85 [FF]   '..' [.]
    0xD18480, // 80 84 [D1]   '..' [.]
    0xDD8382, // 82 83 [DD]   '..' [.]
    0xF38280, // 80 82 [F3]   '..' [.]
    0xF68180, // 80 81 [F6]   '..' [.]
    0xD88000, // 00 80 [D8]   '..' [.]
    0xC67F7E, // 7E 7F [C6]   '~.' [.]
    0xE87E7C, // 7C 7E [E8]   '|~' [.]
    0xED7D7C, // 7C 7D [ED]   '|}' [.]
    0xC37C78, // 78 7C [C3]   'x|' [.]
    0xCF7B7A, // 7A 7B [CF]   'z{' [.]
    0xE17A78, // 78 7A [E1]   'xz' [.]
    0xE47978, // 78 79 [E4]   'xy' [.]
    0xCA7870, // 70 78 [CA]   'px' [.]
    0xF07776, // 76 77 [F0]   'vw' [.]
    0xDE7674, // 74 76 [DE]   'tv' [.]
    0xDB7574, // 74 75 [DB]   'tu' [.]
    0xF57470, // 70 74 [F5]   'pt' [.]
    0xF97372, // 72 73 [F9]   'rs' [.]
    0xD77270, // 70 72 [D7]   'pr' [.]
    0xD27170, // 70 71 [D2]   'pq' [.]
    0xFC7060, // 60 70 [FC]   '`p' [.]
    0xDD6F6E, // 6E 6F [DD]   'no' [.]
    0xF36E6C, // 6C 6E [F3]   'ln' [.]
    0xF66D6C, // 6C 6D [F6]   'lm' [.]
    0xD86C68, // 68 6C [D8]   'hl' [.]
    0xD46B6A, // 6A 6B [D4]   'jk' [.]
    0xFA6A68, // 68 6A [FA]   'hj' [.]
    0xFF6968, // 68 69 [FF]   'hi' [.]
    0xD16860, // 60 68 [D1]   '`h' [.]
    0xEB6766, // 66 67 [EB]   'fg' [.]
    0xC56664, // 64 66 [C5]   'df' [.]
    0xC06564, // 64 65 [C0]   'de' [.]
    0xEE6460, // 60 64 [EE]   '`d' [.]
    0xE26362, // 62 63 [E2]   'bc' [.]
    0xCC6260, // 60 62 [CC]   '`b' [.]
    0xC96160, // 60 61 [C9]   '`a' [.]
    0xE76040, // 40 60 [E7]   '@`' [.]
    0xFF5F5E, // 5E 5F [FF]   '^_' [.]
    0xD15E5C, // 5C 5E [D1]   '\^' [.]
    0xD45D5C, // 5C 5D [D4]   '\]' [.]
    0xFA5C58, // 58 5C [FA]   'X\' [.]
    0xF65B5A, // 5A 5B [F6]   'Z[' [.]
    0xD85A58, // 58 5A [D8]   'XZ' [.]
    0xDD5958, // 58 59 [DD]   'XY' [.]
    0xF35850, // 50 58 [F3]   'PX' [.]
    0xC95756, // 56 57 [C9]   'VW' [.]
    0xE75654, // 54 56 [E7]   'TV' [.]
    0xE25554, // 54 55 [E2]   'TU' [.]
    0xCC5450, // 50 54 [CC]   'PT' [.]
    0xC05352, // 52 53 [C0]   'RS' [.]
    0xEE5250, // 50 52 [EE]   'PR' [.]
    0xEB5150, // 50 51 [EB]   'PQ' [.]
    0xC55040, // 40 50 [C5]   '@P' [.]
    0xE44F4E, // 4E 4F [E4]   'NO' [.]
    0xCA4E4C, // 4C 4E [CA]   'LN' [.]
    0xCF4D4C, // 4C 4D [CF]   'LM' [.]
    0xE14C48, // 48 4C [E1]   'HL' [.]
    0xED4B4A, // 4A 4B [ED]   'JK' [.]
    0xC34A48, // 48 4A [C3]   'HJ' [.]
    0xC64948, // 48 49 [C6]   'HI' [.]
    0xE84840, // 40 48 [E8]   '@H' [.]
    0xD24746, // 46 47 [D2]   'FG' [.]
    0xFC4644, // 44 46 [FC]   'DF' [.]
    0xF94544, // 44 45 [F9]   'DE' [.]
    0xD74440, // 40 44 [D7]   '@D' [.]
    0xDB4342, // 42 43 [DB]   'BC' [.]
    0xF54240, // 40 42 [F5]   '@B' [.]
    0xF04140, // 40 41 [F0]   '@A' [.]
    0xDE4000, // 00 40 [DE]   '.@' [.]
    0xF93F3E, // 3E 3F [F9]   '>?' [.]
    0xD73E3C, // 3C 3E [D7]   '<>' [.]
    0xD23D3C, // 3C 3D [D2]   '<=' [.]
    0xFC3C38, // 38 3C [FC]   '8<' [.]
    0xF03B3A, // 3A 3B [F0]   ':;' [.]
    0xDE3A38, // 38 3A [DE]   '8:' [.]
    0xDB3938, // 38 39 [DB]   '89' [.]
    0xF53830, // 30 38 [F5]   '08' [.]
    0xCF3736, // 36 37 [CF]   '67' [.]
    0xE13634, // 34 36 [E1]   '46' [.]
    0xE43534, // 34 35 [E4]   '45' [.]
    0xCA3430, // 30 34 [CA]   '04' [.]
    0xC63332, // 32 33 [C6]   '23' [.]
    0xE83230, // 30 32 [E8]   '02' [.]
    0xED3130, // 30 31 [ED]   '01' [.]
    0xC33020, // 20 30 [C3]   ' 0' [.]
    0xE22F2E, // 2E 2F [E2]   './' [.]
    0xCC2E2C, // 2C 2E [CC]   ',.' [.]
    0xC92D2C, // 2C 2D [C9]   ',-' [.]
    0xE72C28, // 28 2C [E7]   '(,' [.]
    0xEB2B2A, // 2A 2B [EB]   '*+' [.]
    0xC52A28, // 28 2A [C5]   '(*' [.]
    0xC02928, // 28 29 [C0]   '()' [.]
    0xEE2820, // 20 28 [EE]   ' (' [.]
    0xD42726, // 26 27 [D4]   '&'' [.]
    0xFA2624, // 24 26 [FA]   '$&' [.]
    0xFF2524, // 24 25 [FF]   '$%' [.]
    0xD12420, // 20 24 [D1]   ' $' [.]
    0xDD2322, // 22 23 [DD]   '"#' [.]
    0xF32220, // 20 22 [F3]   ' "' [.]
    0xF62120, // 20 21 [F6]   ' !' [.]
    0xD82000, // 00 20 [D8]   '. ' [.]
    0xC01F1E, // 1E 1F [C0]   '..' [.]
    0xEE1E1C, // 1C 1E [EE]   '..' [.]
    0xEB1D1C, // 1C 1D [EB]   '..' [.]
    0xC51C18, // 18 1C [C5]   '..' [.]
    0xC91B1A, // 1A 1B [C9]   '..' [.]
    0xE71A18, // 18 1A [E7]   '..' [.]
    0xE21918, // 18 19 [E2]   '..' [.]
    0xCC1810, // 10 18 [CC]   '..' [.]
    0xF61716, // 16 17 [F6]   '..' [.]
    0xD81614, // 14 16 [D8]   '..' [.]
    0xDD1514, // 14 15 [DD]   '..' [.]
    0xF31410, // 10 14 [F3]   '..' [.]
    0xFF1312, // 12 13 [FF]   '..' [.]
    0xD11210, // 10 12 [D1]   '..' [.]
    0xD41110, // 10 11 [D4]   '..' [.]
    0xFA1000, // 00 10 [FA]   '..' [.]
    0xDB0F0E, // 0E 0F [DB]   '..' [.]
    0xF50E0C, // 0C 0E [F5]   '..' [.]
    0xF00D0C, // 0C 0D [F0]   '..' [.]
    0xDE0C08, // 08 0C [DE]   '..' [.]
    0xD20B0A, // 0A 0B [D2]   '..' [.]
    0xFC0A08, // 08 0A [FC]   '..' [.]
    0xF90908, // 08 09 [F9]   '..' [.]
    0xD70800, // 00 08 [D7]   '..' [.]
    0xED0706, // 06 07 [ED]   '..' [.]
    0xC30604, // 04 06 [C3]   '..' [.]
    0xC60504, // 04 05 [C6]   '..' [.]
    0xE80400, // 00 04 [E8]   '..' [.]
    0xE40302, // 02 03 [E4]   '..' [.]
    0xCA0200, // 00 02 [CA]   '..' [.]
    0xCF0100, // 00 01 [CF]   '..' [.]
    0xE00000, // 00 00 [E0]   '..' [.]
};
const otp_zone_raw_buffer_t brbp_multibit = {
    0xFFFFFC, // FC FF [FF]   '..' [.]
    0xD1FEFB, // FB FE [D1]   '..' [.]
    0xD4FDF4, // F4 FD [D4]   '..' [.]
    0xFAFCED, // ED FC [FA]   '..' [.]
    0xF6FBDA, // DA FB [F6]   '..' [.]
    0xD8FABB, // BB FA [D8]   '..' [.]
    0xDDF978, // 78 F9 [DD]   'x.' [.]
    0xF3F9F9, // F9 F9 [F3]   '..' [.]
    0xC9F5F6, // F6 F5 [C9]   '..' [.]
    0xE7F2F7, // F7 F2 [E7]   '..' [.]
    0xE2FDF4, // F4 FD [E2]   '..' [.]
    0xCCE4F5, // F5 E4 [CC]   '..' [.]
    0xC0D3F2, // F2 D3 [C0]   '..' [.]
    0xEEB2F3, // F3 B2 [EE]   '..' [.]
    0xEB71F0, // F0 71 [EB]   '.q' [.]
    0xC4F0F1, // F1 F0 [C4]   '..' [.]
    0xE6EFEE, // EE EF [E6]   '..' [.]
    0xCEEEEF, // EF EE [CE]   '..' [.]
    0xC7EDEC, // EC ED [C7]   '..' [.]
    0xF1ECED, // ED EC [F1]   '..' [.]
    0xCDEBEA, // EA EB [CD]   '..' [.]
    0x83EAEB, // EB EA [83]   '..' [.]
    0x46E9E8, // E8 E9 [46]   '..' [F]
    0xE8E8EE, // EE E8 [E8]   '..' [.]
    0xD2E7ED, // ED E7 [D2]   '..' [.]
    0xFCE6F4, // F4 E6 [FC]   '..' [.]
    0xF9E5C7, // C7 E5 [F9]   '..' [.]
    0xD7E4A6, // A6 E4 [D7]   '..' [.]
    0xDBE361, // 61 E3 [DB]   'a.' [.]
    0xF5E3E0, // E0 E3 [F5]   '..' [.]
    0xF0E3E3, // E3 E3 [F0]   '..' [.]
    0xDEE4E2, // E2 E4 [DE]   '..' [.]
    0xC6D7DD, // DD D7 [C6]   '..' [.]
    0xE8CEDC, // DC CE [E8]   '..' [.]
    0xEDFDDF, // DF FD [ED]   '..' [.]
    0xC39CDE, // DE 9C [C3]   '..' [.]
    0xCF5BD9, // D9 5B [CF]   '.[' [.]
    0xE0DAD8, // D8 DA [E0]   '..' [.]
    0xE6D9DB, // DB D9 [E6]   '..' [.]
    0xCED8DA, // DA D8 [CE]   '..' [.]
    0xF8D7D5, // D5 D7 [F8]   '..' [.]
    0xCED6D4, // D4 D6 [CE]   '..' [.]
    0xFBD5D7, // D7 D5 [FB]   '..' [.]
    0xB5D4D6, // D6 D4 [B5]   '..' [.]
    0x79D3D1, // D1 D3 [79]   '..' [y]
    0xD7D2DE, // DE D2 [D7]   '..' [.]
    0xD2D1C5, // C5 D1 [D2]   '..' [.]
    0xFCD0F4, // F4 D0 [FC]   '..' [.]
    0xDDCF8B, // 8B CF [DD]   '..' [.]
    0xF3CE4A, // 4A CE [F3]   'J.' [.]
    0xF6CCC9, // C9 CC [F6]   '..' [.]
    0xD8CEC8, // C8 CE [D8]   '..' [.]
    0xD4CFCF, // CF CF [D4]   '..' [.]
    0xFAC2CE, // CE C2 [FA]   '..' [.]
    0xFFD9CD, // CD D9 [FF]   '..' [.]
    0xD1E8CC, // CC E8 [D1]   '..' [.]
    0xEB87C3, // C3 87 [EB]   '..' [.]
    0xC546C2, // C2 46 [C5]   '.F' [.]
    0xC1C5C1, // C1 C5 [C1]   '..' [.]
    0xECC4C0, // C0 C4 [EC]   '..' [.]
    0xE6C3C7, // C7 C3 [E6]   '..' [.]
    0xC4C2C6, // C6 C2 [C4]   '..' [.]
    0xD9C1C5, // C5 C1 [D9]   '..' [.]
    0xC7C0C4, // C4 C0 [C7]   '..' [.]
    0x80BFBB, // BB BF [80]   '..' [.]
    0x6EBEBA, // BA BE [6E]   '..' [n]
    0xEBBDA5, // A5 BD [EB]   '..' [.]
    0xC5BC94, // 94 BC [C5]   '..' [.]
    0xC9BBF3, // F3 BB [C9]   '..' [.]
    0xE7BA32, // 32 BA [E7]   '2.' [.]
    0xE2B8B1, // B1 B8 [E2]   '..' [.]
    0xCCBAB0, // B0 BA [CC]   '..' [.]
    0xF6B3BF, // BF B3 [F6]   '..' [.]
    0xD8BEBE, // BE BE [D8]   '..' [.]
    0xDDA5BD, // BD A5 [DD]   '..' [.]
    0xF394BC, // BC 94 [F3]   '..' [.]
    0xFFF3BB, // BB F3 [FF]   '..' [.]
    0xD132BA, // BA 32 [D1]   '.2' [.]
    0xD5B1B9, // B9 B1 [D5]   '..' [.]
    0xF8B0B8, // B8 B0 [F8]   '..' [.]
    0xDFAFA7, // A7 AF [DF]   '..' [.]
    0xFDAEA6, // A6 AE [FD]   '..' [.]
    0xE0ADA5, // A5 AD [E0]   '..' [.]
    0xFEACA4, // A4 AC [FE]   '..' [.]
    0x92ABA3, // A3 AB [92]   '..' [.]
    0x7CAAA2, // A2 AA [7C]   '..' [|]
    0xF9A999, // 99 A9 [F9]   '..' [.]
    0xD7A8F8, // F8 A8 [D7]   '..' [.]
    0xEDA737, // 37 A7 [ED]   '7.' [.]
    0xC3A7B6, // B6 A7 [C3]   '..' [.]
    0xC6A7B5, // B5 A7 [C6]   '..' [.]
    0xE8A0B4, // B4 A0 [E8]   '..' [.]
    0xE4ABB3, // B3 AB [E4]   '..' [.]
    0xCAB2B2, // B2 B2 [CA]   '..' [.]
    0xCF81B1, // B1 81 [CF]   '..' [.]
    0xE1E0B0, // B0 E0 [E1]   '..' [.]
    0xF91F8F, // 8F 1F [F9]   '..' [.]
    0xD69E8E, // 8E 9E [D6]   '..' [.]
    0xD09D8D, // 8D 9D [D0]   '..' [.]
    0xF89C8C, // 8C 9C [F8]   '..' [.]
    0xF89B8B, // 8B 9B [F8]   '..' [.]
    0xCE9A8A, // 8A 9A [CE]   '..' [.]
    0xFB9989, // 89 99 [FB]   '..' [.]
    0xB59888, // 88 98 [B5]   '..' [.]
    0x4F9787, // 87 97 [4F]   '..' [O]
    0xE196F6, // F6 96 [E1]   '..' [.]
    0xE49535, // 35 95 [E4]   '5.' [.]
    0xCA95B4, // B4 95 [CA]   '..' [.]
    0xC691B3, // B3 91 [C6]   '..' [.]
    0xE896B2, // B2 96 [E8]   '..' [.]
    0xED99B1, // B1 99 [ED]   '..' [.]
    0xC380B0, // B0 80 [C3]   '..' [.]
    0xE2AFAF, // AF AF [E2]   '..' [.]
    0xCCCEAE, // AE CE [CC]   '..' [.]
    0xC90DAD, // AD 0D [C9]   '..' [.]
    0xE68CAC, // AC 8C [E6]   '..' [.]
    0xE98BAB, // AB 8B [E9]   '..' [.]
    0xC18AAA, // AA 8A [C1]   '..' [.]
    0xC889A9, // A9 89 [C8]   '..' [.]
    0xFE88A8, // A8 88 [FE]   '..' [.]
    0xF487A7, // A7 87 [F4]   '..' [.]
    0xBA86A6, // A6 86 [BA]   '..' [.]
    0x7F85A5, // A5 85 [7F]   '..' [.]
    0xD18444, // 44 84 [D1]   'D.' [.]
    0xDD82C3, // C3 82 [DD]   '..' [.]
    0xF380C2, // C2 80 [F3]   '..' [.]
    0xF685C1, // C1 85 [F6]   '..' [.]
    0xD888C0, // C0 88 [D8]   '..' [.]
    0xC66F3F, // 3F 6F [C6]   '?o' [.]
    0xE85E3E, // 3E 5E [E8]   '>^' [.]
    0xED3D3D, // 3D 3D [ED]   '==' [.]
    0xC3FC3C, // 3C FC [C3]   '<.' [.]
    0xCE7B3B, // 3B 7B [CE]   ';{' [.]
    0xE37A3A, // 3A 7A [E3]   ':z' [.]
    0xE07939, // 39 79 [E0]   '9y' [.]
    0xC27838, // 38 78 [C2]   '8x' [.]
    0xE07737, // 37 77 [E0]   '7w' [.]
    0xFE7636, // 36 76 [FE]   '6v' [.]
    0x9B7535, // 35 75 [9B]   '5u' [.]
    0x757434, // 34 74 [75]   '4t' [u]
    0xF972F3, // F3 72 [F9]   '.r' [.]
    0xD770F2, // F2 70 [D7]   '.p' [.]
    0xD275F1, // F1 75 [D2]   '.u' [.]
    0xFC78F0, // F0 78 [FC]   '.x' [.]
    0xDD7FEF, // EF 7F [DD]   '..' [.]
    0xF34EEE, // EE 4E [F3]   '.N' [.]
    0xF62DED, // ED 2D [F6]   '.-' [.]
    0xD8ECEC, // EC EC [D8]   '..' [.]
    0xD56BEB, // EB 6B [D5]   '.k' [.]
    0xF86AEA, // EA 6A [F8]   '.j' [.]
    0xFB69E9, // E9 69 [FB]   '.i' [.]
    0xD968E8, // E8 68 [D9]   '.h' [.]
    0xFB67E7, // E7 67 [FB]   '.g' [.]
    0xE566E6, // E6 66 [E5]   '.f' [.]
    0x8065E5, // E5 65 [80]   '.e' [.]
    0x6E64E4, // E4 64 [6E]   '.d' [n]
    0xE26063, // 63 60 [E2]   'c`' [.]
    0xCC6762, // 62 67 [CC]   'bg' [.]
    0xC96861, // 61 68 [C9]   'ah' [.]
    0xE77160, // 60 71 [E7]   '`q' [.]
    0xFF7E5F, // 5F 7E [FF]   '_~' [.]
    0xD11F5E, // 5E 1F [D1]   '^.' [.]
    0xD4DC5D, // 5D DC [D4]   '].' [.]
    0xFB5D5C, // 5C 5D [FB]   '\]' [.]
    0xF45A5B, // 5B 5A [F4]   '[Z' [.]
    0xDC5B5A, // 5A 5B [DC]   'Z[' [.]
    0xD55859, // 59 58 [D5]   'YX' [.]
    0xE35958, // 58 59 [E3]   'XY' [.]
    0xE95657, // 57 56 [E9]   'WV' [.]
    0xA75756, // 56 57 [A7]   'VW' [.]
    0x625455, // 55 54 [62]   'UT' [b]
    0xCC5254, // 54 52 [CC]   'TR' [.]
    0xC05953, // 53 59 [C0]   'SY' [.]
    0xEE4052, // 52 40 [EE]   'R@' [.]
    0xEB7351, // 51 73 [EB]   'Qs' [.]
    0xC51250, // 50 12 [C5]   'P.' [.]
    0xE4CD4F, // 4F CD [E4]   'O.' [.]
    0xCB4C4E, // 4E 4C [CB]   'NL' [.]
    0xCD4F4D, // 4D 4F [CD]   'MO' [.]
    0xE54E4C, // 4C 4E [E5]   'LN' [.]
    0xE5494B, // 4B 49 [E5]   'KI' [.]
    0xD3484A, // 4A 48 [D3]   'JH' [.]
    0xE64B49, // 49 4B [E6]   'IK' [.]
    0xA84A48, // 48 4A [A8]   'HJ' [.]
    0x524547, // 47 45 [52]   'GE' [R]
    0xFC4A46, // 46 4A [FC]   'FJ' [.]
    0xF95145, // 45 51 [F9]   'EQ' [.]
    0xD76044, // 44 60 [D7]   'D`' [.]
    0xDB0743, // 43 07 [DB]   'C.' [.]
    0xF5C642, // 42 C6 [F5]   'B.' [.]
    0xF14541, // 41 45 [F1]   'AE' [.]
    0xDC4440, // 40 44 [DC]   '@D' [.]
    0xFD3B3F, // 3F 3B [FD]   '?;' [.]
    0xDF3A3E, // 3E 3A [DF]   '>:' [.]
    0xC2393D, // 3D 39 [C2]   '=9' [.]
    0xDC383C, // 3C 38 [DC]   '<8' [.]
    0xB03F3B, // 3B 3F [B0]   ';?' [.]
    0x5E3E3A, // 3A 3E [5E]   ':>' [^]
    0xDB2139, // 39 21 [DB]   '9!' [.]
    0xF51038, // 38 10 [F5]   '8.' [.]
    0xCF7F37, // 37 7F [CF]   '7.' [.]
    0xE1BE36, // 36 BE [E1]   '6.' [.]
    0xE53D35, // 35 3D [E5]   '5=' [.]
    0xC83C34, // 34 3C [C8]   '4<' [.]
    0xC23B33, // 33 3B [C2]   '3;' [.]
    0xE03A32, // 32 3A [E0]   '2:' [.]
    0xFD3931, // 31 39 [FD]   '19' [.]
    0xE33830, // 30 38 [E3]   '08' [.]
    0xA2272F, // 2F 27 [A2]   '/'' [.]
    0x4C262E, // 2E 26 [4C]   '.&' [L]
    0xC91D2D, // 2D 1D [C9]   '-.' [.]
    0xE77C2C, // 2C 7C [E7]   ',|' [.]
    0xEBBB2B, // 2B BB [EB]   '+.' [.]
    0xC43A2A, // 2A 3A [C4]   '*:' [.]
    0xC23929, // 29 39 [C2]   ')9' [.]
    0xEA3828, // 28 38 [EA]   '(8' [.]
    0xDC3727, // 27 37 [DC]   ''7' [.]
    0xEA3626, // 26 36 [EA]   '&6' [.]
    0xDF3525, // 25 35 [DF]   '%5' [.]
    0x913424, // 24 34 [91]   '$4' [.]
    0x5D3323, // 23 33 [5D]   '#3' []]
    0xF34222, // 22 42 [F3]   '"B' [.]
    0xF68121, // 21 81 [F6]   '!.' [.]
    0xD90020, // 20 00 [D9]   ' .' [.]
    0xC23F1F, // 1F 3F [C2]   '.?' [.]
    0xEA3E1E, // 1E 3E [EA]   '.>' [.]
    0xE33D1D, // 1D 3D [E3]   '.=' [.]
    0xD53C1C, // 1C 3C [D5]   '.<' [.]
    0xE93B1B, // 1B 3B [E9]   '.;' [.]
    0xA73A1A, // 1A 3A [A7]   '.:' [.]
    0x623919, // 19 39 [62]   '.9' [b]
    0xCCD818, // 18 D8 [CC]   '..' [.]
    0xF75717, // 17 57 [F7]   '.W' [.]
    0xDA5616, // 16 56 [DA]   '.V' [.]
    0xD95515, // 15 55 [D9]   '.U' [.]
    0xFB5414, // 14 54 [FB]   '.T' [.]
    0xEF5313, // 13 53 [EF]   '.S' [.]
    0xF15212, // 12 52 [F1]   '.R' [.]
    0x945111, // 11 51 [94]   '.Q' [.]
    0x7A5010, // 10 50 [7A]   '.P' [z]
    0xDA8F0F, // 0F 8F [DA]   '..' [.]
    0xF78E0E, // 0E 8E [F7]   '..' [.]
    0xF48D0D, // 0D 8D [F4]   '..' [.]
    0xD68C0C, // 0C 8C [D6]   '..' [.]
    0xC28B0B, // 0B 8B [C2]   '..' [.]
    0xDC8A0A, // 0A 8A [DC]   '..' [.]
    0xB98909, // 09 89 [B9]   '..' [.]
    0x578808, // 08 88 [57]   '..' [W]
    0xEE0707, // 07 07 [EE]   '..' [.]
    0xC60606, // 06 06 [C6]   '..' [.]
    0xCF0505, // 05 05 [CF]   '..' [.]
    0xF90404, // 04 04 [F9]   '..' [.]
    0xC50303, // 03 03 [C5]   '..' [.]
    0x8B0202, // 02 02 [8B]   '..' [.]
    0x4E0101, // 01 01 [4E]   '..' [N]
    0xE70000, // 00 00 [E7]   '..' [.]
};

}} // namespace zoned_otp::_data

